@@ -2,6 +2,15 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
+"""
+This module contains some script utils that are used in the chemenv package.
+"""
+
+
+import re
+from collections import OrderedDict
+
+import numpy as np
 
 from pymatgen.ext.matproj import MPRester
 from pymatgen.io.cif import CifParser
@@ -13,13 +22,6 @@ try:
 except ImportError:
     StructureVis = None  # type: ignore
     no_vis = True
-
-
-import re
-from collections import OrderedDict
-
-import numpy as np
-
 from pymatgen.analysis.chemenv.coordination_environments.chemenv_strategies import (
     SimplestChemenvStrategy,
 )
@@ -39,9 +41,6 @@ from pymatgen.analysis.chemenv.utils.defs_utils import chemenv_citations
 from pymatgen.core.sites import PeriodicSite
 from pymatgen.core.structure import Molecule
 
-"""
-This module contains some utils for the main script of the chemenv package.
-"""
 
 __author__ = "David Waroquiers"
 __copyright__ = "Copyright 2012, The Materials Project"
@@ -73,38 +72,43 @@ def draw_cg(
     show_distorted=True,
     faces_color_override=None,
 ):
+    """
+    Draw cg.
+
+    :param vis:
+    :param site:
+    :param neighbors:
+    :param cg:
+    :param perm:
+    :param perfect2local_map:
+    :param show_perfect:
+    :param csm_info:
+    :param symmetry_measure_type:
+    :param perfect_radius:
+    :param show_distorted:
+    :param faces_color_override:
+    :return:
+    """
     if show_perfect:
         if csm_info is None:
-            raise ValueError(
-                "Not possible to show perfect environment without csm_info"
-            )
+            raise ValueError("Not possible to show perfect environment without csm_info")
         csm_suffix = symmetry_measure_type[4:]
         perf_radius = (perfect_radius - 0.2) / 0.002
     if perm is not None and perfect2local_map is not None:
-        raise ValueError(
-            'Only "perm" or "perfect2local_map" should be provided in draw_cg, not both'
-        )
+        raise ValueError('Only "perm" or "perfect2local_map" should be provided in draw_cg, not both')
     if show_distorted:
         vis.add_bonds(neighbors, site)
         for n in neighbors:
             vis.add_site(n)
     if len(neighbors) < 3:
         if show_distorted:
-            vis.add_bonds(
-                neighbors, site, color=[0.0, 1.0, 0.0], opacity=0.4, radius=0.175
-            )
+            vis.add_bonds(neighbors, site, color=[0.0, 1.0, 0.0], opacity=0.4, radius=0.175)
         if show_perfect:
             if len(neighbors) == 2:
                 perfect_geometry = AbstractGeometry.from_cg(cg)
-                trans = csm_info["other_symmetry_measures"][
-                    "translation_vector_{}".format(csm_suffix)
-                ]
-                rot = csm_info["other_symmetry_measures"][
-                    "rotation_matrix_{}".format(csm_suffix)
-                ]
-                scale = csm_info["other_symmetry_measures"][
-                    "scaling_factor_{}".format(csm_suffix)
-                ]
+                trans = csm_info["other_symmetry_measures"]["translation_vector_{}".format(csm_suffix)]
+                rot = csm_info["other_symmetry_measures"]["rotation_matrix_{}".format(csm_suffix)]
+                scale = csm_info["other_symmetry_measures"]["scaling_factor_{}".format(csm_suffix)]
                 points = perfect_geometry.points_wcs_ctwcc()
                 rotated_points = rotateCoords(points, rot)
                 points = [scale * pp + trans for pp in rotated_points]
@@ -143,15 +147,9 @@ def draw_cg(
             vis.add_edges(edges)
         if show_perfect:
             perfect_geometry = AbstractGeometry.from_cg(cg)
-            trans = csm_info["other_symmetry_measures"][
-                "translation_vector_{}".format(csm_suffix)
-            ]
-            rot = csm_info["other_symmetry_measures"][
-                "rotation_matrix_{}".format(csm_suffix)
-            ]
-            scale = csm_info["other_symmetry_measures"][
-                "scaling_factor_{}".format(csm_suffix)
-            ]
+            trans = csm_info["other_symmetry_measures"]["translation_vector_{}".format(csm_suffix)]
+            rot = csm_info["other_symmetry_measures"]["rotation_matrix_{}".format(csm_suffix)]
+            scale = csm_info["other_symmetry_measures"]["scaling_factor_{}".format(csm_suffix)]
             points = perfect_geometry.points_wcs_ctwcc()
             rotated_points = rotateCoords(points, rot)
             points = [scale * pp + trans for pp in rotated_points]
@@ -172,15 +170,22 @@ def draw_cg(
                 )
 
 
-# Visualizing a coordination geometry
-def visualize(
-    cg, zoom=None, vis=None, myfactor=1.0, view_index=True, faces_color_override=None
-):
+def visualize(cg, zoom=None, vis=None, myfactor=1.0, view_index=True, faces_color_override=None):
+    """
+    Visualizing a coordination geometry
+    :param cg:
+    :param zoom:
+    :param vis:
+    :param myfactor:
+    :param view_index:
+    :param faces_color_override:
+    :return:
+    """
     if vis is None:
         vis = StructureVis(show_polyhedron=False, show_unit_cell=False)
     myspecies = ["O"] * (cg.coordination_number + 1)
     myspecies[0] = "Cu"
-    coords = [np.zeros(3, np.float) + cg.central_site]
+    coords = [np.zeros(3, np.float_) + cg.central_site]
 
     for pp in cg.points:
         coords.append(np.array(pp) + cg.central_site)
@@ -204,17 +209,32 @@ def visualize(
 
 
 def welcome(chemenv_config):
+    """
+    Show welcome message.
+    :param chemenv_config:
+    :return:
+    """
     print("Chemical Environment package (ChemEnv)")
     print(chemenv_citations())
     print(chemenv_config.package_options_description())
 
 
 def thankyou():
+    """
+    Show thank you message.
+    :return:
+    """
     print("Thank you for using the ChemEnv package")
     print(chemenv_citations())
 
 
 def compute_environments(chemenv_configuration):
+    """
+    Compute the environments.
+
+    :param chemenv_configuration:
+    :return:
+    """
     string_sources = {
         "cif": {"string": "a Cif file", "regexp": r".*\.cif$"},
         "mp": {"string": "the Materials Project database", "regexp": r"mp-[0-9]+$"},
@@ -224,30 +244,18 @@ def compute_environments(chemenv_configuration):
     lgf = LocalGeometryFinder()
     lgf.setup_parameters()
     allcg = AllCoordinationGeometries()
-    strategy_class = strategies_class_lookup[
-        chemenv_configuration.package_options["default_strategy"]["strategy"]
-    ]
+    strategy_class = strategies_class_lookup[chemenv_configuration.package_options["default_strategy"]["strategy"]]
     # TODO: Add the possibility to change the parameters and save them in the chemenv_configuration
     default_strategy = strategy_class()
-    default_strategy.setup_options(
-        chemenv_configuration.package_options["default_strategy"]["strategy_options"]
-    )
-    max_dist_factor = chemenv_configuration.package_options[
-        "default_max_distance_factor"
-    ]
+    default_strategy.setup_options(chemenv_configuration.package_options["default_strategy"]["strategy_options"])
+    max_dist_factor = chemenv_configuration.package_options["default_max_distance_factor"]
     firsttime = True
     while True:
         if len(questions) > 1:
             found = False
-            print(
-                "Enter the source from which the structure is coming or <q> to quit :"
-            )
+            print("Enter the source from which the structure is coming or <q> to quit :")
             for key_character, qq in questions.items():
-                print(
-                    " - <{}> for a structure from {}".format(
-                        key_character, string_sources[qq]["string"]
-                    )
-                )
+                print(" - <{}> for a structure from {}".format(key_character, string_sources[qq]["string"]))
             test = input(" ... ")
             if test == "q":
                 break
@@ -277,11 +285,7 @@ def compute_environments(chemenv_configuration):
             a = MPRester()
             structure = a.get_structure_by_material_id(input_source)
         lgf.setup_structure(structure)
-        print(
-            "Computing environments for {} ... ".format(
-                structure.composition.reduced_formula
-            )
-        )
+        print("Computing environments for {} ... ".format(structure.composition.reduced_formula))
         se = lgf.compute_structure_environments(maximum_distance_factor=max_dist_factor)
         print("Computing environments finished")
         while True:
@@ -299,9 +303,7 @@ def compute_environments(chemenv_configuration):
                         if strategy.uniquely_determines_coordination_environments:
                             ces = strategy.get_site_coordination_environments(site)
                         else:
-                            ces = strategy.get_site_coordination_environments_fractions(
-                                site
-                            )
+                            ces = strategy.get_site_coordination_environments_fractions(site)
                     except NeighborsNotComputedChemenvError:
                         continue
                     if ces is None:
@@ -334,19 +336,12 @@ def compute_environments(chemenv_configuration):
                             mystring += " - {} ({}): {:.2f} % (csm : {:2f})\n".format(
                                 cg.name, cg.mp_symbol, 100.0 * ce[2], csm
                             )
-                    if (
-                        test in ["d", "g"]
-                        and strategy.uniquely_determines_coordination_environments
-                    ):
+                    if test in ["d", "g"] and strategy.uniquely_determines_coordination_environments:
                         if thecg.mp_symbol != UNCLEAR_ENVIRONMENT_SYMBOL:
                             mystring += "  <Continuous symmetry measures>  "
-                            mingeoms = se.ce_list[isite][thecg.coordination_number][
-                                0
-                            ].minimum_geometries()
+                            mingeoms = se.ce_list[isite][thecg.coordination_number][0].minimum_geometries()
                             for mingeom in mingeoms:
-                                csm = mingeom[1]["other_symmetry_measures"][
-                                    "csm_wcs_ctwcc"
-                                ]
+                                csm = mingeom[1]["other_symmetry_measures"]["csm_wcs_ctwcc"]
                                 mystring += "{} : {:.2f}       ".format(mingeom[0], csm)
                     print(mystring)
             if test == "g":
@@ -361,9 +356,7 @@ def compute_environments(chemenv_configuration):
                         for isite in indices:
                             if isite < 0:
                                 raise IndexError
-                            se.plot_environments(
-                                isite, additional_condition=se.AC.ONLY_ACB
-                            )
+                            se.plot_environments(isite)
                         break
                     except ValueError:
                         print("This is not a valid site")
@@ -375,9 +368,7 @@ def compute_environments(chemenv_configuration):
                 if test == "y":
                     break
                 continue
-            test = input(
-                'View structure with environments ? ("y" for the unit cell or "m" for a supercell or "n") : '
-            )
+            test = input('View structure with environments ? ("y" for the unit cell or "m" for a supercell or "n") : ')
             if test in ["y", "m"]:
                 if test == "m":
                     mydeltas = []
@@ -388,17 +379,13 @@ def compute_environments(chemenv_configuration):
                             for i0 in range(int(nns[0])):
                                 for i1 in range(int(nns[1])):
                                     for i2 in range(int(nns[2])):
-                                        mydeltas.append(
-                                            np.array(
-                                                [1.0 * i0, 1.0 * i1, 1.0 * i2], np.float
-                                            )
-                                        )
+                                        mydeltas.append(np.array([1.0 * i0, 1.0 * i1, 1.0 * i2], np.float_))
                             break
 
                         except (ValueError, IndexError):
                             print("Not a valid multiplicity")
                 else:
-                    mydeltas = [np.zeros(3, np.float)]
+                    mydeltas = [np.zeros(3, np.float_)]
                 if firsttime:
                     vis = StructureVis(show_polyhedron=False, show_unit_cell=True)
                     vis.show_help = False
