@@ -12,7 +12,7 @@ import logging
 from monty.json import MSONable
 
 from pymatgen.analysis.graphs import MoleculeGraph, MolGraphSplitError
-from pymatgen.analysis.local_env import OpenBabelNN
+from pymatgen.analysis.local_env import OpenBabelNN, metal_edge_extender
 from pymatgen.io.babel import BabelMolAdaptor
 
 __author__ = "Samuel Blau"
@@ -82,26 +82,18 @@ class Fragmenter(MSONable):
         self.opt_steps = opt_steps
 
         if edges is None:
-            self.mol_graph = MoleculeGraph.with_local_env_strategy(
-                molecule, OpenBabelNN()
-            )
+            self.mol_graph = MoleculeGraph.with_local_env_strategy(molecule, OpenBabelNN())
         else:
             edges = {(e[0], e[1]): None for e in edges}
             self.mol_graph = MoleculeGraph.with_edges(molecule, edges)
 
-        if (
-            "Li" in molecule.composition or "Mg" in molecule.composition
-        ) and use_metal_edge_extender:
+        if ("Li" in molecule.composition or "Mg" in molecule.composition) and use_metal_edge_extender:
             self.mol_graph = metal_edge_extender(self.mol_graph)
 
         self.prev_unique_frag_dict = prev_unique_frag_dict or {}
-        self.new_unique_frag_dict = (
-            {}
-        )  # new fragments from the given molecule not contained in prev_unique_frag_dict
+        self.new_unique_frag_dict = {}  # new fragments from the given molecule not contained in prev_unique_frag_dict
         self.all_unique_frag_dict = {}  # all fragments from just the given molecule
-        self.unique_frag_dict = (
-            {}
-        )  # all fragments from both the given molecule and prev_unique_frag_dict
+        self.unique_frag_dict = {}  # all fragments from both the given molecule and prev_unique_frag_dict
 
         if depth == 0:  # Non-iterative, find all possible fragments:
 
@@ -122,9 +114,7 @@ class Fragmenter(MSONable):
                 if level == 0:
                     self.fragments_by_level["0"] = self._fragment_one_level(
                         {
-                            str(
-                                self.mol_graph.molecule.composition.alphabetical_formula
-                            )
+                            str(self.mol_graph.molecule.composition.alphabetical_formula)
                             + " E"
                             + str(len(self.mol_graph.graph.edges())): [self.mol_graph]
                         }
@@ -132,9 +122,7 @@ class Fragmenter(MSONable):
                 else:
                     num_frags_prev_level = 0
                     for key in self.fragments_by_level[str(level - 1)]:
-                        num_frags_prev_level += len(
-                            self.fragments_by_level[str(level - 1)][key]
-                        )
+                        num_frags_prev_level += len(self.fragments_by_level[str(level - 1)][key])
                     if num_frags_prev_level == 0:
                         # Nothing left to fragment, so exit the loop:
                         break
@@ -149,9 +137,7 @@ class Fragmenter(MSONable):
         else:
             for frag_key in self.all_unique_frag_dict:
                 if frag_key not in self.prev_unique_frag_dict:
-                    self.new_unique_frag_dict[frag_key] = copy.deepcopy(
-                        self.all_unique_frag_dict[frag_key]
-                    )
+                    self.new_unique_frag_dict[frag_key] = copy.deepcopy(self.all_unique_frag_dict[frag_key])
                 else:
                     for fragment in self.all_unique_frag_dict[frag_key]:
                         found = False
@@ -178,9 +164,7 @@ class Fragmenter(MSONable):
                     for new_frag in self.new_unique_frag_dict[frag_key]:
                         self.unique_frag_dict[frag_key].append(new_frag)
                 else:
-                    self.unique_frag_dict[frag_key] = copy.deepcopy(
-                        self.new_unique_frag_dict[frag_key]
-                    )
+                    self.unique_frag_dict[frag_key] = copy.deepcopy(self.new_unique_frag_dict[frag_key])
 
             self.total_unique_fragments = 0
             for frag_key in self.unique_frag_dict:
@@ -202,9 +186,7 @@ class Fragmenter(MSONable):
                     bond = [(edge[0], edge[1])]
                     fragments = []
                     try:
-                        fragments = old_frag.split_molecule_subgraphs(
-                            bond, allow_reverse=True
-                        )
+                        fragments = old_frag.split_molecule_subgraphs(bond, allow_reverse=True)
                     except MolGraphSplitError:
                         if self.open_rings:
                             fragments = [open_ring(old_frag, bond, self.opt_steps)]
@@ -215,14 +197,9 @@ class Fragmenter(MSONable):
                             + str(len(fragment.graph.edges()))
                         )
                         proceed = True
-                        if (
-                            self.assume_previous_thoroughness
-                            and self.prev_unique_frag_dict != {}
-                        ):
+                        if self.assume_previous_thoroughness and self.prev_unique_frag_dict != {}:
                             if new_frag_key in self.prev_unique_frag_dict:
-                                for unique_fragment in self.prev_unique_frag_dict[
-                                    new_frag_key
-                                ]:
+                                for unique_fragment in self.prev_unique_frag_dict[new_frag_key]:
                                     if unique_fragment.isomorphic_to(fragment):
                                         proceed = False
                                         break
@@ -232,16 +209,12 @@ class Fragmenter(MSONable):
                                 new_frag_dict[new_frag_key] = [fragment]
                             else:
                                 found = False
-                                for unique_fragment in self.all_unique_frag_dict[
-                                    new_frag_key
-                                ]:
+                                for unique_fragment in self.all_unique_frag_dict[new_frag_key]:
                                     if unique_fragment.isomorphic_to(fragment):
                                         found = True
                                         break
                                 if not found:
-                                    self.all_unique_frag_dict[new_frag_key].append(
-                                        fragment
-                                    )
+                                    self.all_unique_frag_dict[new_frag_key].append(fragment)
                                     if new_frag_key in new_frag_dict:
                                         new_frag_dict[new_frag_key].append(fragment)
                                     else:
@@ -278,9 +251,7 @@ class Fragmenter(MSONable):
                         if frag_key not in self.all_unique_frag_dict:
                             if frag_key not in new_frag_keys["0"]:
                                 new_frag_keys["0"].append(copy.deepcopy(frag_key))
-                                new_frag_key_dict[frag_key] = copy.deepcopy(
-                                    [new_fragment]
-                                )
+                                new_frag_key_dict[frag_key] = copy.deepcopy([new_fragment])
                             else:
                                 found = False
                                 for unique_fragment in new_frag_key_dict[frag_key]:
@@ -288,9 +259,7 @@ class Fragmenter(MSONable):
                                         found = True
                                         break
                                 if not found:
-                                    new_frag_key_dict[frag_key].append(
-                                        copy.deepcopy(new_fragment)
-                                    )
+                                    new_frag_key_dict[frag_key].append(copy.deepcopy(new_fragment))
                         else:
                             found = False
                             for unique_fragment in self.all_unique_frag_dict[frag_key]:
@@ -298,9 +267,7 @@ class Fragmenter(MSONable):
                                     found = True
                                     break
                             if not found:
-                                self.all_unique_frag_dict[frag_key].append(
-                                    copy.deepcopy(new_fragment)
-                                )
+                                self.all_unique_frag_dict[frag_key].append(copy.deepcopy(new_fragment))
         for key in new_frag_key_dict:
             self.all_unique_frag_dict[key] = copy.deepcopy(new_frag_key_dict[key])
         idx = 0
@@ -315,20 +282,14 @@ class Fragmenter(MSONable):
                         for bond in ring_edges[0]:
                             new_fragment = open_ring(fragment, [bond], self.opt_steps)
                             frag_key = (
-                                str(
-                                    new_fragment.molecule.composition.alphabetical_formula
-                                )
+                                str(new_fragment.molecule.composition.alphabetical_formula)
                                 + " E"
                                 + str(len(new_fragment.graph.edges()))
                             )
                             if frag_key not in self.all_unique_frag_dict:
                                 if frag_key not in new_frag_keys[str(idx)]:
-                                    new_frag_keys[str(idx)].append(
-                                        copy.deepcopy(frag_key)
-                                    )
-                                    new_frag_key_dict[frag_key] = copy.deepcopy(
-                                        [new_fragment]
-                                    )
+                                    new_frag_keys[str(idx)].append(copy.deepcopy(frag_key))
+                                    new_frag_key_dict[frag_key] = copy.deepcopy([new_fragment])
                                 else:
                                     found = False
                                     for unique_fragment in new_frag_key_dict[frag_key]:
@@ -336,21 +297,15 @@ class Fragmenter(MSONable):
                                             found = True
                                             break
                                     if not found:
-                                        new_frag_key_dict[frag_key].append(
-                                            copy.deepcopy(new_fragment)
-                                        )
+                                        new_frag_key_dict[frag_key].append(copy.deepcopy(new_fragment))
                             else:
                                 found = False
-                                for unique_fragment in self.all_unique_frag_dict[
-                                    frag_key
-                                ]:
+                                for unique_fragment in self.all_unique_frag_dict[frag_key]:
                                     if unique_fragment.isomorphic_to(new_fragment):
                                         found = True
                                         break
                                 if not found:
-                                    self.all_unique_frag_dict[frag_key].append(
-                                        copy.deepcopy(new_fragment)
-                                    )
+                                    self.all_unique_frag_dict[frag_key].append(copy.deepcopy(new_fragment))
             for key in new_frag_key_dict:
                 self.all_unique_frag_dict[key] = copy.deepcopy(new_frag_key_dict[key])
         self.all_unique_frag_dict.pop(mol_key)
@@ -368,45 +323,3 @@ def open_ring(mol_graph, bond, opt_steps):
     obmol.remove_bond(bond[0][0] + 1, bond[0][1] + 1)
     obmol.localopt(steps=opt_steps, forcefield="uff")
     return MoleculeGraph.with_local_env_strategy(obmol.pymatgen_mol, OpenBabelNN())
-
-
-def metal_edge_extender(mol_graph):
-    """
-    Function to identify and add missed edges in ionic bonding of Li and Mg ions.
-    """
-    metal_sites = {"Li": {}, "Mg": {}}
-    coordinators = ["O", "N", "F", "Cl"]
-    num_new_edges = 0
-    for idx in mol_graph.graph.nodes():
-        if mol_graph.graph.nodes()[idx]["specie"] in metal_sites:
-            metal_sites[mol_graph.graph.nodes()[idx]["specie"]][idx] = [
-                site[2] for site in mol_graph.get_connected_sites(idx)
-            ]
-    for metal in metal_sites:
-        for idx in metal_sites[metal]:
-            for ii, site in enumerate(mol_graph.molecule):
-                if ii != idx and ii not in metal_sites[metal][idx]:
-                    if str(site.specie) in coordinators:
-                        if site.distance(mol_graph.molecule[idx]) < 2.5:
-                            mol_graph.add_edge(idx, ii)
-                            num_new_edges += 1
-                            metal_sites[metal][idx].append(ii)
-    total_metal_edges = 0
-    for metal in metal_sites:
-        for idx in metal_sites[metal]:
-            total_metal_edges += len(metal_sites[metal][idx])
-    if total_metal_edges == 0:
-        for metal in metal_sites:
-            for idx in metal_sites[metal]:
-                for ii, site in enumerate(mol_graph.molecule):
-                    if ii != idx and ii not in metal_sites[metal][idx]:
-                        if str(site.specie) in coordinators:
-                            if site.distance(mol_graph.molecule[idx]) < 3.5:
-                                mol_graph.add_edge(idx, ii)
-                                num_new_edges += 1
-                                metal_sites[metal][idx].append(ii)
-    total_metal_edges = 0
-    for metal in metal_sites:
-        for idx in metal_sites[metal]:
-            total_metal_edges += len(metal_sites[metal][idx])
-    return mol_graph
