@@ -24,6 +24,7 @@ from multiprocessing import Pool
 
 import numpy as np
 from monty.json import MontyDecoder, MSONable
+from monty.dev import deprecated
 from scipy.spatial import ConvexHull, HalfspaceIntersection
 
 try:
@@ -33,6 +34,7 @@ except ImportError:
 
 from tqdm import tqdm
 
+
 from pymatgen.analysis.phase_diagram import PDEntry, PhaseDiagram
 from pymatgen.analysis.reaction_calculator import Reaction, ReactionError
 from pymatgen.core.composition import Composition
@@ -44,6 +46,7 @@ from pymatgen.util.coord import Simplex
 from pymatgen.util.plotting import pretty_plot
 from pymatgen.util.string import latexify
 
+
 __author__ = "Sai Jayaraman"
 __copyright__ = "Copyright 2012, The Materials Project"
 __version__ = "0.4"
@@ -105,9 +108,7 @@ class PourbaixEntry(MSONable):
         """
         Returns:
         """
-        return self.entry.composition.get("H", 0.0) - 2 * self.entry.composition.get(
-            "O", 0.0
-        )
+        return self.entry.composition.get("H", 0.0) - 2 * self.entry.composition.get("O", 0.0)
 
     @property
     def nH2O(self):
@@ -247,9 +248,7 @@ class PourbaixEntry(MSONable):
         """
         Sum of number of atoms minus the number of H and O in composition
         """
-        return 1.0 / (
-            self.num_atoms - self.composition.get("H", 0) - self.composition.get("O", 0)
-        )
+        return 1.0 / (self.num_atoms - self.composition.get("H", 0) - self.composition.get("O", 0))
 
     @property
     def composition(self):
@@ -400,18 +399,14 @@ class IonEntry(PDEntry):
         self.ion = ion
         # Auto-assign name
         name = name if name else self.ion.reduced_formula
-        super().__init__(
-            composition=ion.composition, energy=energy, name=name, attribute=attribute
-        )
+        super().__init__(composition=ion.composition, energy=energy, name=name, attribute=attribute)
 
     @classmethod
     def from_dict(cls, d):
         """
         Returns an IonEntry object from a dict.
         """
-        return IonEntry(
-            Ion.from_dict(d["ion"]), d["energy"], d.get("name"), d.get("attribute")
-        )
+        return IonEntry(Ion.from_dict(d["ion"]), d["energy"], d.get("name"), d.get("attribute"))
 
     def as_dict(self):
         """
@@ -421,9 +416,7 @@ class IonEntry(PDEntry):
         return d
 
     def __repr__(self):
-        return "IonEntry : {} with energy = {:.4f}".format(
-            self.composition, self.energy
-        )
+        return "IonEntry : {} with energy = {:.4f}".format(self.composition, self.energy)
 
     def __str__(self):
         return self.__repr__()
@@ -467,9 +460,7 @@ class PourbaixDiagram(MSONable):
     Class to create a Pourbaix diagram from entries
     """
 
-    def __init__(
-        self, entries, comp_dict=None, conc_dict=None, filter_solids=False, nproc=None
-    ):
+    def __init__(self, entries, comp_dict=None, conc_dict=None, filter_solids=False, nproc=None):
         """
         Args:
             entries ([PourbaixEntry] or [MultiEntry]): Entries list
@@ -489,11 +480,7 @@ class PourbaixDiagram(MSONable):
         entries = deepcopy(entries)
 
         # Get non-OH elements
-        self.pbx_elts = set(
-            itertools.chain.from_iterable(
-                [entry.composition.elements for entry in entries]
-            )
-        )
+        self.pbx_elts = set(itertools.chain.from_iterable([entry.composition.elements for entry in entries]))
         self.pbx_elts = list(self.pbx_elts - ELEMENTS_HO)
         self.dim = len(self.pbx_elts) - 1
 
@@ -501,24 +488,18 @@ class PourbaixDiagram(MSONable):
         if isinstance(entries[0], MultiEntry):
             self._processed_entries = entries
             # Extract individual entries
-            single_entries = list(
-                set(itertools.chain.from_iterable([e.entry_list for e in entries]))
-            )
+            single_entries = list(set(itertools.chain.from_iterable([e.entry_list for e in entries])))
             self._unprocessed_entries = single_entries
             self._filtered_entries = single_entries
             self._conc_dict = None
-            self._elt_comp = {
-                k: v for k, v in entries[0].composition.items() if k not in ELEMENTS_HO
-            }
+            self._elt_comp = {k: v for k, v in entries[0].composition.items() if k not in ELEMENTS_HO}
             self._multielement = True
 
         # Process single entry inputs
         else:
             # Set default conc/comp dicts
             if not comp_dict:
-                comp_dict = {
-                    elt.symbol: 1.0 / len(self.pbx_elts) for elt in self.pbx_elts
-                }
+                comp_dict = {elt.symbol: 1.0 / len(self.pbx_elts) for elt in self.pbx_elts}
             if not conc_dict:
                 conc_dict = {elt.symbol: 1e-6 for elt in self.pbx_elts}
             self._conc_dict = conc_dict
@@ -535,22 +516,14 @@ class PourbaixDiagram(MSONable):
                 # TODO: the logic here for ion concentration setting is in two
                 #       places, in PourbaixEntry and here, should be consolidated
                 if len(ion_elts) == 1:
-                    entry.concentration = (
-                        conc_dict[ion_elts[0].symbol] * entry.normalization_factor
-                    )
+                    entry.concentration = conc_dict[ion_elts[0].symbol] * entry.normalization_factor
                 elif len(ion_elts) > 1 and not entry.concentration:
-                    raise ValueError(
-                        "Elemental concentration not compatible "
-                        "with multi-element ions"
-                    )
+                    raise ValueError("Elemental concentration not compatible " "with multi-element ions")
 
             self._unprocessed_entries = solid_entries + ion_entries
 
             if not len(solid_entries + ion_entries) == len(entries):
-                raise ValueError(
-                    "All supplied entries must have a phase type of "
-                    'either "Solid" or "Ion"'
-                )
+                raise ValueError("All supplied entries must have a phase type of " 'either "Solid" or "Ion"')
 
             if filter_solids:
                 # O is 2.46 b/c pbx entry finds energies referenced to H2O
@@ -562,16 +535,12 @@ class PourbaixDiagram(MSONable):
 
             if len(comp_dict) > 1:
                 self._multielement = True
-                self._processed_entries = self._preprocess_pourbaix_entries(
-                    self._filtered_entries, nproc=nproc
-                )
+                self._processed_entries = self._preprocess_pourbaix_entries(self._filtered_entries, nproc=nproc)
             else:
                 self._processed_entries = self._filtered_entries
                 self._multielement = False
 
-        self._stable_domains, self._stable_domain_vertices = self.get_pourbaix_domains(
-            self._processed_entries
-        )
+        self._stable_domains, self._stable_domain_vertices = self.get_pourbaix_domains(self._processed_entries)
 
     def _convert_entries_to_points(self, pourbaix_entries):
         """
@@ -585,14 +554,11 @@ class PourbaixDiagram(MSONable):
 
         """
         vecs = [
-            [entry.npH, entry.nPhi, entry.energy]
-            + [entry.composition.get(elt) for elt in self.pbx_elts[:-1]]
+            [entry.npH, entry.nPhi, entry.energy] + [entry.composition.get(elt) for elt in self.pbx_elts[:-1]]
             for entry in pourbaix_entries
         ]
         vecs = np.array(vecs)
-        norms = np.transpose(
-            [[entry.normalization_factor for entry in pourbaix_entries]]
-        )
+        norms = np.transpose([[entry.normalization_factor for entry in pourbaix_entries]])
         vecs *= norms
         return vecs
 
@@ -620,12 +586,8 @@ class PourbaixDiagram(MSONable):
             solid_entries,
             key=lambda x: (x.composition.reduced_composition, x.entry.energy_per_atom),
         )
-        grouped_by_composition = itertools.groupby(
-            sorted_entries, key=lambda x: x.composition.reduced_composition
-        )
-        min_entries = [
-            list(grouped_entries)[0] for comp, grouped_entries in grouped_by_composition
-        ]
+        grouped_by_composition = itertools.groupby(sorted_entries, key=lambda x: x.composition.reduced_composition)
+        min_entries = [list(grouped_entries)[0] for comp, grouped_entries in grouped_by_composition]
         min_entries += ion_entries
 
         logger.debug("Constructing nph-nphi-composition points for qhull")
@@ -649,9 +611,7 @@ class PourbaixDiagram(MSONable):
             valid_facets = []
             for facet in facets:
                 comps = vecs[facet][:, 3:]
-                full_comps = np.concatenate(
-                    [comps, 1 - np.sum(comps, axis=1).reshape(len(comps), 1)], axis=1
-                )
+                full_comps = np.concatenate([comps, 1 - np.sum(comps, axis=1).reshape(len(comps), 1)], axis=1)
                 # Ensure an compositional interior point exists in the simplex
                 if np.linalg.matrix_rank(full_comps) > self.dim:
                     valid_facets.append(facet)
@@ -734,17 +694,14 @@ class PourbaixDiagram(MSONable):
         entry_combos = [itertools.combinations(entries, j + 1) for j in range(N)]
         entry_combos = itertools.chain.from_iterable(entry_combos)
 
-        entry_combos = filter(
-            lambda x: total_comp < MultiEntry(x).composition, entry_combos
-        )
+        entry_combos = filter(lambda x: total_comp < MultiEntry(x).composition, entry_combos)
 
         # Generate and filter entries
         processed_entries = []
         total = sum([comb(len(entries), j + 1) for j in range(N)])
         if total > 1e6:
             warnings.warn(
-                "Your pourbaix diagram includes {} entries and may "
-                "take a long time to generate.".format(total)
+                "Your pourbaix diagram includes {} entries and may " "take a long time to generate.".format(total)
             )
 
         # Parallel processing of multi-entry generation
@@ -832,8 +789,7 @@ class PourbaixDiagram(MSONable):
 
         # Get hyperplanes
         hyperplanes = [
-            np.array([-PREFAC * entry.npH, -entry.nPhi, 0, -entry.energy])
-            * entry.normalization_factor
+            np.array([-PREFAC * entry.npH, -entry.nPhi, 0, -entry.energy]) * entry.normalization_factor
             for entry in pourbaix_entries
         ]
         hyperplanes = np.array(hyperplanes)
@@ -875,15 +831,11 @@ class PourbaixDiagram(MSONable):
 
             # Sort points by cross product of centered points,
             # isn't strictly necessary but useful for plotting tools
-            points_centered = sorted(
-                points_centered, key=cmp_to_key(lambda x, y: x[0] * y[1] - x[1] * y[0])
-            )
+            points_centered = sorted(points_centered, key=cmp_to_key(lambda x, y: x[0] * y[1] - x[1] * y[0]))
             points = points_centered + center
 
             # Create simplices corresponding to pourbaix boundary
-            simplices = [
-                Simplex(points[indices]) for indices in ConvexHull(points).simplices
-            ]
+            simplices = [Simplex(points[indices]) for indices in ConvexHull(points).simplices]
             pourbaix_domains[entry] = simplices
             pourbaix_domain_vertices[entry] = points
 
@@ -899,9 +851,7 @@ class PourbaixDiagram(MSONable):
         Returns:
 
         """
-        energies_at_conditions = [
-            e.normalized_energy_at_conditions(pH, V) for e in self.stable_entries
-        ]
+        energies_at_conditions = [e.normalized_energy_at_conditions(pH, V) for e in self.stable_entries]
         return self.stable_entries[np.argmin(energies_at_conditions)]
 
     def get_decomposition_energy(self, entry, pH, V):
@@ -923,16 +873,10 @@ class PourbaixDiagram(MSONable):
         # Check composition consistency between entry and Pourbaix diagram:
         pbx_comp = Composition(self._elt_comp).fractional_composition
         entry_pbx_comp = Composition(
-            {
-                elt: coeff
-                for elt, coeff in entry.composition.items()
-                if elt not in ELEMENTS_HO
-            }
+            {elt: coeff for elt, coeff in entry.composition.items() if elt not in ELEMENTS_HO}
         ).fractional_composition
         if entry_pbx_comp != pbx_comp:
-            raise ValueError(
-                "Composition of stability entry does not match " "Pourbaix Diagram"
-            )
+            raise ValueError("Composition of stability entry does not match " "Pourbaix Diagram")
         entry_normalized_energy = entry.normalized_energy_at_conditions(pH, V)
         hull_energy = self.get_hull_energy(pH, V)
         decomposition_energy = entry_normalized_energy - hull_energy
@@ -955,9 +899,7 @@ class PourbaixDiagram(MSONable):
             (float or [float]) minimum pourbaix energy at conditions
 
         """
-        all_gs = np.array(
-            [e.normalized_energy_at_conditions(pH, V) for e in self.stable_entries]
-        )
+        all_gs = np.array([e.normalized_energy_at_conditions(pH, V) for e in self.stable_entries])
         base = np.min(all_gs, axis=0)
         return base
 
@@ -975,9 +917,7 @@ class PourbaixDiagram(MSONable):
                 pH, V condition
 
         """
-        all_gs = np.array(
-            [e.normalized_energy_at_conditions(pH, V) for e in self.stable_entries]
-        )
+        all_gs = np.array([e.normalized_energy_at_conditions(pH, V) for e in self.stable_entries])
         return self.stable_entries[np.argmin(all_gs)]
 
     @property
@@ -1090,12 +1030,8 @@ class PourbaixPlotter:
         xlim = limits[0]
         ylim = limits[1]
 
-        h_line = np.transpose(
-            [[xlim[0], -xlim[0] * PREFAC], [xlim[1], -xlim[1] * PREFAC]]
-        )
-        o_line = np.transpose(
-            [[xlim[0], -xlim[0] * PREFAC + 1.23], [xlim[1], -xlim[1] * PREFAC + 1.23]]
-        )
+        h_line = np.transpose([[xlim[0], -xlim[0] * PREFAC], [xlim[1], -xlim[1] * PREFAC]])
+        o_line = np.transpose([[xlim[0], -xlim[0] * PREFAC + 1.23], [xlim[1], -xlim[1] * PREFAC + 1.23]])
         neutral_line = np.transpose([[7, ylim[0]], [7, ylim[1]]])
         V0_line = np.transpose([[xlim[0], 0], [xlim[1], 0]])
 
@@ -1137,7 +1073,7 @@ class PourbaixPlotter:
         V_resolution=100,
         e_hull_max=1,
         cmap="RdYlBu_r",
-        **kwargs
+        **kwargs,
     ):
         """
         Args:
@@ -1205,6 +1141,10 @@ def generate_entry_label(entry):
     return latexify_ion(latexify(entry.name))
 
 
+@deprecated(
+    message="These methods have been deprecated in favor of using the Stringify mix-in class, which provides"
+    "to_latex_string, to_unicode_string, etc. They will be removed in v2022."
+)
 def latexify_ion(formula):
     """
     Convert a formula to latex format.
