@@ -286,9 +286,7 @@ class OccupancyComparator(AbstractComparator):
         Returns:
             True if sets of occupancies (amt) are equal on both sites.
         """
-        return set(sp1.element_composition.values()) == set(
-            sp2.element_composition.values()
-        )
+        return set(sp1.element_composition.values()) == set(sp2.element_composition.values())
 
     def get_hash(self, composition):
         """
@@ -537,9 +535,7 @@ class StructureMatcher(MSONable):
             raise ValueError("mask has incorrect shape")
 
         # vectors are from s2 to s1
-        vecs, d_2 = pbc_shortest_vectors(
-            avg_lattice, s2, s1, mask, return_d2=True, lll_frac_tol=lll_frac_tol
-        )
+        vecs, d_2 = pbc_shortest_vectors(avg_lattice, s2, s1, mask, return_d2=True, lll_frac_tol=lll_frac_tol)
         lin = LinearAssignment(d_2)
         s = lin.solution
         short_vecs = vecs[np.arange(len(s)), s]
@@ -561,15 +557,11 @@ class StructureMatcher(MSONable):
         mask = np.zeros((len(struct2), len(struct1), fu), dtype=np.bool)
 
         inner = []
-        for sp2, i in itertools.groupby(
-            enumerate(struct2.species_and_occu), key=lambda x: x[1]
-        ):
+        for sp2, i in itertools.groupby(enumerate(struct2.species_and_occu), key=lambda x: x[1]):
             i = list(i)
             inner.append((sp2, slice(i[0][0], i[-1][0] + 1)))
 
-        for sp1, j in itertools.groupby(
-            enumerate(struct1.species_and_occu), key=lambda x: x[1]
-        ):
+        for sp1, j in itertools.groupby(enumerate(struct1.species_and_occu), key=lambda x: x[1]):
             j = list(j)
             j = slice(j[0][0], j[-1][0] + 1)
             for sp2, i in inner:
@@ -607,9 +599,9 @@ class StructureMatcher(MSONable):
         """
         struct1, struct2 = self._process_species([struct1, struct2])
 
-        if not self._subset and self._comparator.get_hash(
-            struct1.composition
-        ) != self._comparator.get_hash(struct2.composition):
+        if not self._subset and self._comparator.get_hash(struct1.composition) != self._comparator.get_hash(
+            struct2.composition
+        ):
             return None
 
         if not symmetric:
@@ -646,9 +638,7 @@ class StructureMatcher(MSONable):
         """
         struct1, struct2 = self._process_species([struct1, struct2])
         struct1, struct2, fu, s1_supercell = self._preprocess(struct1, struct2)
-        match = self._match(
-            struct1, struct2, fu, s1_supercell, use_rms=True, break_on_match=False
-        )
+        match = self._match(struct1, struct2, fu, s1_supercell, use_rms=True, break_on_match=False)
 
         if match is None:
             return None
@@ -759,9 +749,7 @@ class StructureMatcher(MSONable):
         mask, s1_t_inds, s2_t_ind = self._get_mask(struct1, struct2, fu, s1_supercell)
 
         if mask.shape[0] > mask.shape[1]:
-            raise ValueError(
-                "after supercell creation, struct1 must " "have more sites than struct2"
-            )
+            raise ValueError("after supercell creation, struct1 must " "have more sites than struct2")
 
         # check that a valid mapping exists
         if (not self._subset) and mask.shape[1] != mask.shape[0]:
@@ -772,9 +760,7 @@ class StructureMatcher(MSONable):
 
         best_match = None
         # loop over all lattices
-        for s1fc, s2fc, avg_l, sc_m in self._get_supercells(
-            struct1, struct2, fu, s1_supercell
-        ):
+        for s1fc, s2fc, avg_l, sc_m in self._get_supercells(struct1, struct2, fu, s1_supercell):
             # compute fractional tolerance
             normalization = (len(s1fc) / avg_l.volume) ** (1 / 3)
             inv_abc = np.array(avg_l.reciprocal_lattice.abc)
@@ -784,13 +770,9 @@ class StructureMatcher(MSONable):
                 t = s1fc[s1i] - s2fc[s2_t_ind]
                 t_s2fc = s2fc + t
                 if self._cmp_fstruct(s1fc, t_s2fc, frac_tol, mask):
-                    inv_lll_abc = np.array(
-                        avg_l.get_lll_reduced_lattice().reciprocal_lattice.abc
-                    )
+                    inv_lll_abc = np.array(avg_l.get_lll_reduced_lattice().reciprocal_lattice.abc)
                     lll_frac_tol = inv_lll_abc * self.stol / (np.pi * normalization)
-                    dist, t_adj, mapping = self._cart_dists(
-                        s1fc, t_s2fc, avg_l, mask, normalization, lll_frac_tol
-                    )
+                    dist, t_adj, mapping = self._cart_dists(s1fc, t_s2fc, avg_l, mask, normalization, lll_frac_tol)
                     if use_rms:
                         val = np.linalg.norm(dist) / len(dist) ** 0.5
                     else:
@@ -861,9 +843,7 @@ class StructureMatcher(MSONable):
                     )
                 inds = list(inds)
                 matches.extend([unmatched[i][0] for i in inds])
-                unmatched = [
-                    unmatched[i] for i in range(len(unmatched)) if i not in inds
-                ]
+                unmatched = [unmatched[i] for i in range(len(unmatched)) if i not in inds]
                 all_groups.append([original_s_list[i] for i in matches])
 
         return all_groups
@@ -944,10 +924,7 @@ class StructureMatcher(MSONable):
 
             # do quick check that compositions are compatible
             mapped_comp = Composition({sp_mapping[k]: v for k, v in s1_comp.items()})
-            if (not self._subset) and (
-                self._comparator.get_hash(mapped_comp)
-                != self._comparator.get_hash(s2_comp)
-            ):
+            if (not self._subset) and (self._comparator.get_hash(mapped_comp) != self._comparator.get_hash(s2_comp)):
                 continue
 
             mapped_struct = struct1.copy()
@@ -962,9 +939,7 @@ class StructureMatcher(MSONable):
                     break_on_match,
                 )
             else:
-                m = self._strict_match(
-                    mapped_struct, struct2, fu, s1_supercell, use_rms, break_on_match
-                )
+                m = self._strict_match(mapped_struct, struct2, fu, s1_supercell, use_rms, break_on_match)
             if m:
                 matches.append((sp_mapping, m))
                 if single_match:
@@ -991,9 +966,7 @@ class StructureMatcher(MSONable):
         struct1, struct2 = self._process_species([struct1, struct2])
         struct1, struct2, fu, s1_supercell = self._preprocess(struct1, struct2)
 
-        matches = self._anonymous_match(
-            struct1, struct2, fu, s1_supercell, use_rms=True, break_on_match=False
-        )
+        matches = self._anonymous_match(struct1, struct2, fu, s1_supercell, use_rms=True, break_on_match=False)
         if matches:
             best = sorted(matches, key=lambda x: x[1][0])[0]
             return best[1][0], best[0]
@@ -1018,9 +991,7 @@ class StructureMatcher(MSONable):
         struct1, struct2 = self._process_species([struct1, struct2])
         struct1, struct2, fu, s1_supercell = self._preprocess(struct1, struct2)
 
-        matches = self._anonymous_match(
-            struct1, struct2, fu, s1_supercell, use_rms=True, break_on_match=True
-        )
+        matches = self._anonymous_match(struct1, struct2, fu, s1_supercell, use_rms=True, break_on_match=True)
 
         if matches:
             min_X_diff = np.inf
@@ -1035,9 +1006,7 @@ class StructureMatcher(MSONable):
 
         return None
 
-    def get_all_anonymous_mappings(
-        self, struct1, struct2, niggli=True, include_dist=False
-    ):
+    def get_all_anonymous_mappings(self, struct1, struct2, niggli=True, include_dist=False):
         """
         Performs an anonymous fitting, which allows distinct species in one
         structure to map to another. Returns a dictionary of species
@@ -1055,9 +1024,7 @@ class StructureMatcher(MSONable):
         struct1, struct2 = self._process_species([struct1, struct2])
         struct1, struct2, fu, s1_supercell = self._preprocess(struct1, struct2, niggli)
 
-        matches = self._anonymous_match(
-            struct1, struct2, fu, s1_supercell, break_on_match=not include_dist
-        )
+        matches = self._anonymous_match(struct1, struct2, fu, s1_supercell, break_on_match=not include_dist)
         if matches:
             if include_dist:
                 return [(m[0], m[1][0]) for m in matches]
@@ -1082,9 +1049,7 @@ class StructureMatcher(MSONable):
         struct1, struct2 = self._process_species([struct1, struct2])
         struct1, struct2, fu, s1_supercell = self._preprocess(struct1, struct2, niggli)
 
-        matches = self._anonymous_match(
-            struct1, struct2, fu, s1_supercell, break_on_match=True, single_match=True
-        )
+        matches = self._anonymous_match(struct1, struct2, fu, s1_supercell, break_on_match=True, single_match=True)
 
         return bool(matches)
 
@@ -1095,20 +1060,15 @@ class StructureMatcher(MSONable):
         is impossible to find
         """
         if self._primitive_cell:
-            raise ValueError(
-                "get_supercell_matrix cannot be used with the " "primitive cell option"
-            )
+            raise ValueError("get_supercell_matrix cannot be used with the " "primitive cell option")
         struct, supercell, fu, s1_supercell = self._preprocess(struct, supercell, False)
 
         if not s1_supercell:
             raise ValueError(
-                "The non-supercell must be put onto the basis"
-                " of the supercell, not the other way around"
+                "The non-supercell must be put onto the basis" " of the supercell, not the other way around"
             )
 
-        match = self._match(
-            struct, supercell, fu, s1_supercell, use_rms=True, break_on_match=False
-        )
+        match = self._match(struct, supercell, fu, s1_supercell, use_rms=True, break_on_match=False)
 
         if match is None:
             return None
@@ -1134,36 +1094,25 @@ class StructureMatcher(MSONable):
                 the remaining site indices of struct2.
         """
         if self._primitive_cell:
-            raise ValueError(
-                "get_transformation cannot be used with the " "primitive cell option"
-            )
+            raise ValueError("get_transformation cannot be used with the " "primitive cell option")
 
         struct1, struct2 = self._process_species((struct1, struct2))
 
         s1, s2, fu, s1_supercell = self._preprocess(struct1, struct2, False)
         ratio = fu if s1_supercell else 1 / fu
         if s1_supercell and fu > 1:
-            raise ValueError(
-                "Struct1 must be the supercell, " "not the other way around"
-            )
+            raise ValueError("Struct1 must be the supercell, " "not the other way around")
 
         if len(s1) * ratio >= len(s2):
             # s1 is superset
-            match = self._strict_match(
-                s1, s2, fu=fu, s1_supercell=False, use_rms=True, break_on_match=False
-            )
+            match = self._strict_match(s1, s2, fu=fu, s1_supercell=False, use_rms=True, break_on_match=False)
             if match is None:
                 return None
             # invert the mapping, since it needs to be from s1 to s2
-            mapping = [
-                list(match[4]).index(i) if i in match[4] else None
-                for i in range(len(s1))
-            ]
+            mapping = [list(match[4]).index(i) if i in match[4] else None for i in range(len(s1))]
             return match[2], match[3], mapping
         # s2 is superset
-        match = self._strict_match(
-            s2, s1, fu=fu, s1_supercell=True, use_rms=True, break_on_match=False
-        )
+        match = self._strict_match(s2, s1, fu=fu, s1_supercell=True, use_rms=True, break_on_match=False)
         if match is None:
             return None
         # add sites not included in the mapping
@@ -1255,9 +1204,7 @@ class PointDefectComparator(MSONable):
     this comparator will break.
     """
 
-    def __init__(
-        self, check_charge=False, check_primitive_cell=False, check_lattice_scale=False
-    ):
+    def __init__(self, check_charge=False, check_primitive_cell=False, check_lattice_scale=False):
         """
         Args:
             check_charge (bool): Gives option to check
@@ -1287,12 +1234,8 @@ class PointDefectComparator(MSONable):
         """
         possible_defect_types = (Defect, Vacancy, Substitution, Interstitial)
 
-        if not isinstance(d1, possible_defect_types) or not isinstance(
-            d2, possible_defect_types
-        ):
-            raise ValueError(
-                "Cannot use PointDefectComparator to" " compare non-defect objects..."
-            )
+        if not isinstance(d1, possible_defect_types) or not isinstance(d2, possible_defect_types):
+            raise ValueError("Cannot use PointDefectComparator to" " compare non-defect objects...")
 
         if not isinstance(d1, d2.__class__):
             return False
@@ -1315,9 +1258,7 @@ class PointDefectComparator(MSONable):
         if self.check_primitive_cell or self.check_lattice_scale:
             # if allowing for base structure volume or supercell modifications,
             # then need to preprocess defect objects to allow for matching
-            d1_mod_bulk_structure, d2_mod_bulk_structure, _, _ = sm._preprocess(
-                d1.bulk_structure, d2.bulk_structure
-            )
+            d1_mod_bulk_structure, d2_mod_bulk_structure, _, _ = sm._preprocess(d1.bulk_structure, d2.bulk_structure)
             d1_defect_site = PeriodicSite(
                 d1.site.specie,
                 d1.site.coords,
