@@ -17,7 +17,10 @@ __date__ = "Jan 13, 2012"
 __status__ = "Beta"
 
 import itertools
+from dataclasses import dataclass
+from typing import Iterable, Dict
 
+from monty.dev import deprecated
 from scipy.constants import N_A
 
 from pymatgen.analysis.phase_diagram import PDEntry, PhaseDiagram
@@ -25,8 +28,10 @@ from pymatgen.apps.battery.battery_abc import AbstractElectrode, AbstractVoltage
 from pymatgen.core.composition import Composition
 from pymatgen.core.periodic_table import Element
 from pymatgen.core.units import Charge, Time
+from pymatgen.entries.computed_entries import ComputedEntry
 
 
+@dataclass
 class InsertionElectrode(AbstractElectrode):
     """
     A set of topotactically related compounds, with different amounts of a
@@ -34,7 +39,11 @@ class InsertionElectrode(AbstractElectrode):
     insertion battery electrode.
     """
 
-    def __init__(self, entries, working_ion_entry):
+    _stable_entries: Iterable[ComputedEntry]
+    _unstable_entries: Iterable[ComputedEntry]
+
+    @classmethod
+    def from_entries(cls, entries, working_ion_entry, strip_structures=False):
         """
         Create a new InsertionElectrode.
 
@@ -45,10 +54,23 @@ class InsertionElectrode(AbstractElectrode):
             working_ion_entry: A single ComputedEntry or PDEntry
                 representing the element that carries charge across the
                 battery, e.g. Li.
+            strip_structures: Since the electrode document only uses volume we can make the
+                electrode object significantly leaner by dropping the structure data.
+                If this parameter is set to True, the ComputedStructureEntry will be replaced
+                with ComputedEntry and the volume will be stored in ComputedEntry.data['volume']
         """
-        self._entries = entries
-        self._working_ion = working_ion_entry.composition.elements[0]
-        self._working_ion_entry = working_ion_entry
+
+        if strip_structures:
+            ents = []
+            for ient in entries:
+                dd = ient.as_dict()
+                ent = ComputedEntry.from_dict(dd)
+                ent.data["volume"] = ient.structure.volume
+                ents.append(ent)
+            entries = ents
+
+        _working_ion = working_ion_entry.composition.elements[0]
+        _working_ion_entry = working_ion_entry
 
         # Prepare to make phase diagram: determine elements and set their energy
         # to be very high
@@ -61,58 +83,39 @@ class InsertionElectrode(AbstractElectrode):
 
         pdentries = []
         pdentries.extend(entries)
-        pdentries.extend(
-            [PDEntry(Composition({el: 1}), element_energy) for el in elements]
-        )
+        pdentries.extend([PDEntry(Composition({el: 1}), element_energy) for el in elements])
 
         # Make phase diagram to determine which entries are stable vs. unstable
         pd = PhaseDiagram(pdentries)
 
         def lifrac(e):
-            return e.composition.get_atomic_fraction(self._working_ion)
+            return e.composition.get_atomic_fraction(_working_ion)
 
         # stable entries ordered by amount of Li asc
-        self._stable_entries = tuple(
-            sorted([e for e in pd.stable_entries if e in entries], key=lifrac)
-        )
+        _stable_entries = tuple(sorted([e for e in pd.stable_entries if e in entries], key=lifrac))
 
         # unstable entries ordered by amount of Li asc
-        self._unstable_entries = tuple(
-            sorted([e for e in pd.unstable_entries if e in entries], key=lifrac)
-        )
+        _unstable_entries = tuple(sorted([e for e in pd.unstable_entries if e in entries], key=lifrac))
 
         # create voltage pairs
-        self._vpairs = tuple(
+        _vpairs = tuple(
             [
-                InsertionVoltagePair(
-                    self._stable_entries[i],
-                    self._stable_entries[i + 1],
+                InsertionVoltagePair.from_entries(
+                    _stable_entries[i],
+                    _stable_entries[i + 1],
                     working_ion_entry,
                 )
-                for i in range(len(self._stable_entries) - 1)
+                for i in range(len(_stable_entries) - 1)
             ]
         )
-
-    @property
-    def working_ion(self):
-        """
-        The working ion as an Element object
-        """
-        return self._working_ion
-
-    @property
-    def working_ion_entry(self):
-        """
-        Returns: Working ion entry
-        """
-        return self._working_ion_entry
-
-    @property
-    def voltage_pairs(self):
-        """
-        Returns: All InsertionVoltagePairs in electrode.
-        """
-        return self._vpairs
+        framework = _vpairs[0].framework
+        return cls(
+            voltage_pairs=_vpairs,
+            working_ion_entry=_working_ion_entry,
+            _stable_entries=_stable_entries,
+            _unstable_entries=_unstable_entries,
+            _framework_formula=framework.reduced_formula,
+        )
 
     def get_stable_entries(self, charge_to_discharge=True):
         """
@@ -284,18 +287,14 @@ class InsertionElectrode(AbstractElectrode):
         """
         battery_list = []
         pair_it = (
-            self._vpairs
-            if adjacent_only
-            else itertools.combinations_with_replacement(self._vpairs, 2)
+            self.voltage_pairs if adjacent_only else itertools.combinations_with_replacement(self.voltage_pairs, 2)
         )
 
-        ion = self._working_ion
+        ion = self.working_ion
 
         for pair in pair_it:
             entry_charge = pair.entry_charge if adjacent_only else pair[0].entry_charge
-            entry_discharge = (
-                pair.entry_discharge if adjacent_only else pair[1].entry_discharge
-            )
+            entry_discharge = pair.entry_discharge if adjacent_only else pair[1].entry_discharge
 
             chg_frac = entry_charge.composition.get_atomic_fraction(ion)
             dischg_frac = entry_discharge.composition.get_atomic_fraction(ion)
@@ -313,9 +312,62 @@ class InsertionElectrode(AbstractElectrode):
                 stable_entries = filter(in_range, self.get_stable_entries())
                 all_entries = list(stable_entries)
                 all_entries.extend(unstable_entries)
-                battery_list.append(self.__class__(all_entries, self.working_ion_entry))
+                battery_list.append(self.__class__.from_entries(all_entries, self.working_ion_entry))
         return battery_list
 
+    def get_summary_dict(self, print_subelectrodes=True) -> Dict:
+        """
+        Generate a summary dict.
+        Populates the summary dict with the basic information from the parent method then populates more information.
+        Since the parent method calls self.get_summary_dict(print_subelectrodes=True) for the subelectrodes.
+        The current methode will be called from within super().get_summary_dict.
+
+        Args:
+            print_subelectrodes: Also print data on all the possible
+                subelectrodes.
+
+        Returns:
+            A summary of this electrode"s properties in dict format.
+        """
+
+        d = super().get_summary_dict(print_subelectrodes=print_subelectrodes)
+
+        chg_comp = self.fully_charged_entry.composition
+        dischg_comp = self.fully_discharged_entry.composition
+
+        d.update(
+            {
+                "id_charge": self.fully_charged_entry.entry_id,
+                "formula_charge": chg_comp.reduced_formula,
+                "id_discharge": self.fully_discharged_entry.entry_id,
+                "formula_discharge": dischg_comp.reduced_formula,
+                "max_instability": self.get_max_instability(),
+                "min_instability": self.get_min_instability(),
+                "material_ids": [itr_ent.entry_id for itr_ent in self.get_all_entries()],
+                "stable_material_ids": [itr_ent.entry_id for itr_ent in self.get_stable_entries()],
+                "unstable_material_ids": [itr_ent.entry_id for itr_ent in self.get_unstable_entries()],
+            }
+        )
+        if all(["decomposition_energy" in itr_ent.data for itr_ent in self.get_all_entries()]):
+            d.update(
+                {
+                    "stability_charge": self.fully_charged_entry.data["decomposition_energy"],
+                    "stability_discharge": self.fully_discharged_entry.data["decomposition_energy"],
+                    "stability_data": {
+                        itr_ent.entry_id: itr_ent.data["decomposition_energy"] for itr_ent in self.get_all_entries()
+                    },
+                }
+            )
+
+        if all(["muO2" in itr_ent.data for itr_ent in self.get_all_entries()]):
+            d.update({"muO2_data": {itr_ent.entry_id: itr_ent.data["muO2"] for itr_ent in self.get_all_entries()}})
+
+        return d
+
+    @deprecated(
+        replacement=get_summary_dict,
+        message="Name and logic changed, as_dict_summary will be removed in a future release.",
+    )
     def as_dict_summary(self, print_subelectrodes=True):
         """
         Generate a summary dict.
@@ -341,9 +393,9 @@ class InsertionElectrode(AbstractElectrode):
             "capacity_vol": self.get_capacity_vol(),
             "energy_grav": self.get_specific_energy(),
             "energy_vol": self.get_energy_density(),
-            "working_ion": self._working_ion.symbol,
+            "working_ion": self.working_ion.symbol,
             "nsteps": self.num_steps,
-            "framework": self._vpairs[0].framework.to_data_dict,
+            "framework": self.voltage_pairs[0].framework.to_data_dict,
             "formula_charge": chg_comp.reduced_formula,
             "id_charge": self.fully_charged_entry.entry_id,
             "formula_discharge": dischg_comp.reduced_formula,
@@ -352,52 +404,32 @@ class InsertionElectrode(AbstractElectrode):
             "fracA_discharge": dischg_comp.get_atomic_fraction(ion),
             "max_instability": self.get_max_instability(),
             "min_instability": self.get_min_instability(),
-            "material_ids": [itr_ent.entry_id for itr_ent in self._entries],
-            "stable_material_ids": [
-                itr_ent.entry_id for itr_ent in self.get_stable_entries()
-            ],
-            "unstable_material_ids": [
-                itr_ent.entry_id for itr_ent in self.get_unstable_entries()
-            ],
+            "material_ids": [itr_ent.entry_id for itr_ent in self.get_all_entries()],
+            "stable_material_ids": [itr_ent.entry_id for itr_ent in self.get_stable_entries()],
+            "unstable_material_ids": [itr_ent.entry_id for itr_ent in self.get_unstable_entries()],
         }
 
-        if all(["decomposition_energy" in itr_ent.data for itr_ent in self._entries]):
+        if all(["decomposition_energy" in itr_ent.data for itr_ent in self.get_all_entries()]):
             d.update(
                 {
-                    "stability_charge": self.fully_charged_entry.data[
-                        "decomposition_energy"
-                    ],
-                    "stability_discharge": self.fully_discharged_entry.data[
-                        "decomposition_energy"
-                    ],
+                    "stability_charge": self.fully_charged_entry.data["decomposition_energy"],
+                    "stability_discharge": self.fully_discharged_entry.data["decomposition_energy"],
                     "stability_data": {
-                        itr_ent.entry_id: itr_ent.data["decomposition_energy"]
-                        for itr_ent in self._entries
+                        itr_ent.entry_id: itr_ent.data["decomposition_energy"] for itr_ent in self.get_all_entries()
                     },
                 }
             )
 
-        if all(["muO2" in itr_ent.data for itr_ent in self._entries]):
-            d.update(
-                {
-                    "muO2_data": {
-                        itr_ent.entry_id: itr_ent.data["muO2"]
-                        for itr_ent in self._entries
-                    }
-                }
-            )
+        if all(["muO2" in itr_ent.data for itr_ent in self.get_all_entries()]):
+            d.update({"muO2_data": {itr_ent.entry_id: itr_ent.data["muO2"] for itr_ent in self.get_all_entries()}})
 
         if print_subelectrodes:
 
             def f_dict(c):
-                return c.as_dict_summary(print_subelectrodes=False)
+                return c.get_summary_dict(print_subelectrodes=False)
 
-            d["adj_pairs"] = list(
-                map(f_dict, self.get_sub_electrodes(adjacent_only=True))
-            )
-            d["all_pairs"] = list(
-                map(f_dict, self.get_sub_electrodes(adjacent_only=False))
-            )
+            d["adj_pairs"] = list(map(f_dict, self.get_sub_electrodes(adjacent_only=True)))
+            d["all_pairs"] = list(map(f_dict, self.get_sub_electrodes(adjacent_only=False)))
         return d
 
     def __str__(self):
@@ -407,18 +439,14 @@ class InsertionElectrode(AbstractElectrode):
         output = []
         chg_form = self.fully_charged_entry.composition.reduced_formula
         dischg_form = self.fully_discharged_entry.composition.reduced_formula
-        output.append(
-            "InsertionElectrode with endpoints at {} and {}".format(
-                chg_form, dischg_form
-            )
-        )
+        output.append("InsertionElectrode with endpoints at {} and {}".format(chg_form, dischg_form))
         output.append("Avg. volt. = {} V".format(self.get_average_voltage()))
         output.append("Grav. cap. = {} mAh/g".format(self.get_capacity_grav()))
         output.append("Vol. cap. = {}".format(self.get_capacity_vol()))
         return "\n".join(output)
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict_legacy(cls, d):
         """
         Args:
             d (dict): Dict representation
@@ -434,24 +462,29 @@ class InsertionElectrode(AbstractElectrode):
             dec.process_decoded(d["working_ion_entry"]),
         )
 
-    def as_dict(self):
+    def as_dict_legacy(self):
         """
         Returns: MSONAble dict
         """
         return {
             "@module": self.__class__.__module__,
             "@class": self.__class__.__name__,
-            "entries": [entry.as_dict() for entry in self._entries],
+            "entries": [entry.as_dict() for entry in self.get_all_entries()],
             "working_ion_entry": self.working_ion_entry.as_dict(),
         }
 
 
+@dataclass
 class InsertionVoltagePair(AbstractVoltagePair):
     """
     Defines an Insertion Voltage Pair.
     """
 
-    def __init__(self, entry1, entry2, working_ion_entry):
+    entry_charge: ComputedEntry
+    entry_discharge: ComputedEntry
+
+    @classmethod
+    def from_entries(cls, entry1, entry2, working_ion_entry):
         """
         Args:
             entry1: Entry corresponding to one of the entries in the voltage step.
@@ -464,9 +497,9 @@ class InsertionVoltagePair(AbstractVoltagePair):
 
         entry_charge = entry1
         entry_discharge = entry2
-        if entry_charge.composition.get_atomic_fraction(
+        if entry_charge.composition.get_atomic_fraction(working_element) > entry2.composition.get_atomic_fraction(
             working_element
-        ) > entry2.composition.get_atomic_fraction(working_element):
+        ):
             (entry_charge, entry_discharge) = (entry_discharge, entry_charge)
 
         comp_charge = entry_charge.composition
@@ -474,49 +507,30 @@ class InsertionVoltagePair(AbstractVoltagePair):
 
         ion_sym = working_element.symbol
 
-        frame_charge_comp = Composition(
-            {el: comp_charge[el] for el in comp_charge if el.symbol != ion_sym}
-        )
-        frame_discharge_comp = Composition(
-            {el: comp_discharge[el] for el in comp_discharge if el.symbol != ion_sym}
-        )
+        frame_charge_comp = Composition({el: comp_charge[el] for el in comp_charge if el.symbol != ion_sym})
+        frame_discharge_comp = Composition({el: comp_discharge[el] for el in comp_discharge if el.symbol != ion_sym})
 
         # Data validation
 
         # check that the ion is just a single element
         if not working_ion_entry.composition.is_element:
-            raise ValueError(
-                "VoltagePair: The working ion specified must be " "an element"
-            )
+            raise ValueError("VoltagePair: The working ion specified must be " "an element")
 
         # check that at least one of the entries contains the working element
         if (
             not comp_charge.get_atomic_fraction(working_element) > 0
             and not comp_discharge.get_atomic_fraction(working_element) > 0
         ):
-            raise ValueError(
-                "VoltagePair: The working ion must be present in " "one of the entries"
-            )
+            raise ValueError("VoltagePair: The working ion must be present in " "one of the entries")
 
         # check that the entries do not contain the same amount of the workin
         # element
-        if comp_charge.get_atomic_fraction(
-            working_element
-        ) == comp_discharge.get_atomic_fraction(working_element):
-            raise ValueError(
-                "VoltagePair: The working ion atomic percentage "
-                "cannot be the same in both the entries"
-            )
+        if comp_charge.get_atomic_fraction(working_element) == comp_discharge.get_atomic_fraction(working_element):
+            raise ValueError("VoltagePair: The working ion atomic percentage " "cannot be the same in both the entries")
 
         # check that the frameworks of the entries are equivalent
-        if (
-            not frame_charge_comp.reduced_formula
-            == frame_discharge_comp.reduced_formula
-        ):
-            raise ValueError(
-                "VoltagePair: the specified entries must have the"
-                " same compositional framework"
-            )
+        if not frame_charge_comp.reduced_formula == frame_discharge_comp.reduced_formula:
+            raise ValueError("VoltagePair: the specified entries must have the" " same compositional framework")
 
         # Initialize normalization factors, charged and discharged entries
 
@@ -524,143 +538,72 @@ class InsertionVoltagePair(AbstractVoltagePair):
         working_ion_valence = abs(max(valence_list))
 
         (
-            self.framework,
+            framework,
             norm_charge,
         ) = frame_charge_comp.get_reduced_composition_and_factor()
         norm_discharge = frame_discharge_comp.get_reduced_composition_and_factor()[1]
 
-        self._working_ion_entry = working_ion_entry
-
         # Initialize normalized properties
-        self._vol_charge = entry_charge.structure.volume / norm_charge
-        self._vol_discharge = entry_discharge.structure.volume / norm_discharge
+        if hasattr(entry_charge, "structure"):
+            _vol_charge = entry_charge.structure.volume / norm_charge
+        else:
+            _vol_charge = entry_charge.data.get("volume")
+
+        if hasattr(entry_discharge, "structure"):
+            _vol_discharge = entry_discharge.structure.volume / norm_discharge
+        else:
+            _vol_discharge = entry_discharge.data.get("volume")
 
         comp_charge = entry_charge.composition
         comp_discharge = entry_discharge.composition
 
-        self._mass_charge = comp_charge.weight / norm_charge
-        self._mass_discharge = comp_discharge.weight / norm_discharge
+        _mass_charge = comp_charge.weight / norm_charge
+        _mass_discharge = comp_discharge.weight / norm_discharge
 
-        self._num_ions_transferred = (
-            comp_discharge[working_element] / norm_discharge
-        ) - (comp_charge[working_element] / norm_charge)
+        _num_ions_transferred = (comp_discharge[working_element] / norm_discharge) - (
+            comp_charge[working_element] / norm_charge
+        )
 
-        self._voltage = (
-            (
-                (entry_charge.energy / norm_charge)
-                - (entry_discharge.energy / norm_discharge)
-            )
-            / self._num_ions_transferred
+        _voltage = (
+            ((entry_charge.energy / norm_charge) - (entry_discharge.energy / norm_discharge)) / _num_ions_transferred
             + working_ion_entry.energy_per_atom
         ) / working_ion_valence
-        self._mAh = (
-            self._num_ions_transferred
-            * Charge(1, "e").to("C")
-            * Time(1, "s").to("h")
-            * N_A
-            * 1000
-            * working_ion_valence
+        _mAh = _num_ions_transferred * Charge(1, "e").to("C") * Time(1, "s").to("h") * N_A * 1000 * working_ion_valence
+
+        _frac_charge = comp_charge.get_atomic_fraction(working_element)
+        _frac_discharge = comp_discharge.get_atomic_fraction(working_element)
+
+        vpair = cls(
+            voltage=_voltage,
+            mAh=_mAh,
+            mass_charge=_mass_charge,
+            mass_discharge=_mass_discharge,
+            vol_charge=_vol_charge,
+            vol_discharge=_vol_discharge,
+            frac_charge=_frac_charge,
+            frac_discharge=_frac_discharge,
+            working_ion_entry=working_ion_entry,
+            entry_charge=entry_charge,
+            entry_discharge=entry_discharge,
+            _framework_formula=framework.reduced_formula,
         )
 
         # Step 4: add (optional) hull and muO2 data
-        self.decomp_e_charge = entry_charge.data.get("decomposition_energy", None)
-        self.decomp_e_discharge = entry_discharge.data.get("decomposition_energy", None)
+        vpair.decomp_e_charge = entry_charge.data.get("decomposition_energy", None)
+        vpair.decomp_e_discharge = entry_discharge.data.get("decomposition_energy", None)
 
-        self.muO2_charge = entry_charge.data.get("muO2", None)
-        self.muO2_discharge = entry_discharge.data.get("muO2", None)
+        vpair.muO2_charge = entry_charge.data.get("muO2", None)
+        vpair.muO2_discharge = entry_discharge.data.get("muO2", None)
 
-        self.entry_charge = entry_charge
-        self.entry_discharge = entry_discharge
-        self.normalization_charge = norm_charge
-        self.normalization_discharge = norm_discharge
-        self._frac_charge = comp_charge.get_atomic_fraction(working_element)
-        self._frac_discharge = comp_discharge.get_atomic_fraction(working_element)
-
-    @property
-    def working_ion(self):
-        """
-        Returns: working ion
-        """
-        return self._working_ion_entry.composition.elements[0]
-
-    @property
-    def frac_charge(self):
-        """
-        Returns: Amount of working ion at charge
-        """
-        return self._frac_charge
-
-    @property
-    def frac_discharge(self):
-        """
-        Returns: Amount of working ion at discharge
-        """
-        return self._frac_discharge
-
-    @property
-    def voltage(self):
-        """
-        Returns: Voltage of electrode
-        """
-        return self._voltage
-
-    @property
-    def mAh(self):
-        """
-        Returns: Energy in mAh.
-        """
-        return self._mAh
-
-    @property
-    def mass_charge(self):
-        """
-        Returns: Mass of charged electrode.
-        """
-        return self._mass_charge
-
-    @property
-    def mass_discharge(self):
-        """
-        Returns: Mass of discharged electrode.
-        """
-        return self._mass_discharge
-
-    @property
-    def vol_charge(self):
-        """
-        Returns: Volume of charged electrode.
-        """
-        return self._vol_charge
-
-    @property
-    def vol_discharge(self):
-        """
-        Returns: Volume of discharged electrode.
-        """
-        return self._vol_discharge
-
-    @property
-    def working_ion_entry(self):
-        """
-        Returns: Working ion entry
-        """
-        return self._working_ion_entry
+        return vpair
 
     def __repr__(self):
         output = [
-            "Insertion voltage pair with working ion {}".format(
-                self._working_ion_entry.composition.reduced_formula
-            ),
+            "Insertion voltage pair with working ion {}".format(self.working_ion_entry.composition.reduced_formula),
             "V = {}, mAh = {}".format(self.voltage, self.mAh),
-            "mass_charge = {}, mass_discharge = {}".format(
-                self.mass_charge, self.mass_discharge
-            ),
-            "vol_charge = {}, vol_discharge = {}".format(
-                self.vol_charge, self.vol_discharge
-            ),
-            "frac_charge = {}, frac_discharge = {}".format(
-                self.frac_charge, self.frac_discharge
-            ),
+            "mass_charge = {}, mass_discharge = {}".format(self.mass_charge, self.mass_discharge),
+            "vol_charge = {}, vol_discharge = {}".format(self.vol_charge, self.vol_discharge),
+            "frac_charge = {}, frac_discharge = {}".format(self.frac_charge, self.frac_discharge),
         ]
         return "\n".join(output)
 
