@@ -14,7 +14,7 @@ import re
 import string
 from functools import total_ordering
 from itertools import combinations_with_replacement, product
-from typing import List, Tuple
+from typing import List, Tuple, Union, Dict
 
 from monty.fractions import gcd, gcd_float
 from monty.json import MSONable
@@ -22,7 +22,11 @@ from monty.serialization import loadfn
 
 from pymatgen.core.periodic_table import DummySpecies, Element, Species, get_el_sp
 from pymatgen.core.units import Mass
-from pymatgen.util.string import formula_double_format
+from pymatgen.util.string import formula_double_format, Stringify
+
+
+SpeciesLike = Union[str, Element, Species, DummySpecies]
+
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
@@ -34,7 +38,7 @@ __date__ = "Nov 10, 2012"
 
 
 @total_ordering
-class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
+class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, Stringify):
     """
     Represents a Composition, which is essentially a {element:amount} mapping
     type. Composition is written to be immutable and hashable,
@@ -96,7 +100,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
 
     oxi_prob = None  # prior probability of oxidation used by oxi_state_guesses
 
-    def __init__(self, *args, strict=False, **kwargs):  # allow_negative=False
+    def __init__(self, *args, strict: bool = False, **kwargs):
         r"""
         Very flexible Composition construction, similar to the built-in Python
         dict(). Also extended to allow simple string init.
@@ -130,31 +134,26 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         elif len(args) == 1 and isinstance(args[0], str):
             elmap = self._parse_formula(args[0])
         else:
-            elmap = dict(*args, **kwargs)
+            elmap = dict(*args, **kwargs)  # type: ignore
         elamt = {}
         self._natoms = 0
         for k, v in elmap.items():
             if v < -Composition.amount_tolerance and not self.allow_negative:
-                raise CompositionError("Amounts in Composition cannot be " "negative!")
+                raise ValueError("Amounts in Composition cannot be " "negative!")
             if abs(v) >= Composition.amount_tolerance:
                 elamt[get_el_sp(k)] = v
                 self._natoms += abs(v)
         self._data = elamt
         if strict and not self.valid:
-            raise ValueError(
-                "Composition is not valid, contains: {}".format(
-                    ", ".join(map(str, self.elements))
-                )
-            )
+            raise ValueError("Composition is not valid, contains: {}".format(", ".join(map(str, self.elements))))
 
-    def __getitem__(self, item):
+    def __getitem__(self, item: SpeciesLike):
         try:
             sp = get_el_sp(item)
             return self._data.get(sp, 0)
         except ValueError as ex:
             raise TypeError(
-                "Invalid key {}, {} for Composition\n"
-                "ValueError exception:\n{}".format(item, type(item), ex)
+                "Invalid key {}, {} for Composition\n" "ValueError exception:\n{}".format(item, type(item), ex)
             )
 
     def __len__(self):
@@ -169,8 +168,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
             return sp in self._data
         except ValueError as ex:
             raise TypeError(
-                "Invalid key {}, {} for Composition\n"
-                "ValueError exception:\n{}".format(item, type(item), ex)
+                "Invalid key {}, {} for Composition\n" "ValueError exception:\n{}".format(item, type(item), ex)
             )
 
     def __eq__(self, other):
@@ -216,7 +214,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         composition gives an FeO2 composition.
 
         Raises:
-            CompositionError if the subtracted composition is greater than the
+            ValueError if the subtracted composition is greater than the
             original composition in any of its elements, unless allow_negative
             is True
         """
@@ -233,18 +231,14 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         """
         if not isinstance(other, numbers.Number):
             return NotImplemented
-        return Composition(
-            {el: self[el] * other for el in self}, allow_negative=self.allow_negative
-        )
+        return Composition({el: self[el] * other for el in self}, allow_negative=self.allow_negative)
 
     __rmul__ = __mul__
 
     def __truediv__(self, other):
         if not isinstance(other, numbers.Number):
             return NotImplemented
-        return Composition(
-            {el: self[el] / other for el in self}, allow_negative=self.allow_negative
-        )
+        return Composition({el: self[el] / other for el in self}, allow_negative=self.allow_negative)
 
     __div__ = __truediv__
 
@@ -273,7 +267,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         """
         return sum((el.Z * abs(amt) for el, amt in self.items()))
 
-    def almost_equals(self, other, rtol=0.1, atol=1e-8):
+    def almost_equals(self, other: "Composition", rtol: float = 0.1, atol: float = 1e-8) -> bool:
         """
         Returns true if compositions are equal within a tolerance.
 
@@ -298,7 +292,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         """
         return len(self) == 1
 
-    def copy(self):
+    def copy(self) -> "Composition":
         """
         :return: A copy of the composition.
         """
@@ -381,7 +375,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         factor = self.get_reduced_formula_and_factor()[1]
         return self / factor, factor
 
-    def get_reduced_formula_and_factor(self, iupac_ordering=False) -> Tuple[str, float]:
+    def get_reduced_formula_and_factor(self, iupac_ordering: bool = False) -> Tuple[str, float]:
         """
         Calculates a reduced formula and factor.
 
@@ -399,9 +393,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
             A pretty normalized formula and a multiplicative factor, i.e.,
             Li4Fe4P4O16 returns (LiFePO4, 4).
         """
-        all_int = all(
-            abs(x - round(x)) < Composition.amount_tolerance for x in self.values()
-        )
+        all_int = all(abs(x - round(x)) < Composition.amount_tolerance for x in self.values())
         if not all_int:
             return self.formula.replace(" ", ""), 1
         d = {k: int(round(v)) for k, v in self.get_el_amt_dict().items()}
@@ -414,8 +406,8 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         return formula, factor
 
     def get_integer_formula_and_factor(
-        self, max_denominator=10000, iupac_ordering=False
-    ):
+        self, max_denominator: int = 10000, iupac_ordering: bool = False
+    ) -> Tuple[str, float]:
         """
         Calculates an integer formula and factor.
 
@@ -470,14 +462,11 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         if "C" in elements:
             elements = ["C"] + [el for el in elements if el != "C"]
 
-        formula = [
-            "%s%s" % (el, formula_double_format(c[el]) if c[el] != 1 else "")
-            for el in elements
-        ]
+        formula = ["%s%s" % (el, formula_double_format(c[el]) if c[el] != 1 else "") for el in elements]
         return " ".join(formula)
 
     @property
-    def elements(self) -> List[Element]:
+    def elements(self) -> List[Union[Element, Species, DummySpecies]]:
         """
         Returns view of elements in Composition.
         """
@@ -485,14 +474,17 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
 
     def __str__(self):
         return " ".join(
-            [
-                "{}{}".format(k, formula_double_format(v, ignore_ones=False))
-                for k, v in self.as_dict().items()
-            ]
+            ["{}{}".format(k, formula_double_format(v, ignore_ones=False)) for k, v in self.as_dict().items()]
         )
 
+    def to_pretty_string(self) -> str:
+        """
+        :return: Same as __str__ but without spaces.
+        """
+        return re.sub(r"\s+", "", self.__str__())
+
     @property
-    def num_atoms(self):
+    def num_atoms(self) -> float:
         """
         Total number of atoms in Composition. For negative amounts, sum
         of absolute values
@@ -500,15 +492,13 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         return self._natoms
 
     @property
-    def weight(self):
+    def weight(self) -> float:
         """
         Total molecular weight of Composition
         """
-        return Mass(
-            sum([amount * el.atomic_mass for el, amount in self.items()]), "amu"
-        )
+        return Mass(sum([amount * el.atomic_mass for el, amount in self.items()]), "amu")
 
-    def get_atomic_fraction(self, el):
+    def get_atomic_fraction(self, el: SpeciesLike) -> float:
         """
         Calculate atomic fraction of an Element or Species.
 
@@ -520,7 +510,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         """
         return abs(self[el]) / self._natoms
 
-    def get_wt_fraction(self, el):
+    def get_wt_fraction(self, el: SpeciesLike):
         """
         Calculate weight fraction of an Element or Species.
 
@@ -532,7 +522,10 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         """
         return get_el_sp(el).atomic_mass * abs(self[el]) / self.weight
 
-    def contains_element_type(self, category):
+    def contains_element_type(
+        self,
+        category: str,
+    ):
         """
         Check if Composition contains any elements matching a given category.
 
@@ -542,7 +535,6 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
             "alkali", "alkaline", "halogen", "chalcogen", "lanthanoid",
             "actinoid", "quadrupolar", "s-block", "p-block", "d-block", "f-block"
 
-
         Returns:
             True if any elements in Composition match category, otherwise False
         """
@@ -568,9 +560,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         )
 
         if category not in allowed_categories:
-            raise ValueError(
-                "Please pick a category from: {}".format(", ".join(allowed_categories))
-            )
+            raise ValueError("Please pick a category from: {}".format(", ".join(allowed_categories)))
 
         if "block" in category:
             return any([category[0] in el.block for el in self.elements])
@@ -601,7 +591,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
                 sym_dict[el] += amt * factor
                 f = f.replace(m.group(), "", 1)
             if f.strip():
-                raise CompositionError("{} is an invalid formula!".format(f))
+                raise ValueError("{} is an invalid formula!".format(f))
             return sym_dict
 
         m = re.search(r"\(([^\(\)]+)\)\s*([\.e\d]*)", formula)
@@ -610,15 +600,13 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
             if m.group(2) != "":
                 factor = float(m.group(2))
             unit_sym_dict = get_sym_dict(m.group(1), factor)
-            expanded_sym = "".join(
-                ["{}{}".format(el, amt) for el, amt in unit_sym_dict.items()]
-            )
+            expanded_sym = "".join(["{}{}".format(el, amt) for el, amt in unit_sym_dict.items()])
             expanded_formula = formula.replace(m.group(), expanded_sym)
             return self._parse_formula(expanded_formula)
         return get_sym_dict(formula, 1)
 
     @property
-    def anonymized_formula(self):
+    def anonymized_formula(self) -> str:
         """
         An anonymized formula. Unique species are arranged in ordering of
         increasing amounts and assigned ascending alphabets. Useful for
@@ -651,7 +639,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         return "-".join(sorted([str(el) for el in self.elements]))
 
     @property
-    def valid(self):
+    def valid(self) -> bool:
         """
         Returns True if Composition contains valid elements or species and
         False if the Composition contains any dummy species.
@@ -662,7 +650,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         return "Comp: " + self.formula
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, d) -> "Composition":
         """
         Creates a composition from a dict generated by as_dict(). Strictly not
         necessary given that the standard constructor already takes in such an
@@ -675,24 +663,24 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         """
         return cls(d)
 
-    def get_el_amt_dict(self):
+    def get_el_amt_dict(self) -> Dict[str, float]:
         """
         Returns:
             Dict with element symbol and (unreduced) amount e.g.,
             {"Fe": 4.0, "O":6.0} or {"Fe3+": 4.0, "O2-":6.0}
         """
-        d = collections.defaultdict(float)
+        d: Dict[str, float] = collections.defaultdict(float)
         for e, a in self.items():
             d[e.symbol] += a
         return d
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """
         Returns:
             dict with species symbol and (unreduced) amount e.g.,
             {"Fe": 4.0, "O":6.0} or {"Fe3+": 4.0, "O2-":6.0}
         """
-        d = collections.defaultdict(float)
+        d: Dict[str, float] = collections.defaultdict(float)
         for e, a in self.items():
             d[str(e)] += a
         return d
@@ -707,7 +695,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         return self.get_reduced_composition_and_factor()[0].as_dict()
 
     @property
-    def to_data_dict(self):
+    def to_data_dict(self) -> dict:
         """
         Returns:
             A dict with many keys and values relating to Composition/Formula,
@@ -724,11 +712,11 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
 
     def oxi_state_guesses(
         self,
-        oxi_states_override=None,
-        target_charge=0,
-        all_oxi_states=False,
-        max_sites=None,
-    ):
+        oxi_states_override: dict = None,
+        target_charge: float = 0,
+        all_oxi_states: bool = False,
+        max_sites: int = None,
+    ) -> List[Dict[str, float]]:
         """
         Checks if the composition is charge-balanced and returns back all
         charge-balanced oxidation state combinations. Composition must have
@@ -762,17 +750,15 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
                 composition is not charge balanced, an empty list is returned.
         """
 
-        return self._get_oxid_state_guesses(
-            all_oxi_states, max_sites, oxi_states_override, target_charge
-        )[0]
+        return self._get_oxid_state_guesses(all_oxi_states, max_sites, oxi_states_override, target_charge)[0]
 
     def add_charges_from_oxi_state_guesses(
         self,
-        oxi_states_override=None,
-        target_charge=0,
-        all_oxi_states=False,
-        max_sites=None,
-    ):
+        oxi_states_override: dict = None,
+        target_charge: float = 0,
+        all_oxi_states: bool = False,
+        max_sites: int = None,
+    ) -> "Composition":
         """
         Assign oxidation states basedon guessed oxidation states.
 
@@ -821,7 +807,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         # Return the new object
         return Composition(collections.Counter(species))
 
-    def remove_charges(self):
+    def remove_charges(self) -> "Composition":
         """
         Removes the charges from any species in a Composition object.
 
@@ -829,17 +815,12 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
             Composition object without charge decoration, for example
             {"Fe3+": 2.0, "O2-":3.0} becomes {"Fe": 2.0, "O":3.0}
         """
-        d = collections.Counter()
-
-        for e, f in self.items():
-            e = re.findall(r"[A-z]+", str(e))[0]
-            d[str(e)] += f
-
+        d: Dict[Element, float] = collections.defaultdict(float)
+        for e, a in self.items():
+            d[Element(e.symbol)] += a
         return Composition(d)
 
-    def _get_oxid_state_guesses(
-        self, all_oxi_states, max_sites, oxi_states_override, target_charge
-    ):
+    def _get_oxid_state_guesses(self, all_oxi_states, max_sites, oxi_states_override, target_charge):
         """
         Utility operation for guessing oxidation states.
 
@@ -873,17 +854,14 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
                 return a list of [2,2,2,3,3,3] for the oxidation states of If the composition
                 is
 
-            """
+        """
         comp = self.copy()
         # reduce Composition if necessary
         if max_sites and max_sites < 0:
             comp = self.reduced_composition
 
             if max_sites < -1 and comp.num_atoms > abs(max_sites):
-                raise ValueError(
-                    "Composition {} cannot accommodate max_sites "
-                    "setting!".format(comp)
-                )
+                raise ValueError("Composition {} cannot accommodate max_sites " "setting!".format(comp))
 
         elif max_sites and comp.num_atoms > max_sites:
             reduced_comp, reduced_factor = self.get_reduced_composition_and_factor()
@@ -891,27 +869,17 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
                 reduced_comp *= max(1, int(max_sites / reduced_comp.num_atoms))
                 comp = reduced_comp  # as close to max_sites as possible
             if comp.num_atoms > max_sites:
-                raise ValueError(
-                    "Composition {} cannot accommodate max_sites "
-                    "setting!".format(comp)
-                )
+                raise ValueError("Composition {} cannot accommodate max_sites " "setting!".format(comp))
 
         # Load prior probabilities of oxidation states, used to rank solutions
         if not Composition.oxi_prob:
             module_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)))
-            all_data = loadfn(
-                os.path.join(module_dir, "..", "analysis", "icsd_bv.yaml")
-            )
-            Composition.oxi_prob = {
-                Species.from_string(sp): data
-                for sp, data in all_data["occurrence"].items()
-            }
+            all_data = loadfn(os.path.join(module_dir, "..", "analysis", "icsd_bv.yaml"))
+            Composition.oxi_prob = {Species.from_string(sp): data for sp, data in all_data["occurrence"].items()}
         oxi_states_override = oxi_states_override or {}
         # assert: Composition only has integer amounts
         if not all(amt == int(amt) for amt in comp.values()):
-            raise ValueError(
-                "Charge balance analysis requires integer " "values in Composition!"
-            )
+            raise ValueError("Charge balance analysis requires integer " "values in Composition!")
 
         # for each element, determine all possible sum of oxidations
         # (taking into account nsites for that particular element)
@@ -929,9 +897,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
             elif all_oxi_states:
                 oxids = Element(el).oxidation_states
             else:
-                oxids = (
-                    Element(el).icsd_oxidation_states or Element(el).oxidation_states
-                )
+                oxids = Element(el).icsd_oxidation_states or Element(el).oxidation_states
 
             # get all possible combinations of oxidation states
             # and sum each combination
@@ -943,24 +909,18 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
                     el_sums[idx].append(oxid_sum)
 
                 # Determine how probable is this combo?
-                score = sum(
-                    [Composition.oxi_prob.get(Species(el, o), 0) for o in oxid_combo]
-                )
+                score = sum([Composition.oxi_prob.get(Species(el, o), 0) for o in oxid_combo])
 
                 # If it is the most probable combo for a certain sum,
                 #   store the combination
-                if oxid_sum not in el_sum_scores[idx] or score > el_sum_scores[idx].get(
-                    oxid_sum, 0
-                ):
+                if oxid_sum not in el_sum_scores[idx] or score > el_sum_scores[idx].get(oxid_sum, 0):
                     el_sum_scores[idx][oxid_sum] = score
                     el_best_oxid_combo[idx][oxid_sum] = oxid_combo
 
         # Determine which combination of oxidation states for each element
         #    is the most probable
         all_sols = []  # will contain all solutions
-        all_oxid_combo = (
-            []
-        )  # will contain the best combination of oxidation states for each site
+        all_oxid_combo = []  # will contain the best combination of oxidation states for each site
         all_scores = []  # will contain a score for each solution
         for x in product(*el_sums):
             # each x is a trial of one possible oxidation sum for each element
@@ -978,12 +938,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
                 all_scores.append(score)
 
                 # collect the combination of oxidation states for each site
-                all_oxid_combo.append(
-                    dict(
-                        (e, el_best_oxid_combo[idx][v])
-                        for idx, (e, v) in enumerate(zip(els, x))
-                    )
-                )
+                all_oxid_combo.append(dict((e, el_best_oxid_combo[idx][v]) for idx, (e, v) in enumerate(zip(els, x))))
 
         # sort the solutions by highest to lowest score
         if all_scores:
@@ -1000,9 +955,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
         return all_sols, all_oxid_combo
 
     @staticmethod
-    def ranked_compositions_from_indeterminate_formula(
-        fuzzy_formula, lock_if_strict=True
-    ):
+    def ranked_compositions_from_indeterminate_formula(fuzzy_formula, lock_if_strict=True):
         """
         Takes in a formula where capitilization might not be correctly entered,
         and suggests a ranked list of potential Composition matches.
@@ -1028,16 +981,14 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
             try:
                 comp = Composition(fuzzy_formula)
                 return [comp]
-            except (CompositionError, ValueError):
+            except ValueError:
                 pass
 
         all_matches = Composition._comps_from_fuzzy_formula(fuzzy_formula)
         # remove duplicates
         all_matches = list(set(all_matches))
         # sort matches by rank descending
-        all_matches = sorted(
-            all_matches, key=lambda match: (match[1], match[0]), reverse=True
-        )
+        all_matches = sorted(all_matches, key=lambda match: (match[1], match[0]), reverse=True)
         all_matches = [m[0] for m in all_matches]
         return all_matches
 
@@ -1099,7 +1050,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
             # get element and amount from regex match
             el = m.group(1)
             if len(el) > 2 or len(el) < 1:
-                raise CompositionError("Invalid element symbol entered!")
+                raise ValueError("Invalid element symbol entered!")
             amt = float(m.group(2)) if m.group(2).strip() != "" else 1
 
             # convert the element string to proper [uppercase,lowercase] format
@@ -1142,16 +1093,12 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
                 mp_factor = 1 if mp.group(2) == "" else float(mp.group(2))
                 # Match the stuff inside the parenthesis with the appropriate
                 # factor
-                for match in Composition._comps_from_fuzzy_formula(
-                    mp.group(1), mp_dict, mp_points, factor=mp_factor
-                ):
+                for match in Composition._comps_from_fuzzy_formula(mp.group(1), mp_dict, mp_points, factor=mp_factor):
                     only_me = True
                     # Match the stuff outside the parentheses and return the
                     # sum.
 
-                    for match2 in Composition._comps_from_fuzzy_formula(
-                        mp_form, mp_dict, mp_points, factor=1
-                    ):
+                    for match2 in Composition._comps_from_fuzzy_formula(mp_form, mp_dict, mp_points, factor=1):
                         only_me = False
                         yield (match[0] + match2[0], match[1] + match2[1])
                     # if the stuff inside the parenthesis is nothing, then just
@@ -1166,14 +1113,10 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
                 m_points1 = m_points
                 m_form1 = fuzzy_formula
                 m_dict1 = dict(m_dict)
-                (m_form1, m_dict1, m_points1) = _parse_chomp_and_rank(
-                    m1, m_form1, m_dict1, m_points1
-                )
+                (m_form1, m_dict1, m_points1) = _parse_chomp_and_rank(m1, m_form1, m_dict1, m_points1)
                 if m_dict1:
                     # there was a real match
-                    for match in Composition._comps_from_fuzzy_formula(
-                        m_form1, m_dict1, m_points1, factor
-                    ):
+                    for match in Composition._comps_from_fuzzy_formula(m_form1, m_dict1, m_points1, factor):
                         yield match
 
             # try to match two-letter elements
@@ -1182,18 +1125,14 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable):
                 m_points2 = m_points
                 m_form2 = fuzzy_formula
                 m_dict2 = dict(m_dict)
-                (m_form2, m_dict2, m_points2) = _parse_chomp_and_rank(
-                    m2, m_form2, m_dict2, m_points2
-                )
+                (m_form2, m_dict2, m_points2) = _parse_chomp_and_rank(m2, m_form2, m_dict2, m_points2)
                 if m_dict2:
                     # there was a real match
-                    for match in Composition._comps_from_fuzzy_formula(
-                        m_form2, m_dict2, m_points2, factor
-                    ):
+                    for match in Composition._comps_from_fuzzy_formula(m_form2, m_dict2, m_points2, factor):
                         yield match
 
 
-def reduce_formula(sym_amt, iupac_ordering=False):
+def reduce_formula(sym_amt, iupac_ordering: bool = False) -> Tuple[str, float]:
     """
     Helper method to reduce a sym_amt dict to a reduced formula and factor.
 
@@ -1224,9 +1163,7 @@ def reduce_formula(sym_amt, iupac_ordering=False):
     # if the composition contains a poly anion
     if len(syms) >= 3 and get_el_sp(syms[-1]).X - get_el_sp(syms[-2]).X < 1.65:
         poly_sym_amt = {syms[i]: sym_amt[syms[i]] / factor for i in [-2, -1]}
-        (poly_form, poly_factor) = reduce_formula(
-            poly_sym_amt, iupac_ordering=iupac_ordering
-        )
+        (poly_form, poly_factor) = reduce_formula(poly_sym_amt, iupac_ordering=iupac_ordering)
 
         if poly_factor != 1:
             polyanion.append("({}){}".format(poly_form, int(poly_factor)))
@@ -1242,12 +1179,8 @@ def reduce_formula(sym_amt, iupac_ordering=False):
         reduced_form.append(s)
         reduced_form.append(formula_double_format(normamt))
 
-    reduced_form = "".join(reduced_form + polyanion)
-    return reduced_form, factor
-
-
-class CompositionError(Exception):
-    """Exception class for composition errors"""
+    reduced_form = "".join(reduced_form + polyanion)  # type: ignore
+    return reduced_form, factor  # type: ignore
 
 
 class ChemicalPotential(dict, MSONable):
@@ -1294,7 +1227,7 @@ class ChemicalPotential(dict, MSONable):
             return ChemicalPotential({e: self.get(e, 0) + other.get(e, 0) for e in els})
         raise NotImplementedError()
 
-    def get_energy(self, composition, strict=True):
+    def get_energy(self, composition: Composition, strict: bool = True) -> float:
         """
         Calculates the energy of a composition.
 
