@@ -16,6 +16,7 @@ from monty.json import MSONable
 
 from pymatgen.electronic_structure.core import Magmom
 from pymatgen.util.string import transformation_to_string
+from pymatgen.util.typing import ArrayLike
 
 __author__ = "Shyue Ping Ong, Shyam Dwaraknath, Matthew Horton"
 __copyright__ = "Copyright 2011, The Materials Project"
@@ -37,7 +38,7 @@ class SymmOp(MSONable):
         A 4x4 numpy.array representing the symmetry operation.
     """
 
-    def __init__(self, affine_transformation_matrix, tol=0.01):
+    def __init__(self, affine_transformation_matrix: ArrayLike, tol=0.01):
         """
         Initializes the SymmOp from a 4x4 affine transformation matrix.
         In general, this constructor should not be used unless you are
@@ -57,8 +58,8 @@ class SymmOp(MSONable):
 
     @staticmethod
     def from_rotation_and_translation(
-        rotation_matrix=((1, 0, 0), (0, 1, 0), (0, 0, 1)),
-        translation_vec=(0, 0, 0),
+        rotation_matrix: ArrayLike = ((1, 0, 0), (0, 1, 0), (0, 0, 1)),
+        translation_vec: ArrayLike = (0, 0, 0),
         tol=0.1,
     ):
         """
@@ -78,9 +79,7 @@ class SymmOp(MSONable):
         if rotation_matrix.shape != (3, 3):
             raise ValueError("Rotation Matrix must be a 3x3 numpy array.")
         if translation_vec.shape != (3,):
-            raise ValueError(
-                "Translation vector must be a rank 1 numpy array " "with 3 elements."
-            )
+            raise ValueError("Translation vector must be a rank 1 numpy array " "with 3 elements.")
         affine_matrix = np.eye(4)
         affine_matrix[0:3][:, 0:3] = rotation_matrix
         affine_matrix[0:3][:, 3] = translation_vec
@@ -128,12 +127,10 @@ class SymmOp(MSONable):
             Numpy array of coordinates after operation
         """
         points = np.array(points)
-        affine_points = np.concatenate(
-            [points, np.ones(points.shape[:-1] + (1,))], axis=-1
-        )
+        affine_points = np.concatenate([points, np.ones(points.shape[:-1] + (1,))], axis=-1)
         return np.inner(affine_points, self.affine_matrix)[..., :-1]
 
-    def apply_rotation_only(self, vector):
+    def apply_rotation_only(self, vector: ArrayLike):
         """
         Vectors should only be operated by the rotation matrix and not the
         translation vector.
@@ -143,7 +140,7 @@ class SymmOp(MSONable):
         """
         return np.dot(self.rotation_matrix, vector)
 
-    def transform_tensor(self, tensor):
+    def transform_tensor(self, tensor: np.ndarray):
         """
         Applies rotation portion to a tensor. Note that tensor has to be in
         full form, not the Voigt form.
@@ -166,7 +163,7 @@ class SymmOp(MSONable):
 
         return np.einsum(einsum_string, *einsum_args)
 
-    def are_symmetrically_related(self, point_a, point_b, tol=0.001):
+    def are_symmetrically_related(self, point_a: ArrayLike, point_b: ArrayLike, tol: float = 0.001) -> bool:
         """
         Checks if two points are symmetrically related.
 
@@ -185,14 +182,14 @@ class SymmOp(MSONable):
         return False
 
     @property
-    def rotation_matrix(self):
+    def rotation_matrix(self) -> np.ndarray:
         """
         A 3x3 numpy.array representing the rotation matrix.
         """
         return self.affine_matrix[0:3][:, 0:3]
 
     @property
-    def translation_vector(self):
+    def translation_vector(self) -> np.ndarray:
         """
         A rank 1 numpy.array of dim 3 representing the translation vector.
         """
@@ -207,7 +204,7 @@ class SymmOp(MSONable):
         return SymmOp(new_matrix)
 
     @property
-    def inverse(self):
+    def inverse(self) -> "SymmOp":
         """
         Returns inverse of transformation.
         """
@@ -216,8 +213,8 @@ class SymmOp(MSONable):
 
     @staticmethod
     def from_axis_angle_and_translation(
-        axis, angle, angle_in_radians=False, translation_vec=(0, 0, 0)
-    ):
+        axis: ArrayLike, angle: float, angle_in_radians: bool = False, translation_vec: ArrayLike = (0, 0, 0)
+    ) -> "SymmOp":
         """
         Generates a SymmOp for a rotation about a given axis plus translation.
 
@@ -235,10 +232,7 @@ class SymmOp(MSONable):
         if isinstance(axis, (tuple, list)):
             axis = np.array(axis)
 
-        if isinstance(translation_vec, (tuple, list)):
-            vec = np.array(translation_vec)
-        else:
-            vec = translation_vec
+        vec = np.array(translation_vec)
 
         a = angle if angle_in_radians else angle * pi / 180
         cosa = cos(a)
@@ -258,7 +252,9 @@ class SymmOp(MSONable):
         return SymmOp.from_rotation_and_translation(r, vec)
 
     @staticmethod
-    def from_origin_axis_angle(origin, axis, angle, angle_in_radians=False):
+    def from_origin_axis_angle(
+        origin: ArrayLike, axis: ArrayLike, angle: float, angle_in_radians: bool = False
+    ) -> "SymmOp":
         """
         Generates a SymmOp for a rotation about a given axis through an
         origin.
@@ -275,54 +271,54 @@ class SymmOp(MSONable):
             SymmOp.
         """
         theta = angle * pi / 180 if not angle_in_radians else angle
-        a = origin[0]
-        b = origin[1]
-        c = origin[2]
-        u = axis[0]
-        v = axis[1]
-        w = axis[2]
+        a = origin[0]  # type: ignore
+        b = origin[1]  # type: ignore
+        c = origin[2]  # type: ignore
+        u = axis[0]  # type: ignore
+        v = axis[1]  # type: ignore
+        w = axis[2]  # type: ignore
         # Set some intermediate values.
-        u2 = u * u
-        v2 = v * v
-        w2 = w * w
+        u2 = u * u  # type: ignore
+        v2 = v * v  # type: ignore
+        w2 = w * w  # type: ignore
         cos_t = cos(theta)
         sin_t = sin(theta)
-        l2 = u2 + v2 + w2
-        l = sqrt(l2)
+        l2 = u2 + v2 + w2  # type: ignore
+        l = sqrt(l2)  # type: ignore
 
         # Build the matrix entries element by element.
-        m11 = (u2 + (v2 + w2) * cos_t) / l2
-        m12 = (u * v * (1 - cos_t) - w * l * sin_t) / l2
-        m13 = (u * w * (1 - cos_t) + v * l * sin_t) / l2
-        m14 = (
-            a * (v2 + w2)
-            - u * (b * v + c * w)
-            + (u * (b * v + c * w) - a * (v2 + w2)) * cos_t
-            + (b * w - c * v) * l * sin_t
-        ) / l2
+        m11 = (u2 + (v2 + w2) * cos_t) / l2  # type: ignore
+        m12 = (u * v * (1 - cos_t) - w * l * sin_t) / l2  # type: ignore
+        m13 = (u * w * (1 - cos_t) + v * l * sin_t) / l2  # type: ignore
+        m14 = (  # type: ignore
+            a * (v2 + w2)  # type: ignore
+            - u * (b * v + c * w)  # type: ignore
+            + (u * (b * v + c * w) - a * (v2 + w2)) * cos_t  # type: ignore
+            + (b * w - c * v) * l * sin_t  # type: ignore
+        ) / l2  # type: ignore
 
-        m21 = (u * v * (1 - cos_t) + w * l * sin_t) / l2
-        m22 = (v2 + (u2 + w2) * cos_t) / l2
-        m23 = (v * w * (1 - cos_t) - u * l * sin_t) / l2
-        m24 = (
-            b * (u2 + w2)
-            - v * (a * u + c * w)
-            + (v * (a * u + c * w) - b * (u2 + w2)) * cos_t
-            + (c * u - a * w) * l * sin_t
-        ) / l2
+        m21 = (u * v * (1 - cos_t) + w * l * sin_t) / l2  # type: ignore
+        m22 = (v2 + (u2 + w2) * cos_t) / l2  # type: ignore
+        m23 = (v * w * (1 - cos_t) - u * l * sin_t) / l2  # type: ignore
+        m24 = (  # type: ignore
+            b * (u2 + w2)  # type: ignore
+            - v * (a * u + c * w)  # type: ignore
+            + (v * (a * u + c * w) - b * (u2 + w2)) * cos_t  # type: ignore
+            + (c * u - a * w) * l * sin_t  # type: ignore
+        ) / l2  # type: ignore
 
-        m31 = (u * w * (1 - cos_t) - v * l * sin_t) / l2
-        m32 = (v * w * (1 - cos_t) + u * l * sin_t) / l2
-        m33 = (w2 + (u2 + v2) * cos_t) / l2
-        m34 = (
-            c * (u2 + v2)
-            - w * (a * u + b * v)
-            + (w * (a * u + b * v) - c * (u2 + v2)) * cos_t
-            + (a * v - b * u) * l * sin_t
+        m31 = (u * w * (1 - cos_t) - v * l * sin_t) / l2  # type: ignore
+        m32 = (v * w * (1 - cos_t) + u * l * sin_t) / l2  # type: ignore
+        m33 = (w2 + (u2 + v2) * cos_t) / l2  # type: ignore
+        m34 = (  # type: ignore
+            c * (u2 + v2)  # type: ignore
+            - w * (a * u + b * v)  # type: ignore
+            + (w * (a * u + b * v) - c * (u2 + v2)) * cos_t  # type: ignore
+            + (a * v - b * u) * l * sin_t  # type: ignore
         ) / l2
 
         return SymmOp(
-            [
+            [  # type: ignore
                 [m11, m12, m13, m14],
                 [m21, m22, m23, m24],
                 [m31, m32, m33, m34],
@@ -331,7 +327,7 @@ class SymmOp(MSONable):
         )
 
     @staticmethod
-    def reflection(normal, origin=(0, 0, 0)):
+    def reflection(normal: ArrayLike, origin: ArrayLike = (0, 0, 0)) -> "SymmOp":
         """
         Returns reflection symmetry operation.
 
@@ -361,13 +357,11 @@ class SymmOp(MSONable):
         mirror_mat = [[xx, xy, xz, 0], [xy, yy, yz, 0], [xz, yz, zz, 0], [0, 0, 0, 1]]
 
         if np.linalg.norm(origin) > 1e-6:
-            mirror_mat = np.dot(
-                np.linalg.inv(translation), np.dot(mirror_mat, translation)
-            )
+            mirror_mat = np.dot(np.linalg.inv(translation), np.dot(mirror_mat, translation))
         return SymmOp(mirror_mat)
 
     @staticmethod
-    def inversion(origin=(0, 0, 0)):
+    def inversion(origin: ArrayLike = (0, 0, 0)) -> "SymmOp":
         """
         Inversion symmetry operation about axis.
 
@@ -384,7 +378,7 @@ class SymmOp(MSONable):
         return SymmOp(mat)
 
     @staticmethod
-    def rotoreflection(axis, angle, origin=(0, 0, 0)):
+    def rotoreflection(axis: ArrayLike, angle: float, origin: ArrayLike = (0, 0, 0)) -> "SymmOp":
         """
         Returns a roto-reflection symmetry operation
 
@@ -402,7 +396,7 @@ class SymmOp(MSONable):
         m = np.dot(rot.affine_matrix, refl.affine_matrix)
         return SymmOp(m)
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """
         :return: MSONAble dict.
         """
@@ -413,7 +407,7 @@ class SymmOp(MSONable):
             "tolerance": self.tol,
         }
 
-    def as_xyz_string(self):
+    def as_xyz_string(self) -> str:
         """
         Returns a string of the form 'x, y, z', '-x, -y, z',
         '-y+1/2, x+1/2, z+1/2', etc. Only works for integer rotation matrices
@@ -422,12 +416,10 @@ class SymmOp(MSONable):
         if not np.all(np.isclose(self.rotation_matrix, np.round(self.rotation_matrix))):
             warnings.warn("Rotation matrix should be integer")
 
-        return transformation_to_string(
-            self.rotation_matrix, translation_vec=self.translation_vector, delim=", "
-        )
+        return transformation_to_string(self.rotation_matrix, translation_vec=self.translation_vector, delim=", ")
 
     @staticmethod
-    def from_xyz_string(xyz_string):
+    def from_xyz_string(xyz_string: str) -> "SymmOp":
         """
         Args:
             xyz_string: string of the form 'x, y, z', '-x, -y, z',
@@ -443,28 +435,20 @@ class SymmOp(MSONable):
         for i, tok in enumerate(toks):
             # build the rotation matrix
             for m in re_rot.finditer(tok):
-                factor = -1 if m.group(1) == "-" else 1
+                factor = -1.0 if m.group(1) == "-" else 1.0
                 if m.group(2) != "":
-                    factor *= (
-                        float(m.group(2)) / float(m.group(3))
-                        if m.group(3) != ""
-                        else float(m.group(2))
-                    )
+                    factor *= float(m.group(2)) / float(m.group(3)) if m.group(3) != "" else float(m.group(2))
                 j = ord(m.group(4)) - 120
                 rot_matrix[i, j] = factor
             # build the translation vector
             for m in re_trans.finditer(tok):
                 factor = -1 if m.group(1) == "-" else 1
-                num = (
-                    float(m.group(2)) / float(m.group(3))
-                    if m.group(3) != ""
-                    else float(m.group(2))
-                )
+                num = float(m.group(2)) / float(m.group(3)) if m.group(3) != "" else float(m.group(2))
                 trans[i] = num * factor
         return SymmOp.from_rotation_and_translation(rot_matrix, trans)
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, d) -> "SymmOp":
         """
         :param d: dict
         :return: SymmOp from dict representation.
@@ -481,7 +465,7 @@ class MagSymmOp(SymmOp):
     moment.
     """
 
-    def __init__(self, affine_transformation_matrix, time_reversal, tol=0.01):
+    def __init__(self, affine_transformation_matrix: ArrayLike, time_reversal: int, tol: float = 0.01):
         """
         Initializes the MagSymmOp from a 4x4 affine transformation matrix
         and time reversal operator.
@@ -498,9 +482,7 @@ class MagSymmOp(SymmOp):
         SymmOp.__init__(self, affine_transformation_matrix, tol=tol)
         if time_reversal not in (-1, 1):
             raise Exception(
-                "Time reversal operator not well defined: {0}, {1}".format(
-                    time_reversal, type(time_reversal)
-                )
+                "Time reversal operator not well defined: {0}, {1}".format(time_reversal, type(time_reversal))
             )
         self.time_reversal = time_reversal
 
@@ -547,16 +529,14 @@ class MagSymmOp(SymmOp):
         magmom = Magmom(magmom)  # type casting to handle lists as input
 
         transformed_moment = (
-            self.apply_rotation_only(magmom.global_moment)
-            * np.linalg.det(self.rotation_matrix)
-            * self.time_reversal
+            self.apply_rotation_only(magmom.global_moment) * np.linalg.det(self.rotation_matrix) * self.time_reversal
         )
 
         # retains input spin axis if different from default
         return Magmom.from_global_moment_and_saxis(transformed_moment, magmom.saxis)
 
     @classmethod
-    def from_symmop(cls, symmop, time_reversal):
+    def from_symmop(cls, symmop, time_reversal) -> "MagSymmOp":
         """
         Initialize a MagSymmOp from a SymmOp and time reversal operator.
 
@@ -572,11 +552,11 @@ class MagSymmOp(SymmOp):
 
     @staticmethod
     def from_rotation_and_translation_and_time_reversal(
-        rotation_matrix=((1, 0, 0), (0, 1, 0), (0, 0, 1)),
-        translation_vec=(0, 0, 0),
-        time_reversal=1,
-        tol=0.1,
-    ):
+        rotation_matrix: ArrayLike = ((1, 0, 0), (0, 1, 0), (0, 0, 1)),
+        translation_vec: ArrayLike = (0, 0, 0),
+        time_reversal: int = 1,
+        tol: float = 0.1,
+    ) -> "MagSymmOp":
         """
         Creates a symmetry operation from a rotation matrix, translation
         vector and time reversal operator.
@@ -596,7 +576,7 @@ class MagSymmOp(SymmOp):
         return MagSymmOp.from_symmop(symmop, time_reversal)
 
     @staticmethod
-    def from_xyzt_string(xyzt_string):
+    def from_xyzt_string(xyzt_string: str) -> "MagSymmOp":
         """
         Args:
             xyz_string: string of the form 'x, y, z, +1', '-x, -y, z, -1',
@@ -611,7 +591,7 @@ class MagSymmOp(SymmOp):
             raise Exception("Time reversal operator could not be parsed.")
         return MagSymmOp.from_symmop(symmop, time_reversal)
 
-    def as_xyzt_string(self):
+    def as_xyzt_string(self) -> str:
         """
         Returns a string of the form 'x, y, z, +1', '-x, -y, z, -1',
         '-y+1/2, x+1/2, z+1/2, +1', etc. Only works for integer rotation matrices
@@ -619,7 +599,7 @@ class MagSymmOp(SymmOp):
         xyzt_string = SymmOp.as_xyz_string(self)
         return xyzt_string + ", {:+}".format(self.time_reversal)
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """
         :return: MSONABle dict
         """
@@ -632,7 +612,7 @@ class MagSymmOp(SymmOp):
         }
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, d: dict) -> "MagSymmOp":
         """
         :param d: dict
         :return: MagneticSymmOp from dict representation.
