@@ -225,9 +225,7 @@ class Slab(Structure):
         # Determine what fraction the slab is of the total cell size in the
         # c direction. Round to nearest rational number.
         nlayers_total = int(round(self.lattice.c / self.oriented_unit_cell.lattice.c))
-        nlayers_slab = int(
-            round((sortedcsites[-1].c - sortedcsites[0].c) * nlayers_total)
-        )
+        nlayers_slab = int(round((sortedcsites[-1].c - sortedcsites[0].c) * nlayers_total))
         slab_ratio = nlayers_slab / nlayers_total
 
         a = SpacegroupAnalyzer(self)
@@ -256,10 +254,7 @@ class Slab(Structure):
             # Sort and group the sites by the species and symmetry equivalence
             tomove = sorted(tomove, key=lambda s: equi_index(s))
 
-            grouped = [
-                list(sites)
-                for k, sites in itertools.groupby(tomove, key=lambda s: equi_index(s))
-            ]
+            grouped = [list(sites) for k, sites in itertools.groupby(tomove, key=lambda s: equi_index(s))]
 
             if len(tomove) == 0 or any([len(g) % 2 != 0 for g in grouped]):
                 warnings.warn(
@@ -397,9 +392,7 @@ class Slab(Structure):
         mid_pt = np.sum(self.cart_coords, axis=0) / len(self)
         normal = self.normal
         for site in self:
-            charge = sum(
-                [getattr(sp, "oxi_state", 0) * amt for sp, amt in site.species.items()]
-            )
+            charge = sum([getattr(sp, "oxi_state", 0) * amt for sp, amt in site.species.items()])
             dipole += charge * np.dot(site.coords - mid_pt, normal) * normal
         return dipole
 
@@ -478,12 +471,8 @@ class Slab(Structure):
         def to_s(x):
             return "%0.6f" % x
 
-        outs.append(
-            "abc   : " + " ".join([to_s(i).rjust(10) for i in self.lattice.abc])
-        )
-        outs.append(
-            "angles: " + " ".join([to_s(i).rjust(10) for i in self.lattice.angles])
-        )
+        outs.append("abc   : " + " ".join([to_s(i).rjust(10) for i in self.lattice.abc]))
+        outs.append("angles: " + " ".join([to_s(i).rjust(10) for i in self.lattice.angles]))
         outs.append("Sites ({i})".format(i=len(self)))
         for i, site in enumerate(self):
             outs.append(
@@ -753,9 +742,7 @@ class Slab(Structure):
         if len(removal_list) == 2 * len(indices):
             self.remove_sites(removal_list)
         else:
-            warnings.warn(
-                "Equivalent sites could not be found for removal for all indices. Surface unchanged."
-            )
+            warnings.warn("Equivalent sites could not be found for removal for all indices. Surface unchanged.")
 
 
 class SlabGenerator:
@@ -870,12 +857,8 @@ class SlabGenerator:
         # Add Wyckoff symbols of the bulk, will help with
         # identfying types of sites in the slab system
         sg = SpacegroupAnalyzer(initial_structure)
-        initial_structure.add_site_property(
-            "bulk_wyckoff", sg.get_symmetry_dataset()["wyckoffs"]
-        )
-        initial_structure.add_site_property(
-            "bulk_equivalent", sg.get_symmetry_dataset()["equivalent_atoms"].tolist()
-        )
+        initial_structure.add_site_property("bulk_wyckoff", sg.get_symmetry_dataset()["wyckoffs"])
+        initial_structure.add_site_property("bulk_equivalent", sg.get_symmetry_dataset()["equivalent_atoms"].tolist())
         latt = initial_structure.lattice
         miller_index = _reduce_vector(miller_index)
         # Calculate the surface normal using the reciprocal lattice vector.
@@ -885,7 +868,7 @@ class SlabGenerator:
 
         slab_scale_factor = []
         non_orth_ind = []
-        eye = np.eye(3, dtype=np.int)
+        eye = np.eye(3, dtype=np.int_)
         for i, j in enumerate(miller_index):
             if j == 0:
                 # Lattice vector is perpendicular to surface normal, i.e.,
@@ -922,9 +905,7 @@ class SlabGenerator:
             )
             candidates = []
             for uvw in itertools.product(index_range, index_range, index_range):
-                if (not any(uvw)) or abs(
-                    np.linalg.det(slab_scale_factor + [uvw])
-                ) < 1e-8:
+                if (not any(uvw)) or abs(np.linalg.det(slab_scale_factor + [uvw])) < 1e-8:
                     continue
                 vec = latt.get_cartesian_coords(uvw)
                 l = np.linalg.norm(vec)
@@ -1013,9 +994,7 @@ class SlabGenerator:
             fcoords[:, 2] += i / nlayers
             all_coords.extend(fcoords)
 
-        slab = Structure(
-            new_lattice, species * nlayers_slab, all_coords, site_properties=props
-        )
+        slab = Structure(new_lattice, species * nlayers_slab, all_coords, site_properties=props)
 
         scale_factor = self.slab_scale_factor
         # Whether or not to orthogonalize the structure
@@ -1051,11 +1030,7 @@ class SlabGenerator:
                 }
             )
             # Check this is the correct oriented unit cell
-            ouc = (
-                self.oriented_unit_cell
-                if slab_l.a != ouc.lattice.a or slab_l.b != ouc.lattice.b
-                else ouc
-            )
+            ouc = self.oriented_unit_cell if slab_l.a != ouc.lattice.a or slab_l.b != ouc.lattice.b else ouc
 
         return Slab(
             slab.lattice,
@@ -1121,17 +1096,13 @@ class SlabGenerator:
 
     def _get_c_ranges(self, bonds):
         c_ranges = set()
-        bonds = {
-            (get_el_sp(s1), get_el_sp(s2)): dist for (s1, s2), dist in bonds.items()
-        }
+        bonds = {(get_el_sp(s1), get_el_sp(s2)): dist for (s1, s2), dist in bonds.items()}
         for (sp1, sp2), bond_dist in bonds.items():
             for site in self.oriented_unit_cell:
                 if sp1 in site.species:
                     for nn in self.oriented_unit_cell.get_neighbors(site, bond_dist):
                         if sp2 in nn.species:
-                            c_range = tuple(
-                                sorted([site.frac_coords[2], nn.frac_coords[2]])
-                            )
+                            c_range = tuple(sorted([site.frac_coords[2], nn.frac_coords[2]]))
                             if c_range[1] > 1:
                                 # Takes care of PBC when c coordinate of site
                                 # goes beyond the upper boundary of the cell
@@ -1281,14 +1252,8 @@ class SlabGenerator:
 
                         # find its NNs with the corresponding
                         # species it should be coordinated with
-                        neighbors = slab.get_neighbors(
-                            slab[i], blength, include_index=True
-                        )
-                        tomove = [
-                            nn[2]
-                            for nn in neighbors
-                            if nn[0].species_string == element2
-                        ]
+                        neighbors = slab.get_neighbors(slab[i], blength, include_index=True)
+                        tomove = [nn[2] for nn in neighbors if nn[0].species_string == element2]
                         tomove.append(i)
                         # and then move those NNs along with the central
                         # atom back to the other side of the slab again
@@ -1326,12 +1291,8 @@ class SlabGenerator:
         slab_ratio = nlayers_slab / nlayers
 
         # Sort the index of sites based on which side they are on
-        top_site_index = [
-            i for i in index_of_sites if slab[i].frac_coords[2] > slab.center_of_mass[2]
-        ]
-        bottom_site_index = [
-            i for i in index_of_sites if slab[i].frac_coords[2] < slab.center_of_mass[2]
-        ]
+        top_site_index = [i for i in index_of_sites if slab[i].frac_coords[2] > slab.center_of_mass[2]]
+        bottom_site_index = [i for i in index_of_sites if slab[i].frac_coords[2] < slab.center_of_mass[2]]
 
         # Translate sites to the opposite surfaces
         slab.translate_sites(top_site_index, [0, 0, slab_ratio])
@@ -1442,9 +1403,7 @@ class ReconstructionGenerator:
         added. In the future, use basis sets?
     """
 
-    def __init__(
-        self, initial_structure, min_slab_size, min_vacuum_size, reconstruction_name
-    ):
+    def __init__(self, initial_structure, min_slab_size, min_vacuum_size, reconstruction_name):
         """
         Generates reconstructed slabs from a set of instructions
             specified by a dictionary or json file.
@@ -1545,8 +1504,7 @@ class ReconstructionGenerator:
                 "The reconstruction_name entered (%s) does not exist in the "
                 "archive. Please select from one of the following reconstructions: %s "
                 "or add the appropriate dictionary to the archive file "
-                "reconstructions_archive.json."
-                % (reconstruction_name, list(reconstructions_archive.keys()))
+                "reconstructions_archive.json." % (reconstruction_name, list(reconstructions_archive.keys()))
             )
 
         # Get the instructions to build the reconstruction
@@ -1560,9 +1518,7 @@ class ReconstructionGenerator:
                 new_points_to_remove = recon_json["points_to_remove"]
 
             # Build new instructions from a base reconstruction
-            recon_json = copy.deepcopy(
-                reconstructions_archive[recon_json["base_reconstruction"]]
-            )
+            recon_json = copy.deepcopy(reconstructions_archive[recon_json["base_reconstruction"]])
             if "points_to_add" in recon_json.keys():
                 del recon_json["points_to_add"]
             if "points_to_remove" in recon_json.keys():
@@ -1608,9 +1564,7 @@ class ReconstructionGenerator:
             if "points_to_remove" in self.reconstruction_json.keys():
                 pts_to_rm = copy.deepcopy(self.reconstruction_json["points_to_remove"])
                 for p in pts_to_rm:
-                    p[2] = slab.lattice.get_fractional_coords(
-                        [top_site[0], top_site[1], top_site[2] + p[2] * d]
-                    )[2]
+                    p[2] = slab.lattice.get_fractional_coords([top_site[0], top_site[1], top_site[2] + p[2] * d])[2]
                     cart_point = slab.lattice.get_cartesian_coords(p)
                     dist = [site.distance_from_point(cart_point) for site in slab]
                     site1 = dist.index(min(dist))
@@ -1620,9 +1574,7 @@ class ReconstructionGenerator:
             if "points_to_add" in self.reconstruction_json.keys():
                 pts_to_add = copy.deepcopy(self.reconstruction_json["points_to_add"])
                 for p in pts_to_add:
-                    p[2] = slab.lattice.get_fractional_coords(
-                        [top_site[0], top_site[1], top_site[2] + p[2] * d]
-                    )[2]
+                    p[2] = slab.lattice.get_fractional_coords([top_site[0], top_site[1], top_site[2] + p[2] * d])[2]
                     slab.symmetrically_add_atom(slab[0].specie, p)
 
             slab.reconstruction = self.name
@@ -1654,9 +1606,7 @@ def get_d(slab):
     """
     sorted_sites = sorted(slab, key=lambda site: site.frac_coords[2])
     for i, site in enumerate(sorted_sites):
-        if not "%.6f" % (site.frac_coords[2]) == "%.6f" % (
-            sorted_sites[i + 1].frac_coords[2]
-        ):
+        if not "%.6f" % (site.frac_coords[2]) == "%.6f" % (sorted_sites[i + 1].frac_coords[2]):
             d = abs(site.frac_coords[2] - sorted_sites[i + 1].frac_coords[2])
             break
     return slab.lattice.get_cartesian_coords([0, 0, d])[2]
@@ -1681,9 +1631,7 @@ def is_already_analyzed(miller_index: tuple, miller_list: list, symm_ops: list)
     return False
 
 
-def get_symmetrically_equivalent_miller_indices(
-    structure, miller_index, return_hkil=True
-):
+def get_symmetrically_equivalent_miller_indices(structure, miller_index, return_hkil=True):
     """
     Returns all symmetrically equivalent indices for a given structure. Analysis
     is based on the symmetry of the reciprocal lattice of the structure.
@@ -1696,11 +1644,7 @@ def get_symmetrically_equivalent_miller_indices(
     """
 
     # Change to hkl if hkil because in_coord_list only handles tuples of 3
-    miller_index = (
-        (miller_index[0], miller_index[1], miller_index[3])
-        if len(miller_index) == 4
-        else miller_index
-    )
+    miller_index = (miller_index[0], miller_index[1], miller_index[3]) if len(miller_index) == 4 else miller_index
     mmi = max(np.abs(miller_index))
     r = list(range(-mmi, mmi + 1))
     r.reverse()
@@ -1708,9 +1652,7 @@ def get_symmetrically_equivalent_miller_indices(
     sg = SpacegroupAnalyzer(structure)
     # Get distinct hkl planes from the rhombohedral setting if trigonal
     if sg.get_crystal_system() == "trigonal":
-        prim_structure = SpacegroupAnalyzer(
-            structure
-        ).get_primitive_standard_structure()
+        prim_structure = SpacegroupAnalyzer(structure).get_primitive_standard_structure()
         symm_ops = prim_structure.lattice.get_recp_symmetry_operation()
     else:
         symm_ops = structure.lattice.get_recp_symmetry_operation()
@@ -1724,18 +1666,12 @@ def get_symmetrically_equivalent_miller_indices(
                 equivalent_millers.append(miller)
 
             # include larger Miller indices in the family of planes
-            if all([mmi > i for i in np.abs(miller)]) and not in_coord_list(
-                equivalent_millers, miller
-            ):
-                if is_already_analyzed(
-                    mmi * np.array(miller), equivalent_millers, symm_ops
-                ):
+            if all([mmi > i for i in np.abs(miller)]) and not in_coord_list(equivalent_millers, miller):
+                if is_already_analyzed(mmi * np.array(miller), equivalent_millers, symm_ops):
                     equivalent_millers.append(miller)
 
     if return_hkil and sg.get_crystal_system() in ["trigonal", "hexagonal"]:
-        return [
-            (hkl[0], hkl[1], -1 * hkl[0] - hkl[1], hkl[2]) for hkl in equivalent_millers
-        ]
+        return [(hkl[0], hkl[1], -1 * hkl[0] - hkl[1], hkl[2]) for hkl in equivalent_millers]
     return equivalent_millers
 
 
@@ -1757,18 +1693,14 @@ def get_symmetrically_distinct_miller_indices(structure, max_index, return_hkil=
     r.reverse()
 
     # First we get a list of all hkls for conventional (including equivalent)
-    conv_hkl_list = [
-        miller for miller in itertools.product(r, r, r) if any([i != 0 for i in miller])
-    ]
+    conv_hkl_list = [miller for miller in itertools.product(r, r, r) if any([i != 0 for i in miller])]
 
     sg = SpacegroupAnalyzer(structure)
     # Get distinct hkl planes from the rhombohedral setting if trigonal
     if sg.get_crystal_system() == "trigonal":
         transf = sg.get_conventional_to_primitive_transformation_matrix()
         miller_list = [hkl_transformation(transf, hkl) for hkl in conv_hkl_list]
-        prim_structure = SpacegroupAnalyzer(
-            structure
-        ).get_primitive_standard_structure()
+        prim_structure = SpacegroupAnalyzer(structure).get_primitive_standard_structure()
         symm_ops = prim_structure.lattice.get_recp_symmetry_operation()
     else:
         miller_list = conv_hkl_list
@@ -1793,10 +1725,7 @@ def get_symmetrically_distinct_miller_indices(structure, max_index, return_hkil=
                 unique_millers_conv.append(miller)
 
     if return_hkil and sg.get_crystal_system() in ["trigonal", "hexagonal"]:
-        return [
-            (hkl[0], hkl[1], -1 * hkl[0] - hkl[1], hkl[2])
-            for hkl in unique_millers_conv
-        ]
+        return [(hkl[0], hkl[1], -1 * hkl[0] - hkl[1], hkl[2]) for hkl in unique_millers_conv]
     return unique_millers_conv
 
 
@@ -1814,9 +1743,7 @@ def hkl_transformation(transf, miller_index):
     def lcm(a, b):
         return a * b // math.gcd(a, b)
 
-    reduced_transf = (
-        reduce(lcm, [int(1 / i) for i in itertools.chain(*transf) if i != 0]) * transf
-    )
+    reduced_transf = reduce(lcm, [int(1 / i) for i in itertools.chain(*transf) if i != 0]) * transf
     reduced_transf = reduced_transf.astype(int)
 
     # perform the transformation
@@ -1937,17 +1864,13 @@ def generate_all_slabs(
         # archive available for this particular structure (spacegroup)
         for name, instructions in reconstructions_archive.items():
             if "base_reconstruction" in instructions.keys():
-                instructions = reconstructions_archive[
-                    instructions["base_reconstruction"]
-                ]
+                instructions = reconstructions_archive[instructions["base_reconstruction"]]
             if instructions["spacegroup"]["symbol"] == symbol:
                 # check if this reconstruction has a max index
                 # equal or less than the given max index
                 if max(instructions["miller_index"]) > max_index:
                     continue
-                recon = ReconstructionGenerator(
-                    structure, min_slab_size, min_vacuum_size, name
-                )
+                recon = ReconstructionGenerator(structure, min_slab_size, min_vacuum_size, name)
                 all_slabs.extend(recon.build_slabs())
 
     return all_slabs
@@ -1967,9 +1890,7 @@ def get_slab_regions(slab, blength=3.5):
     fcoords, indices, all_indices = [], [], []
     for site in slab:
         # find sites with c < 0 (noncontiguous)
-        neighbors = slab.get_neighbors(
-            site, blength, include_index=True, include_image=True
-        )
+        neighbors = slab.get_neighbors(site, blength, include_index=True, include_image=True)
         for nn in neighbors:
             if nn[0].frac_coords[2] < 0:
                 # sites are noncontiguous within cell
@@ -1985,15 +1906,10 @@ def get_slab_regions(slab, blength=3.5):
             last_fcoords = copy.copy(fcoords)
             last_indices = copy.copy(indices)
             site = slab[indices[fcoords.index(min(fcoords))]]
-            neighbors = slab.get_neighbors(
-                site, blength, include_index=True, include_image=True
-            )
+            neighbors = slab.get_neighbors(site, blength, include_index=True, include_image=True)
             fcoords, indices = [], []
             for nn in neighbors:
-                if (
-                    1 > nn[0].frac_coords[2] > 0
-                    and nn[0].frac_coords[2] < site.frac_coords[2]
-                ):
+                if 1 > nn[0].frac_coords[2] > 0 and nn[0].frac_coords[2] < site.frac_coords[2]:
                     # sites are noncontiguous within cell
                     fcoords.append(nn[0].frac_coords[2])
                     indices.append(nn[-2])
@@ -2003,12 +1919,7 @@ def get_slab_regions(slab, blength=3.5):
         # Now locate the highest site within the lower region of the slab
         upper_fcoords = []
         for site in slab:
-            if all(
-                [
-                    nn.index not in all_indices
-                    for nn in slab.get_neighbors(site, blength)
-                ]
-            ):
+            if all([nn.index not in all_indices for nn in slab.get_neighbors(site, blength)]):
                 upper_fcoords.append(site.frac_coords[2])
         coords = copy.copy(last_fcoords) if not fcoords else copy.copy(fcoords)
         min_top = slab[last_indices[coords.index(min(coords))]].frac_coords[2]
@@ -2022,9 +1933,7 @@ def get_slab_regions(slab, blength=3.5):
     return ranges
 
 
-def miller_index_from_sites(
-    lattice, coords, coords_are_cartesian=True, round_dp=4, verbose=True
-):
+def miller_index_from_sites(lattice, coords, coords_are_cartesian=True, round_dp=4, verbose=True):
     """
     Get the Miller index of a plane from a list of site coordinates.
 
