@@ -139,13 +139,9 @@ class Cohp(MSONable):
         inter = {}
         for spin in self.cohp:
             if not integrated:
-                inter[spin] = get_linear_interpolated_value(
-                    self.energies, self.cohp[spin], energy
-                )
+                inter[spin] = get_linear_interpolated_value(self.energies, self.cohp[spin], energy)
             elif self.icohp is not None:
-                inter[spin] = get_linear_interpolated_value(
-                    self.energies, self.icohp[spin], energy
-                )
+                inter[spin] = get_linear_interpolated_value(self.energies, self.icohp[spin], energy)
             else:
                 raise ValueError("ICOHP is empty.")
         return inter
@@ -157,14 +153,10 @@ class Cohp(MSONable):
             limit: -COHP smaller -limit will be considered.
 
         """
-        warnings.warn(
-            "This method has not been tested on many examples. Check the parameter limit, pls!"
-        )
+        warnings.warn("This method has not been tested on many examples. Check the parameter limit, pls!")
 
         populations = self.cohp
-        number_energies_below_efermi = len(
-            [x for x in self.energies if x <= self.efermi]
-        )
+        number_energies_below_efermi = len([x for x in self.energies if x <= self.efermi])
 
         if populations is None:
             return None
@@ -297,45 +289,22 @@ class CompleteCohp(Cohp):
             "efermi": self.efermi,
             "structure": self.structure.as_dict(),
             "energies": self.energies.tolist(),
-            "COHP": {
-                "average": {
-                    str(spin): pops.tolist() for spin, pops in self.cohp.items()
-                }
-            },
+            "COHP": {"average": {str(spin): pops.tolist() for spin, pops in self.cohp.items()}},
         }
 
         if self.icohp is not None:
-            d["ICOHP"] = {
-                "average": {
-                    str(spin): pops.tolist() for spin, pops in self.icohp.items()
-                }
-            }
+            d["ICOHP"] = {"average": {str(spin): pops.tolist() for spin, pops in self.icohp.items()}}
 
         for label in self.all_cohps.keys():
-            d["COHP"].update(
-                {
-                    label: {
-                        str(spin): pops.tolist()
-                        for spin, pops in self.all_cohps[label].cohp.items()
-                    }
-                }
-            )
+            d["COHP"].update({label: {str(spin): pops.tolist() for spin, pops in self.all_cohps[label].cohp.items()}})
             if self.all_cohps[label].icohp is not None:
                 if "ICOHP" not in d.keys():
                     d["ICOHP"] = {
-                        label: {
-                            str(spin): pops.tolist()
-                            for spin, pops in self.all_cohps[label].icohp.items()
-                        }
+                        label: {str(spin): pops.tolist() for spin, pops in self.all_cohps[label].icohp.items()}
                     }
                 else:
                     d["ICOHP"].update(
-                        {
-                            label: {
-                                str(spin): pops.tolist()
-                                for spin, pops in self.all_cohps[label].icohp.items()
-                            }
-                        }
+                        {label: {str(spin): pops.tolist() for spin, pops in self.all_cohps[label].icohp.items()}}
                     )
         if False in [bond_dict == {} for bond_dict in self.bonds.values()]:
             d["bonds"] = {
@@ -350,22 +319,11 @@ class CompleteCohp(Cohp):
             for label in self.orb_res_cohp:
                 orb_dict[label] = {}
                 for orbs in self.orb_res_cohp[label]:
-                    cohp = {
-                        str(spin): pops.tolist()
-                        for spin, pops in self.orb_res_cohp[label][orbs]["COHP"].items()
-                    }
+                    cohp = {str(spin): pops.tolist() for spin, pops in self.orb_res_cohp[label][orbs]["COHP"].items()}
                     orb_dict[label][orbs] = {"COHP": cohp}
-                    icohp = {
-                        str(spin): pops.tolist()
-                        for spin, pops in self.orb_res_cohp[label][orbs][
-                            "ICOHP"
-                        ].items()
-                    }
+                    icohp = {str(spin): pops.tolist() for spin, pops in self.orb_res_cohp[label][orbs]["ICOHP"].items()}
                     orb_dict[label][orbs]["ICOHP"] = icohp
-                    orbitals = [
-                        [orb[0], orb[1].name]
-                        for orb in self.orb_res_cohp[label][orbs]["orbitals"]
-                    ]
+                    orbitals = [[orb[0], orb[1].name] for orb in self.orb_res_cohp[label][orbs]["orbitals"]]
                     orb_dict[label][orbs]["orbitals"] = orbitals
             d["orb_res_cohp"] = orb_dict
 
@@ -413,20 +371,12 @@ class CompleteCohp(Cohp):
         summed_icohp = first_cohpobject.icohp.copy()
         for label in label_list[1:]:
             cohp_here = self.get_cohp_by_label(label)
-            summed_cohp[Spin.up] = np.sum(
-                [summed_cohp[Spin.up], cohp_here.cohp[Spin.up]], axis=0
-            )
+            summed_cohp[Spin.up] = np.sum([summed_cohp[Spin.up], cohp_here.cohp[Spin.up]], axis=0)
             if Spin.down in summed_cohp:
-                summed_cohp[Spin.down] = np.sum(
-                    [summed_cohp[Spin.down], cohp_here.cohp[Spin.down]], axis=0
-                )
-            summed_icohp[Spin.up] = np.sum(
-                [summed_icohp[Spin.up], cohp_here.icohp[Spin.up]], axis=0
-            )
+                summed_cohp[Spin.down] = np.sum([summed_cohp[Spin.down], cohp_here.cohp[Spin.down]], axis=0)
+            summed_icohp[Spin.up] = np.sum([summed_icohp[Spin.up], cohp_here.icohp[Spin.up]], axis=0)
             if Spin.down in summed_icohp:
-                summed_icohp[Spin.down] = np.sum(
-                    [summed_icohp[Spin.down], cohp_here.icohp[Spin.down]], axis=0
-                )
+                summed_icohp[Spin.down] = np.sum([summed_icohp[Spin.down], cohp_here.icohp[Spin.down]], axis=0)
 
         divided_cohp = {}
         divided_icohp = {}
@@ -444,9 +394,7 @@ class CompleteCohp(Cohp):
             icohp=divided_icohp,
         )
 
-    def get_summed_cohp_by_label_and_orbital_list(
-        self, label_list, orbital_list, divisor=1
-    ):
+    def get_summed_cohp_by_label_and_orbital_list(self, label_list, orbital_list, divisor=1):
         """
         Returns a COHP object that includes a summed COHP divided by divisor
 
@@ -462,27 +410,17 @@ class CompleteCohp(Cohp):
         if not len(label_list) == len(orbital_list):
             raise ValueError("label_list and orbital_list don't have the same length!")
         # check if cohps are spinpolarized or not
-        first_cohpobject = self.get_orbital_resolved_cohp(
-            label_list[0], orbital_list[0]
-        )
+        first_cohpobject = self.get_orbital_resolved_cohp(label_list[0], orbital_list[0])
         summed_cohp = first_cohpobject.cohp.copy()
         summed_icohp = first_cohpobject.icohp.copy()
         for ilabel, label in enumerate(label_list[1:], 1):
             cohp_here = self.get_orbital_resolved_cohp(label, orbital_list[ilabel])
-            summed_cohp[Spin.up] = np.sum(
-                [summed_cohp[Spin.up], cohp_here.cohp.copy()[Spin.up]], axis=0
-            )
+            summed_cohp[Spin.up] = np.sum([summed_cohp[Spin.up], cohp_here.cohp.copy()[Spin.up]], axis=0)
             if Spin.down in summed_cohp:
-                summed_cohp[Spin.down] = np.sum(
-                    [summed_cohp[Spin.down], cohp_here.cohp.copy()[Spin.down]], axis=0
-                )
-            summed_icohp[Spin.up] = np.sum(
-                [summed_icohp[Spin.up], cohp_here.icohp.copy()[Spin.up]], axis=0
-            )
+                summed_cohp[Spin.down] = np.sum([summed_cohp[Spin.down], cohp_here.cohp.copy()[Spin.down]], axis=0)
+            summed_icohp[Spin.up] = np.sum([summed_icohp[Spin.up], cohp_here.icohp.copy()[Spin.up]], axis=0)
             if Spin.down in summed_icohp:
-                summed_icohp[Spin.down] = np.sum(
-                    [summed_icohp[Spin.down], cohp_here.icohp.copy()[Spin.down]], axis=0
-                )
+                summed_icohp[Spin.down] = np.sum([summed_icohp[Spin.down], cohp_here.icohp.copy()[Spin.down]], axis=0)
 
         divided_cohp = {}
         divided_icohp = {}
@@ -564,25 +502,16 @@ class CompleteCohp(Cohp):
             bonds = {
                 bond: {
                     "length": d["bonds"][bond]["length"],
-                    "sites": tuple(
-                        PeriodicSite.from_dict(site)
-                        for site in d["bonds"][bond]["sites"]
-                    ),
+                    "sites": tuple(PeriodicSite.from_dict(site) for site in d["bonds"][bond]["sites"]),
                 }
                 for bond in d["bonds"]
             }
         else:
             bonds = None
         for label in d["COHP"]:
-            cohp = {
-                Spin(int(spin)): np.array(d["COHP"][label][spin])
-                for spin in d["COHP"][label]
-            }
+            cohp = {Spin(int(spin)): np.array(d["COHP"][label][spin]) for spin in d["COHP"][label]}
             try:
-                icohp = {
-                    Spin(int(spin)): np.array(d["ICOHP"][label][spin])
-                    for spin in d["ICOHP"][label]
-                }
+                icohp = {Spin(int(spin)): np.array(d["ICOHP"][label][spin]) for spin in d["ICOHP"][label]}
             except KeyError:
                 icohp = None
             if label == "average":
@@ -596,24 +525,17 @@ class CompleteCohp(Cohp):
                 orb_cohp[label] = {}
                 for orb in d["orb_res_cohp"][label]:
                     cohp = {
-                        Spin(int(s)): np.array(
-                            d["orb_res_cohp"][label][orb]["COHP"][s], dtype=float
-                        )
+                        Spin(int(s)): np.array(d["orb_res_cohp"][label][orb]["COHP"][s], dtype=float)
                         for s in d["orb_res_cohp"][label][orb]["COHP"]
                     }
                     try:
                         icohp = {
-                            Spin(int(s)): np.array(
-                                d["orb_res_cohp"][label][orb]["ICOHP"][s], dtype=float
-                            )
+                            Spin(int(s)): np.array(d["orb_res_cohp"][label][orb]["ICOHP"][s], dtype=float)
                             for s in d["orb_res_cohp"][label][orb]["ICOHP"]
                         }
                     except KeyError:
                         icohp = None
-                    orbitals = [
-                        tuple((int(o[0]), Orbital[o[1]]))
-                        for o in d["orb_res_cohp"][label][orb]["orbitals"]
-                    ]
+                    orbitals = [tuple((int(o[0]), Orbital[o[1]])) for o in d["orb_res_cohp"][label][orb]["orbitals"]]
                     orb_cohp[label][orb] = {
                         "COHP": cohp,
                         "ICOHP": icohp,
@@ -626,53 +548,29 @@ class CompleteCohp(Cohp):
                 if label not in d["COHP"] or d["COHP"][label] is None:
                     cohp = {
                         Spin.up: np.sum(
-                            np.array(
-                                [
-                                    orb_cohp[label][orb]["COHP"][Spin.up]
-                                    for orb in orb_cohp[label]
-                                ]
-                            ),
+                            np.array([orb_cohp[label][orb]["COHP"][Spin.up] for orb in orb_cohp[label]]),
                             axis=0,
                         )
                     }
                     try:
                         cohp[Spin.down] = np.sum(
-                            np.array(
-                                [
-                                    orb_cohp[label][orb]["COHP"][Spin.down]
-                                    for orb in orb_cohp[label]
-                                ]
-                            ),
+                            np.array([orb_cohp[label][orb]["COHP"][Spin.down] for orb in orb_cohp[label]]),
                             axis=0,
                         )
                     except KeyError:
                         pass
 
-                orb_res_icohp = None in [
-                    orb_cohp[label][orb]["ICOHP"] for orb in orb_cohp[label]
-                ]
-                if (
-                    label not in d["ICOHP"] or d["ICOHP"][label] is None
-                ) and orb_res_icohp:
+                orb_res_icohp = None in [orb_cohp[label][orb]["ICOHP"] for orb in orb_cohp[label]]
+                if (label not in d["ICOHP"] or d["ICOHP"][label] is None) and orb_res_icohp:
                     icohp = {
                         Spin.up: np.sum(
-                            np.array(
-                                [
-                                    orb_cohp[label][orb]["ICOHP"][Spin.up]
-                                    for orb in orb_cohp[label]
-                                ]
-                            ),
+                            np.array([orb_cohp[label][orb]["ICOHP"][Spin.up] for orb in orb_cohp[label]]),
                             axis=0,
                         )
                     }
                     try:
                         icohp[Spin.down] = np.sum(
-                            np.array(
-                                [
-                                    orb_cohp[label][orb]["ICOHP"][Spin.down]
-                                    for orb in orb_cohp[label]
-                                ]
-                            ),
+                            np.array([orb_cohp[label][orb]["ICOHP"][Spin.down] for orb in orb_cohp[label]]),
                             axis=0,
                         )
                     except KeyError:
@@ -684,9 +582,7 @@ class CompleteCohp(Cohp):
             # calculate average
             cohp = np.array([np.array(c) for c in d["COHP"].values()]).mean(axis=0)
             try:
-                icohp = np.array([np.array(c) for c in d["ICOHP"].values()]).mean(
-                    axis=0
-                )
+                icohp = np.array([np.array(c) for c in d["ICOHP"].values()]).mean(axis=0)
             except KeyError:
                 icohp = None
             avg_cohp = Cohp(efermi, energies, cohp, icohp=icohp)
@@ -747,9 +643,7 @@ class CompleteCohp(Cohp):
             cohp_file = Cohpcar(filename=filename, are_coops=are_coops)
             orb_res_cohp = cohp_file.orb_res_cohp
         else:
-            raise ValueError(
-                "Unknown format %s. Valid formats are LMTO " "and LOBSTER." % fmt
-            )
+            raise ValueError("Unknown format %s. Valid formats are LMTO " "and LOBSTER." % fmt)
 
         structure = Structure.from_file(structure_file)
         efermi = cohp_file.efermi
@@ -775,10 +669,7 @@ class CompleteCohp(Cohp):
                     # print(label)
                     cohp_data[label]["COHP"] = {
                         sp: np.sum(
-                            [
-                                orb_res_cohp[label][orbs]["COHP"][sp]
-                                for orbs in orb_res_cohp[label]
-                            ],
+                            [orb_res_cohp[label][orbs]["COHP"][sp] for orbs in orb_res_cohp[label]],
                             axis=0,
                         )
                         for sp in spins
@@ -786,10 +677,7 @@ class CompleteCohp(Cohp):
                 if cohp_file.cohp_data[label]["ICOHP"] is None:
                     cohp_data[label]["ICOHP"] = {
                         sp: np.sum(
-                            [
-                                orb_res_cohp[label][orbs]["ICOHP"][sp]
-                                for orbs in orb_res_cohp[label]
-                            ],
+                            [orb_res_cohp[label][orbs]["ICOHP"][sp] for orbs in orb_res_cohp[label]],
                             axis=0,
                         )
                         for sp in spins
@@ -804,13 +692,7 @@ class CompleteCohp(Cohp):
                     rows = np.array([cohp_data[label][i][spin] for label in cohp_data])
                     avg = np.average(rows, axis=0)
                     # LMTO COHPs have 5 significant figures
-                    avg_data[i].update(
-                        {
-                            spin: np.array(
-                                [round_to_sigfigs(a, 5) for a in avg], dtype=float
-                            )
-                        }
-                    )
+                    avg_data[i].update({spin: np.array([round_to_sigfigs(a, 5) for a in avg], dtype=float)})
             avg_cohp = Cohp(efermi, energies, avg_data["COHP"], icohp=avg_data["ICOHP"])
         else:
             avg_cohp = Cohp(
@@ -869,9 +751,7 @@ class IcohpValue(MSONable):
 
     """
 
-    def __init__(
-        self, label, atom1, atom2, length, translation, num, icohp, are_coops=False
-    ):
+    def __init__(self, label, atom1, atom2, length, translation, num, icohp, are_coops=False):
         """
         Args:
             label: label for the icohp
@@ -1106,9 +986,7 @@ class IcohpCollection(MSONable):
             return icohp_here.icohpvalue(spin)
         return icohp_here.icohpvalue(spin)
 
-    def get_summed_icohp_by_label_list(
-        self, label_list, divisor=1.0, summed_spin_channels=True, spin=Spin.up
-    ):
+    def get_summed_icohp_by_label_list(self, label_list, divisor=1.0, summed_spin_channels=True, spin=Spin.up):
         """
         get the sum of several ICOHP values that are indicated by a list of labels (labels of the bonds are the same as
         in ICOHPLIST/ICOOPLIST)
@@ -1126,9 +1004,7 @@ class IcohpCollection(MSONable):
         for label in label_list:
             icohp_here = self._icohplist[label]
             if icohp_here.num_bonds != 1:
-                warnings.warn(
-                    "One of the ICOHP values is an average over bonds. This is currently not considered."
-                )
+                warnings.warn("One of the ICOHP values is an average over bonds. This is currently not considered.")
             # prints warning if num_bonds is not equal to 1
             if icohp_here._is_spin_polarized:
                 if summed_spin_channels:
@@ -1193,11 +1069,7 @@ class IcohpCollection(MSONable):
                     second_test = True
                 else:
                     second_test = re.split(r"(\d+)", value._atom2)[0] in only_bonds_to
-                if (
-                    value._length >= minbondlength
-                    and value._length <= maxbondlength
-                    and second_test
-                ):
+                if value._length >= minbondlength and value._length <= maxbondlength and second_test:
                     if minsummedicohp is not None:
                         if value.summed_icohp >= minsummedicohp:
                             if maxsummedicohp is not None:
@@ -1231,9 +1103,7 @@ class IcohpCollection(MSONable):
 
         if not self._is_spin_polarized:
             if spin == Spin.down:
-                warnings.warn(
-                    "This spin channel does not exist. I am switching to Spin.up"
-                )
+                warnings.warn("This spin channel does not exist. I am switching to Spin.up")
             spin = Spin.up
 
         for value in self._icohplist.values():
