@@ -8,16 +8,19 @@ This module defines classes to represent the density of states, etc.
 
 import functools
 import warnings
+from typing import Dict
 
 import numpy as np
 from monty.json import MSONable
 from scipy.constants.codata import value as _cd
 
 from pymatgen.core.periodic_table import get_el_sp
+from pymatgen.core.sites import PeriodicSite
 from pymatgen.core.spectrum import Spectrum
 from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.core import Orbital, Spin
 from pymatgen.util.coord import get_linear_interpolated_value
+from pymatgen.util.typing import ArrayLike, SpeciesLike
 
 
 class DOS(Spectrum):
@@ -41,7 +44,7 @@ class DOS(Spectrum):
     XLABEL = "Energy"
     YLABEL = "Density"
 
-    def __init__(self, energies, densities, efermi):
+    def __init__(self, energies: ArrayLike, densities: ArrayLike, efermi: float):
         """
         Args:
             energies: A sequence of energies
@@ -53,7 +56,7 @@ class DOS(Spectrum):
         super().__init__(energies, densities, efermi)
         self.efermi = efermi
 
-    def get_interpolated_gap(self, tol=0.001, abs_tol=False, spin=None):
+    def get_interpolated_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin = None):
         """
         Expects a DOS object and finds the gap
 
@@ -64,26 +67,22 @@ class DOS(Spectrum):
             spin: Possible values are None - finds the gap in the summed
                 densities, Up - finds the gap in the up spin channel,
                 Down - finds the gap in the down spin channel.
-
         Returns:
             (gap, cbm, vbm):
                 Tuple of floats in eV corresponding to the gap, cbm and vbm.
         """
+        if spin is None:
+            tdos = self.y if len(self.ydim) == 1 else np.sum(self.y, axis=1)
+        elif spin == Spin.up:
+            tdos = self.y[:, 0]
+        else:
+            tdos = self.y[:, 1]
 
-        tdos = self.y if len(self.ydim) == 1 else np.sum(self.y, axis=1)
         if not abs_tol:
-            tol = tol * tdos.sum() / tdos.shape[0]
+            tol = tol * tdos.sum() / tdos.shape[0]  # type: ignore
         energies = self.x
-        below_fermi = [
-            i
-            for i in range(len(energies))
-            if energies[i] < self.efermi and tdos[i] > tol
-        ]
-        above_fermi = [
-            i
-            for i in range(len(energies))
-            if energies[i] > self.efermi and tdos[i] > tol
-        ]
+        below_fermi = [i for i in range(len(energies)) if energies[i] < self.efermi and tdos[i] > tol]
+        above_fermi = [i for i in range(len(energies)) if energies[i] > self.efermi and tdos[i] > tol]
         vbm_start = max(below_fermi)
         cbm_start = min(above_fermi)
         if vbm_start == cbm_start:
@@ -97,7 +96,7 @@ class DOS(Spectrum):
         end = get_linear_interpolated_value(terminal_dens, terminal_energies, tol)
         return end - start, end, start
 
-    def get_cbm_vbm(self, tol=0.001, abs_tol=False, spin=None):
+    def get_cbm_vbm(self, tol: float = 0.001, abs_tol: bool = False, spin=None):
         """
         Expects a DOS object and finds the cbm and vbm.
 
@@ -120,7 +119,7 @@ class DOS(Spectrum):
             tdos = self.y[:, 1]
 
         if not abs_tol:
-            tol = tol * tdos.sum() / tdos.shape[0]
+            tol = tol * tdos.sum() / tdos.shape[0]  # type: ignore
 
         # find index of fermi energy
         i_fermi = 0
@@ -139,7 +138,7 @@ class DOS(Spectrum):
         i_gap_end -= 1
         return self.x[i_gap_end], self.x[i_gap_start]
 
-    def get_gap(self, tol=0.001, abs_tol=False, spin=None):
+    def get_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin = None):
         """
         Expects a DOS object and finds the gap.
 
@@ -161,21 +160,15 @@ class DOS(Spectrum):
         Returns a string which can be easily plotted (using gnuplot).
         """
         if Spin.down in self.densities:
-            stringarray = [
-                "#{:30s} {:30s} {:30s}".format("Energy", "DensityUp", "DensityDown")
-            ]
+            stringarray = ["#{:30s} {:30s} {:30s}".format("Energy", "DensityUp", "DensityDown")]
             for i, energy in enumerate(self.energies):
                 stringarray.append(
-                    "{:.5f} {:.5f} {:.5f}".format(
-                        energy, self.densities[Spin.up][i], self.densities[Spin.down][i]
-                    )
+                    "{:.5f} {:.5f} {:.5f}".format(energy, self.densities[Spin.up][i], self.densities[Spin.down][i])
                 )
         else:
             stringarray = ["#{:30s} {:30s}".format("Energy", "DensityUp")]
             for i, energy in enumerate(self.energies):
-                stringarray.append(
-                    "{:.5f} {:.5f}".format(energy, self.densities[Spin.up][i])
-                )
+                stringarray.append("{:.5f} {:.5f}".format(energy, self.densities[Spin.up][i]))
         return "\n".join(stringarray)
 
 
@@ -197,7 +190,7 @@ class Dos(MSONable):
         Fermi level
     """
 
-    def __init__(self, efermi, energies, densities):
+    def __init__(self, efermi: float, energies: ArrayLike, densities: Dict[Spin, ArrayLike]):
         """
         Args:
             efermi: Fermi level energy
@@ -209,7 +202,7 @@ class Dos(MSONable):
         self.energies = np.array(energies)
         self.densities = {k: np.array(d) for k, d in densities.items()}
 
-    def get_densities(self, spin=None):
+    def get_densities(self, spin: Spin = None):
         """
         Returns the density of states for a particular spin.
 
@@ -231,7 +224,7 @@ class Dos(MSONable):
             result = self.densities[spin]
         return result
 
-    def get_smeared_densities(self, sigma):
+    def get_smeared_densities(self, sigma: float):
         """
         Returns the Dict representation of the densities, {Spin: densities},
         but with a Gaussian smearing of std dev sigma applied about the fermi
@@ -246,10 +239,7 @@ class Dos(MSONable):
         from scipy.ndimage.filters import gaussian_filter1d
 
         smeared_dens = {}
-        diff = [
-            self.energies[i + 1] - self.energies[i]
-            for i in range(len(self.energies) - 1)
-        ]
+        diff = [self.energies[i + 1] - self.energies[i] for i in range(len(self.energies) - 1)]
         avgdiff = sum(diff) / len(diff)
         for spin, dens in self.densities.items():
             smeared_dens[spin] = gaussian_filter1d(dens, sigma / avgdiff)
@@ -268,13 +258,10 @@ class Dos(MSONable):
         """
         if not all(np.equal(self.energies, other.energies)):
             raise ValueError("Energies of both DOS are not compatible!")
-        densities = {
-            spin: self.densities[spin] + other.densities[spin]
-            for spin in self.densities.keys()
-        }
+        densities = {spin: self.densities[spin] + other.densities[spin] for spin in self.densities.keys()}
         return Dos(self.efermi, self.energies, densities)
 
-    def get_interpolated_value(self, energy):
+    def get_interpolated_value(self, energy: float):
         """
         Returns interpolated density for a particular energy.
 
@@ -283,12 +270,10 @@ class Dos(MSONable):
         """
         f = {}
         for spin in self.densities.keys():
-            f[spin] = get_linear_interpolated_value(
-                self.energies, self.densities[spin], energy
-            )
+            f[spin] = get_linear_interpolated_value(self.energies, self.densities[spin], energy)
         return f
 
-    def get_interpolated_gap(self, tol=0.001, abs_tol=False, spin=None):
+    def get_interpolated_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin = None):
         """
         Expects a DOS object and finds the gap
 
@@ -309,16 +294,8 @@ class Dos(MSONable):
         if not abs_tol:
             tol = tol * tdos.sum() / tdos.shape[0]
         energies = self.energies
-        below_fermi = [
-            i
-            for i in range(len(energies))
-            if energies[i] < self.efermi and tdos[i] > tol
-        ]
-        above_fermi = [
-            i
-            for i in range(len(energies))
-            if energies[i] > self.efermi and tdos[i] > tol
-        ]
+        below_fermi = [i for i in range(len(energies)) if energies[i] < self.efermi and tdos[i] > tol]
+        above_fermi = [i for i in range(len(energies)) if energies[i] > self.efermi and tdos[i] > tol]
         vbm_start = max(below_fermi)
         cbm_start = min(above_fermi)
         if vbm_start == cbm_start:
@@ -333,7 +310,7 @@ class Dos(MSONable):
         end = get_linear_interpolated_value(terminal_dens, terminal_energies, tol)
         return end - start, end, start
 
-    def get_cbm_vbm(self, tol=0.001, abs_tol=False, spin=None):
+    def get_cbm_vbm(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin = None):
         """
         Expects a DOS object and finds the cbm and vbm.
 
@@ -369,7 +346,7 @@ class Dos(MSONable):
         i_gap_end -= 1
         return self.energies[i_gap_end], self.energies[i_gap_start]
 
-    def get_gap(self, tol=0.001, abs_tol=False, spin=None):
+    def get_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin = None):
         """
         Expects a DOS object and finds the gap.
 
@@ -391,25 +368,19 @@ class Dos(MSONable):
         Returns a string which can be easily plotted (using gnuplot).
         """
         if Spin.down in self.densities:
-            stringarray = [
-                "#{:30s} {:30s} {:30s}".format("Energy", "DensityUp", "DensityDown")
-            ]
+            stringarray = ["#{:30s} {:30s} {:30s}".format("Energy", "DensityUp", "DensityDown")]
             for i, energy in enumerate(self.energies):
                 stringarray.append(
-                    "{:.5f} {:.5f} {:.5f}".format(
-                        energy, self.densities[Spin.up][i], self.densities[Spin.down][i]
-                    )
+                    "{:.5f} {:.5f} {:.5f}".format(energy, self.densities[Spin.up][i], self.densities[Spin.down][i])
                 )
         else:
             stringarray = ["#{:30s} {:30s}".format("Energy", "DensityUp")]
             for i, energy in enumerate(self.energies):
-                stringarray.append(
-                    "{:.5f} {:.5f}".format(energy, self.densities[Spin.up][i])
-                )
+                stringarray.append("{:.5f} {:.5f}".format(energy, self.densities[Spin.up][i]))
         return "\n".join(stringarray)
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, d) -> "Dos":
         """
         Returns Dos object from dict representation of Dos.
         """
@@ -419,7 +390,7 @@ class Dos(MSONable):
             {Spin(int(k)): v for k, v in d["densities"].items()},
         )
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """
         Json-serializable dict representation of Dos.
         """
@@ -428,9 +399,7 @@ class Dos(MSONable):
             "@class": self.__class__.__name__,
             "efermi": self.efermi,
             "energies": list(self.energies),
-            "densities": {
-                str(spin): list(dens) for spin, dens in self.densities.items()
-            },
+            "densities": {str(spin): list(dens) for spin, dens in self.densities.items()},
         }
 
 
@@ -472,9 +441,7 @@ class FermiDos(Dos, MSONable):
             if hasattr(dos, "structure"):
                 structure = dos.structure
             else:
-                raise ValueError(
-                    "Structure object is not provided and not " "present in dos"
-                )
+                raise ValueError("Structure object is not provided and not " "present in dos")
 
         self.structure = structure
         self.nelecs = nelecs or self.structure.composition.total_electrons
@@ -485,13 +452,11 @@ class FermiDos(Dos, MSONable):
 
         # normalize total density of states based on integral at 0K
         tdos = np.array(self.get_densities())
-        self.tdos = (
-            tdos * self.nelecs / (tdos * self.de)[self.energies <= self.efermi].sum()
-        )
+        self.tdos = tdos * self.nelecs / (tdos * self.de)[self.energies <= self.efermi].sum()
 
         ecbm, evbm = self.get_cbm_vbm()
-        self.idx_vbm = np.argmin(abs(self.energies - evbm))
-        self.idx_cbm = np.argmin(abs(self.energies - ecbm))
+        self.idx_vbm = int(np.argmin(abs(self.energies - evbm)))
+        self.idx_cbm = int(np.argmin(abs(self.energies - ecbm)))
         self.A_to_cm = 1e-8
 
         if bandgap:
@@ -500,7 +465,7 @@ class FermiDos(Dos, MSONable):
             else:
                 eref = (evbm + ecbm) / 2.0
 
-            idx_fermi = np.argmin(abs(self.energies - eref))
+            idx_fermi = int(np.argmin(abs(self.energies - eref)))
 
             if idx_fermi == self.idx_vbm:
                 # Fermi level and vbm should be different indices
@@ -541,12 +506,7 @@ class FermiDos(Dos, MSONable):
         return (vb_integral - cb_integral) / (self.volume * self.A_to_cm ** 3)
 
     def get_fermi_interextrapolated(
-        self,
-        concentration: float,
-        temperature: float,
-        warn: bool = True,
-        c_ref: float = 1e10,
-        **kwargs
+        self, concentration: float, temperature: float, warn: bool = True, c_ref: float = 1e10, **kwargs
     ) -> float:
         """
         Similar to get_fermi except that when get_fermi fails to converge,
@@ -581,34 +541,20 @@ class FermiDos(Dos, MSONable):
                 # max(10, ) is to avoid log(0<x<1) and log(1+x) both of which
                 # are slow
                 f2 = self.get_fermi_interextrapolated(
-                    max(10, abs(concentration) * 10.0),
-                    temperature,
-                    warn=False,
-                    **kwargs
+                    max(10, abs(concentration) * 10.0), temperature, warn=False, **kwargs
                 )
                 f1 = self.get_fermi_interextrapolated(
-                    -max(10, abs(concentration) * 10.0),
-                    temperature,
-                    warn=False,
-                    **kwargs
+                    -max(10, abs(concentration) * 10.0), temperature, warn=False, **kwargs
                 )
                 c2 = np.log(abs(1 + self.get_doping(f2, temperature)))
                 c1 = -np.log(abs(1 + self.get_doping(f1, temperature)))
                 slope = (f2 - f1) / (c2 - c1)
-                return f2 + slope * (
-                    np.sign(concentration) * np.log(abs(1 + concentration)) - c2
-                )
+                return f2 + slope * (np.sign(concentration) * np.log(abs(1 + concentration)) - c2)
 
-            f_ref = self.get_fermi_interextrapolated(
-                np.sign(concentration) * c_ref, temperature, warn=False, **kwargs
-            )
-            f_new = self.get_fermi_interextrapolated(
-                concentration / 10.0, temperature, warn=False, **kwargs
-            )
+            f_ref = self.get_fermi_interextrapolated(np.sign(concentration) * c_ref, temperature, warn=False, **kwargs)
+            f_new = self.get_fermi_interextrapolated(concentration / 10.0, temperature, warn=False, **kwargs)
             clog = np.sign(concentration) * np.log(abs(concentration))
-            c_newlog = np.sign(concentration) * np.log(
-                abs(self.get_doping(f_new, temperature))
-            )
+            c_newlog = np.sign(concentration) * np.log(abs(self.get_doping(f_new, temperature)))
             slope = (f_new - f_ref) / (c_newlog - np.sign(concentration) * 10.0)
             return f_new + slope * (clog - c_newlog)
 
@@ -651,15 +597,11 @@ class FermiDos(Dos, MSONable):
             step /= 10.0
 
         if min(relative_error) > rtol:
-            raise ValueError(
-                "Could not find fermi within {}% of concentration={}".format(
-                    rtol * 100, concentration
-                )
-            )
+            raise ValueError("Could not find fermi within {}% of concentration={}".format(rtol * 100, concentration))
         return fermi
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, d) -> "FermiDos":
         """
         Returns Dos object from dict representation of Dos.
         """
@@ -668,11 +610,9 @@ class FermiDos(Dos, MSONable):
             d["energies"],
             {Spin(int(k)): v for k, v in d["densities"].items()},
         )
-        return FermiDos(
-            dos, structure=Structure.from_dict(d["structure"]), nelecs=d["nelecs"]
-        )
+        return FermiDos(dos, structure=Structure.from_dict(d["structure"]), nelecs=d["nelecs"])
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """
         Json-serializable dict representation of Dos.
         """
@@ -681,9 +621,7 @@ class FermiDos(Dos, MSONable):
             "@class": self.__class__.__name__,
             "efermi": self.efermi,
             "energies": list(self.energies),
-            "densities": {
-                str(spin): list(dens) for spin, dens in self.densities.items()
-            },
+            "densities": {str(spin): list(dens) for spin, dens in self.densities.items()},
             "structure": self.structure,
             "nelecs": self.nelecs,
         }
@@ -705,7 +643,9 @@ class CompleteDos(Dos):
         Dict of partial densities of the form {Site:{Orbital:{Spin:Densities}}}
     """
 
-    def __init__(self, structure, total_dos, pdoss):
+    def __init__(
+        self, structure: Structure, total_dos: Dos, pdoss: Dict[PeriodicSite, Dict[Orbital, Dict[Spin, ArrayLike]]]
+    ):
         """
         Args:
             structure: Structure associated with this particular DOS.
@@ -721,7 +661,7 @@ class CompleteDos(Dos):
         self.pdos = pdoss
         self.structure = structure
 
-    def get_site_orbital_dos(self, site, orbital):
+    def get_site_orbital_dos(self, site: PeriodicSite, orbital: Orbital) -> Dos:
         """
         Get the Dos for a particular orbital of a particular site.
 
@@ -734,7 +674,7 @@ class CompleteDos(Dos):
         """
         return Dos(self.efermi, self.energies, self.pdos[site][orbital])
 
-    def get_site_dos(self, site):
+    def get_site_dos(self, site: PeriodicSite) -> Dos:
         """
         Get the total Dos for a site (all orbitals).
 
@@ -747,7 +687,7 @@ class CompleteDos(Dos):
         site_dos = functools.reduce(add_densities, self.pdos[site].values())
         return Dos(self.efermi, self.energies, site_dos)
 
-    def get_site_spd_dos(self, site):
+    def get_site_spd_dos(self, site: PeriodicSite) -> Dict[Orbital, Dos]:
         """
         Get orbital projected Dos of a particular site
 
@@ -757,19 +697,16 @@ class CompleteDos(Dos):
         Returns:
             dict of {orbital: Dos}, e.g. {"s": Dos object, ...}
         """
-        spd_dos = dict()
+        spd_dos: Dict[Orbital, Dict[Spin, ArrayLike]] = dict()
         for orb, pdos in self.pdos[site].items():
             orbital_type = _get_orb_type(orb)
             if orbital_type in spd_dos:
                 spd_dos[orbital_type] = add_densities(spd_dos[orbital_type], pdos)
             else:
                 spd_dos[orbital_type] = pdos
-        return {
-            orb: Dos(self.efermi, self.energies, densities)
-            for orb, densities in spd_dos.items()
-        }
+        return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in spd_dos.items()}
 
-    def get_site_t2g_eg_resolved_dos(self, site):
+    def get_site_t2g_eg_resolved_dos(self, site: PeriodicSite) -> Dict[str, Dos]:
         """
         Get the t2g, eg projected DOS for a particular site.
 
@@ -790,15 +727,11 @@ class CompleteDos(Dos):
                     elif orb in (Orbital.dx2, Orbital.dz2):
                         eg_dos.append(pdos)
         return {
-            "t2g": Dos(
-                self.efermi, self.energies, functools.reduce(add_densities, t2g_dos)
-            ),
-            "e_g": Dos(
-                self.efermi, self.energies, functools.reduce(add_densities, eg_dos)
-            ),
+            "t2g": Dos(self.efermi, self.energies, functools.reduce(add_densities, t2g_dos)),
+            "e_g": Dos(self.efermi, self.energies, functools.reduce(add_densities, eg_dos)),
         }
 
-    def get_spd_dos(self):
+    def get_spd_dos(self) -> Dict[Orbital, Dos]:
         """
         Get orbital projected Dos.
 
@@ -813,12 +746,9 @@ class CompleteDos(Dos):
                     spd_dos[orbital_type] = pdos
                 else:
                     spd_dos[orbital_type] = add_densities(spd_dos[orbital_type], pdos)
-        return {
-            orb: Dos(self.efermi, self.energies, densities)
-            for orb, densities in spd_dos.items()
-        }
+        return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in spd_dos.items()}
 
-    def get_element_dos(self):
+    def get_element_dos(self) -> Dict[SpeciesLike, Dos]:
         """
         Get element projected Dos.
 
@@ -834,12 +764,9 @@ class CompleteDos(Dos):
                     el_dos[el] = pdos
                 else:
                     el_dos[el] = add_densities(el_dos[el], pdos)
-        return {
-            el: Dos(self.efermi, self.energies, densities)
-            for el, densities in el_dos.items()
-        }
+        return {el: Dos(self.efermi, self.energies, densities) for el, densities in el_dos.items()}
 
-    def get_element_spd_dos(self, el):
+    def get_element_spd_dos(self, el: SpeciesLike) -> Dict[Orbital, Dos]:
         """
         Get element and spd projected Dos
 
@@ -860,13 +787,10 @@ class CompleteDos(Dos):
                     else:
                         el_dos[orbital_type] = add_densities(el_dos[orbital_type], pdos)
 
-        return {
-            orb: Dos(self.efermi, self.energies, densities)
-            for orb, densities in el_dos.items()
-        }
+        return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in el_dos.items()}
 
     @property
-    def spin_polarization(self):
+    def spin_polarization(self) -> float:
         """
         Calculates spin polarization at Fermi level.
 
@@ -891,7 +815,7 @@ class CompleteDos(Dos):
         return abs(spin_polarization)
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, d) -> "CompleteDos":
         """
         Returns CompleteDos object from dict representation.
         """
@@ -907,7 +831,7 @@ class CompleteDos(Dos):
             pdoss[at] = orb_dos
         return CompleteDos(struct, tdos, pdoss)
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """
         Json-serializable dict representation of CompleteDos.
         """
@@ -917,9 +841,7 @@ class CompleteDos(Dos):
             "efermi": self.efermi,
             "structure": self.structure.as_dict(),
             "energies": list(self.energies),
-            "densities": {
-                str(spin): list(dens) for spin, dens in self.densities.items()
-            },
+            "densities": {str(spin): list(dens) for spin, dens in self.densities.items()},
             "pdos": [],
         }
         if len(self.pdos) > 0:
@@ -927,17 +849,11 @@ class CompleteDos(Dos):
                 dd = {}
                 for orb, pdos in self.pdos[at].items():
                     dd[str(orb)] = {
-                        "densities": {
-                            str(int(spin)): list(dens) for spin, dens in pdos.items()
-                        }
+                        "densities": {str(int(spin)): list(dens) for spin, dens in pdos.items()}  # type: ignore
                     }
                 d["pdos"].append(dd)
-            d["atom_dos"] = {
-                str(at): dos.as_dict() for at, dos in self.get_element_dos().items()
-            }
-            d["spd_dos"] = {
-                str(orb): dos.as_dict() for orb, dos in self.get_spd_dos().items()
-            }
+            d["atom_dos"] = {str(at): dos.as_dict() for at, dos in self.get_element_dos().items()}
+            d["spd_dos"] = {str(orb): dos.as_dict() for orb, dos in self.get_spd_dos().items()}
         return d
 
     def __str__(self):
@@ -949,7 +865,7 @@ class LobsterCompleteDos(CompleteDos):
     Extended CompleteDOS for Lobster
     """
 
-    def get_site_orbital_dos(self, site, orbital):
+    def get_site_orbital_dos(self, site: PeriodicSite, orbital: str) -> Dos:  # type: ignore
         """
         Get the Dos for a particular orbital of a particular site.
 
@@ -983,9 +899,9 @@ class LobsterCompleteDos(CompleteDos):
             "f_x(x^2-3y^2)",
         ]:
             raise ValueError("orbital is not correct")
-        return Dos(self.efermi, self.energies, self.pdos[site][orbital])
+        return Dos(self.efermi, self.energies, self.pdos[site][orbital])  # type: ignore
 
-    def get_site_t2g_eg_resolved_dos(self, site):
+    def get_site_t2g_eg_resolved_dos(self, site: PeriodicSite) -> Dict[str, Dos]:
         """
         Get the t2g, eg projected DOS for a particular site.
         Args:
@@ -1009,15 +925,11 @@ class LobsterCompleteDos(CompleteDos):
                     elif _get_orb_lobster(orb) in (Orbital.dx2, Orbital.dz2):
                         eg_dos.append(pdos)
         return {
-            "t2g": Dos(
-                self.efermi, self.energies, functools.reduce(add_densities, t2g_dos)
-            ),
-            "e_g": Dos(
-                self.efermi, self.energies, functools.reduce(add_densities, eg_dos)
-            ),
+            "t2g": Dos(self.efermi, self.energies, functools.reduce(add_densities, t2g_dos)),
+            "e_g": Dos(self.efermi, self.energies, functools.reduce(add_densities, eg_dos)),
         }
 
-    def get_spd_dos(self):
+    def get_spd_dos(self) -> Dict[str, Dos]:  # type: ignore
         """
         Get orbital projected Dos.
         For example, if 3s and 4s are included in the basis of some element, they will be both summed in the orbital
@@ -1035,12 +947,9 @@ class LobsterCompleteDos(CompleteDos):
                 else:
                     spd_dos[orbital_type] = add_densities(spd_dos[orbital_type], pdos)
 
-        return {
-            orb: Dos(self.efermi, self.energies, densities)
-            for orb, densities in spd_dos.items()
-        }
+        return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in spd_dos.items()}
 
-    def get_element_spd_dos(self, el):
+    def get_element_spd_dos(self, el: SpeciesLike) -> Dict[str, Dos]:  # type: ignore
         """
         Get element and spd projected Dos
 
@@ -1049,7 +958,7 @@ class LobsterCompleteDos(CompleteDos):
             el: Element in Structure.composition associated with LobsterCompleteDos
 
         Returns:
-            dict of {Element: {"S": densities, "P": densities, "D": densities}}
+            dict of {"S": densities, "P": densities, "D": densities}
         """
         el = get_el_sp(el)
         el_dos = {}
@@ -1062,13 +971,10 @@ class LobsterCompleteDos(CompleteDos):
                     else:
                         el_dos[orbital_type] = add_densities(el_dos[orbital_type], pdos)
 
-        return {
-            orb: Dos(self.efermi, self.energies, densities)
-            for orb, densities in el_dos.items()
-        }
+        return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in el_dos.items()}
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, d) -> "LobsterCompleteDos":
         """
         Returns: CompleteDos object from dict representation.
         """
@@ -1085,7 +991,7 @@ class LobsterCompleteDos(CompleteDos):
         return LobsterCompleteDos(struct, tdos, pdoss)
 
 
-def add_densities(density1, density2):
+def add_densities(density1: Dict[Spin, ArrayLike], density2: Dict[Spin, ArrayLike]) -> Dict[Spin, ArrayLike]:
     """
     Method to sum two densities.
 
@@ -1096,10 +1002,7 @@ def add_densities(density1, density2):
     Returns:
         Dict of {spin: density}.
     """
-    return {
-        spin: np.array(density1[spin]) + np.array(density2[spin])
-        for spin in density1.keys()
-    }
+    return {spin: np.array(density1[spin]) + np.array(density2[spin]) for spin in density1.keys()}
 
 
 def _get_orb_type(orb):
