@@ -11,11 +11,11 @@ diagram analysis.
 """
 
 import abc
-import copy
 import json
 import os
+import warnings
 from itertools import combinations
-from typing import List, Optional
+from typing import List
 
 import numpy as np
 from monty.json import MontyDecoder, MontyEncoder, MSONable
@@ -34,7 +34,6 @@ __email__ = "shyuep@gmail.com"
 __status__ = "Production"
 __date__ = "April 2020"
 
-
 with open(os.path.join(os.path.dirname(__file__), "data/g_els.json")) as f:
     G_ELEMS = json.load(f)
 with open(os.path.join(os.path.dirname(__file__), "data/nist_gas_gf.json")) as f:
@@ -58,7 +57,7 @@ class EnergyAdjustment(MSONable):
         """
         Args:
             value: float, value of the energy adjustment in eV
-            uncertainty: float, uncertaint of the energy adjustment in eV. Default: np.nan
+            uncertainty: float, uncertainty of the energy adjustment in eV. Default: np.nan
             name: str, human-readable name of the energy adjustment.
                 (Default: Manual adjustment)
             cls: dict, Serialized Compatibility class used to generate the energy adjustment. (Default: None)
@@ -67,31 +66,27 @@ class EnergyAdjustment(MSONable):
         self.name = name
         self.cls = cls if cls else {}
         self.description = description
+        self._value = value
+        self._uncertainty = uncertainty
 
     @property
-    def explain(self):
-        """
-        Return an explanaion of how the energy adjustment is calculated.
-        """
-
-    @property
-    @abc.abstractmethod
     def value(self):
         """
-        Return the value of the energy adjustment in eV
+        Return the value of the energy correction in eV.
         """
+        return self._value
 
     @property
-    @abc.abstractmethod
     def uncertainty(self):
         """
         Return the uncertainty in the value of the energy adjustment in eV
         """
+        return self._uncertainty
 
     @abc.abstractmethod
-    def _normalize(self, factor):
+    def normalize(self, factor):
         """
-        Scale the value of the energy adjustment by factor.
+        Scale the value of the current energy adjustment by factor in-place.
 
         This method is utilized in ComputedEntry.normalize() to scale the energies to a formula unit basis
         (e.g. E_Fe6O9 = 3 x E_Fe2O3).
@@ -133,9 +128,7 @@ class ConstantEnergyAdjustment(EnergyAdjustment):
                 adjustment. (Default: None)
             description: str, human-readable explanation of the energy adjustment.
         """
-        super().__init__(
-            value, uncertainty, name=name, cls=cls, description=description
-        )
+        super().__init__(value, uncertainty, name=name, cls=cls, description=description)
         self._value = value
         self._uncertainty = uncertainty
 
@@ -146,29 +139,12 @@ class ConstantEnergyAdjustment(EnergyAdjustment):
         """
         return self.description + " ({:.3f} eV)".format(self.value)
 
-    @property
-    def value(self):
+    def normalize(self, factor):
         """
-        Return the value of the energy correction in eV.
+        Normalize energy adjustment (in place), dividing value/uncertainty by a
+        factor.
+        :param factor: factor to divide by
         """
-        return self._value
-
-    @value.setter
-    def value(self, x):
-        self._value = x
-
-    @property
-    def uncertainty(self):
-        """
-        Return the uncertainty in the value of the energy adjustment in eV
-        """
-        return self._uncertainty
-
-    @uncertainty.setter
-    def uncertainty(self, x):
-        self._uncertainty = x
-
-    def _normalize(self, factor):
         self._value /= factor
         self._uncertainty /= factor
 
@@ -241,11 +217,14 @@ class CompositionEnergyAdjustment(EnergyAdjustment):
         """
         Return an explanaion of how the energy adjustment is calculated.
         """
-        return self.description + " ({:.3f} eV/atom x {} atoms)".format(
-            self._adj_per_atom, self.n_atoms
-        )
+        return self.description + " ({:.3f} eV/atom x {} atoms)".format(self._adj_per_atom, self.n_atoms)
 
-    def _normalize(self, factor):
+    def normalize(self, factor):
+        """
+        Normalize energy adjustment (in place), dividing value/uncertainty by a
+        factor.
+        :param factor: factor to divide by
+        """
         self.n_atoms /= factor
 
 
@@ -309,7 +288,12 @@ class TemperatureEnergyAdjustment(EnergyAdjustment):
             self._adj_per_deg, self.temp, self.n_atoms
         )
 
-    def _normalize(self, factor):
+    def normalize(self, factor):
+        """
+        Normalize energy adjustment (in place), dividing value/uncertainty by a
+        factor.
+        :param factor: factor to divide by
+        """
         self.n_atoms /= factor
 
 
@@ -340,6 +324,8 @@ class ComputedEntry(Entry):
                 a string formula, and others.
             energy (float): Energy of the entry. Usually the final calculated
                 energy from VASP or other electronic structure codes.
+            correction (float): Manually set an energy correction, will ignore
+                energy_adjustments if specified.
             energy_adjustments: An optional list of EnergyAdjustment to
                 be applied to the energy. This is used to modify the energy for
                 certain analyses. Defaults to None.
@@ -350,7 +336,6 @@ class ComputedEntry(Entry):
             entry_id: An optional id to uniquely identify the entry.
         """
         super().__init__(composition, energy)
-        self.uncorrected_energy = self._energy
         self.energy_adjustments = energy_adjustments if energy_adjustments else []
 
         if correction != 0.0:
@@ -368,6 +353,14 @@ class ComputedEntry(Entry):
         self.entry_id = entry_id
         self.name = self.composition.reduced_formula
 
+    @property
+    def uncorrected_energy(self) -> float:
+        """
+        Returns:
+            float: the *uncorrected* energy of the entry
+        """
+        return self._energy
+
     @property
     def energy(self) -> float:
         """
@@ -392,9 +385,7 @@ class ComputedEntry(Entry):
                 in eV.
         """
         # adds to ufloat(0.0, 0.0) to ensure that no corrections still result in ufloat object
-        corr = ufloat(0.0, 0.0) + sum(
-            [ufloat(ea.value, ea.uncertainty) for ea in self.energy_adjustments]
-        )
+        corr = ufloat(0.0, 0.0) + sum([ufloat(ea.value, ea.uncertainty) for ea in self.energy_adjustments])
         return corr.nominal_value
 
     @correction.setter
@@ -420,9 +411,7 @@ class ComputedEntry(Entry):
         # adds to ufloat(0.0, 0.0) to ensure that no corrections still result in ufloat object
         unc = ufloat(0.0, 0.0) + sum(
             [
-                ufloat(ea.value, ea.uncertainty)
-                if not np.isnan(ea.uncertainty)
-                else ufloat(ea.value, 0)
+                ufloat(ea.value, ea.uncertainty) if not np.isnan(ea.uncertainty) else ufloat(ea.value, 0)
                 for ea in self.energy_adjustments
             ]
         )
@@ -441,9 +430,7 @@ class ComputedEntry(Entry):
         """
         return self.correction_uncertainty / self.composition.num_atoms
 
-    def normalize(
-        self, mode: str = "formula_unit", inplace: bool = True
-    ) -> Optional["ComputedEntry"]:
+    def normalize(self, mode: str = "formula_unit") -> "ComputedEntry":
         """
         Normalize the entry's composition and energy.
 
@@ -451,53 +438,45 @@ class ComputedEntry(Entry):
             mode: "formula_unit" is the default, which normalizes to
                 composition.reduced_formula. The other option is "atom", which
                 normalizes such that the composition amounts sum to 1.
-            inplace: "True" is the default which normalises the current Entry object.
-                Setting inplace to "False" returns a normalized copy of the Entry object.
         """
-        if inplace:
-            factor = self._normalization_factor(mode)
-            self.uncorrected_energy /= factor
-            for ea in self.energy_adjustments:
-                ea._normalize(factor)
-            super().normalize(mode, inplace)
-            return None
-        else:
-            entry = copy.deepcopy(self)
-            factor = entry._normalization_factor(mode)
-            entry.uncorrected_energy /= factor
-            for ea in entry.energy_adjustments:
-                ea._normalize(factor)
-            return super(ComputedEntry, entry).normalize(mode, inplace)
 
-    def __repr__(self):
+        factor = self._normalization_factor(mode)
+        new_composition = self._composition / factor
+        new_energy = self._energy / factor
+
+        new_entry_dict = self.as_dict()
+        new_entry_dict["composition"] = new_composition.as_dict()
+        new_entry_dict["energy"] = new_energy
+
+        # TODO: make sure EnergyAdjustments are _also_ immutable to avoid this hacking
+        new_energy_adjustments = MontyDecoder().process_decoded(new_entry_dict["energy_adjustments"])
+        for ea in new_energy_adjustments:
+            ea.normalize(factor)
+        new_entry_dict["energy_adjustments"] = [ea.as_dict() for ea in new_energy_adjustments]
+
+        return self.from_dict(new_entry_dict)
+
+    def __repr__(self) -> str:
         n_atoms = self.composition.num_atoms
         output = [
             "{} {:<10} - {:<12} ({})".format(
-                str(self.entry_id),
-                type(self).__name__,
+                self.entry_id,
+                self.__class__.__name__,
                 self.composition.formula,
                 self.composition.reduced_formula,
             ),
             "{:<24} = {:<9.4f} eV ({:<8.4f} eV/atom)".format(
                 "Energy (Uncorrected)", self._energy, self._energy / n_atoms
             ),
-            "{:<24} = {:<9.4f} eV ({:<8.4f} eV/atom)".format(
-                "Correction", self.correction, self.correction / n_atoms
-            ),
-            "{:<24} = {:<9.4f} eV ({:<8.4f} eV/atom)".format(
-                "Energy (Final)", self.energy, self.energy_per_atom
-            ),
+            "{:<24} = {:<9.4f} eV ({:<8.4f} eV/atom)".format("Correction", self.correction, self.correction / n_atoms),
+            "{:<24} = {:<9.4f} eV ({:<8.4f} eV/atom)".format("Energy (Final)", self.energy, self.energy_per_atom),
             "Energy Adjustments:",
         ]
         if len(self.energy_adjustments) == 0:
             output.append("  None")
         else:
             for e in self.energy_adjustments:
-                output.append(
-                    "  {:<23}: {:<9.4f} eV ({:<8.4f} eV/atom)".format(
-                        e.name, e.value, e.value / n_atoms
-                    )
-                )
+                output.append("  {:<23}: {:<9.4f} eV ({:<8.4f} eV/atom)".format(e.name, e.value, e.value / n_atoms))
         output.append("Parameters:")
         for k, v in self.parameters.items():
             output.append("  {:<22} = {}".format(k, v))
@@ -509,6 +488,29 @@ class ComputedEntry(Entry):
     def __str__(self):
         return self.__repr__()
 
+    def __eq__(self, other):
+        # NOTE: Scaled duplicates i.e. physically equivalent materials
+        # are not equal unless normalized separately.
+        if self is other:
+            return True
+
+        # Equality is defined based on composition and energy
+        # If structures are involved, it is assumed that a {composition, energy} is
+        # vanishingly unlikely to be the same if the structures are different
+
+        if not np.allclose(self.energy, other.energy):
+            return False
+
+        # if entry_ids are equivalent, skip the more expensive composition check
+        if self.entry_id and other.entry_id and self.entry_id == other.entry_id:
+            return True
+
+        if self.composition != other.composition:
+            return False
+
+        # assumes that data, parameters, corrections are equivalent
+        return True
+
     @classmethod
     def from_dict(cls, d) -> "ComputedEntry":
         """
@@ -523,10 +525,7 @@ class ComputedEntry(Entry):
                 d["composition"],
                 d["energy"],
                 d["correction"],
-                parameters={
-                    k: dec.process_decoded(v)
-                    for k, v in d.get("parameters", {}).items()
-                },
+                parameters={k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()},
                 data={k: dec.process_decoded(v) for k, v in d.get("data", {}).items()},
                 entry_id=d.get("entry_id", None),
             )
@@ -537,12 +536,8 @@ class ComputedEntry(Entry):
             d["composition"],
             d["energy"],
             correction=0,
-            energy_adjustments=[
-                dec.process_decoded(e) for e in d.get("energy_adjustments", {})
-            ],
-            parameters={
-                k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()
-            },
+            energy_adjustments=[dec.process_decoded(e) for e in d.get("energy_adjustments", {})],
+            parameters={k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()},
             data={k: dec.process_decoded(v) for k, v in d.get("data", {}).items()},
             entry_id=d.get("entry_id", None),
         )
@@ -554,17 +549,23 @@ class ComputedEntry(Entry):
         return_dict = super().as_dict()
         return_dict.update(
             {
-                "energy_adjustments": json.loads(
-                    json.dumps(self.energy_adjustments, cls=MontyEncoder)
-                ),
-                "parameters": json.loads(json.dumps(self.parameters, cls=MontyEncoder)),
-                "data": json.loads(json.dumps(self.data, cls=MontyEncoder)),
                 "entry_id": self.entry_id,
                 "correction": self.correction,
+                "energy_adjustments": json.loads(json.dumps(self.energy_adjustments, cls=MontyEncoder)),
+                "parameters": json.loads(json.dumps(self.parameters, cls=MontyEncoder)),
+                "data": json.loads(json.dumps(self.data, cls=MontyEncoder)),
             }
         )
         return return_dict
 
+    def __hash__(self) -> int:
+        # NOTE It is assumed that the user will ensure entry_id is a
+        # unique identifier for ComputedEntry type classes.
+        if self.entry_id is not None:
+            return hash(f"{self.__class__.__name__}{self.entry_id}")
+
+        return super().__hash__()
+
 
 class ComputedStructureEntry(ComputedEntry):
     """
@@ -577,6 +578,7 @@ class ComputedStructureEntry(ComputedEntry):
         structure: Structure,
         energy: float,
         correction: float = 0.0,
+        composition: Composition = None,
         energy_adjustments: list = None,
         parameters: dict = None,
         data: dict = None,
@@ -598,8 +600,19 @@ class ComputedStructureEntry(ComputedEntry):
                 with the entry. Defaults to None.
             entry_id: An optional id to uniquely identify the entry.
         """
+
+        if composition:
+            composition = Composition(composition)
+            if (
+                composition.get_integer_formula_and_factor()[0]
+                != structure.composition.get_integer_formula_and_factor()[0]
+            ):
+                raise ValueError("Mismatching composition provided.")
+        else:
+            composition = structure.composition
+
         super().__init__(
-            structure.composition,
+            composition,
             energy,
             correction=correction,
             energy_adjustments=energy_adjustments,
@@ -607,15 +620,20 @@ class ComputedStructureEntry(ComputedEntry):
             data=data,
             entry_id=entry_id,
         )
-        self.structure = structure
+        self._structure = structure
+
+    @property
+    def structure(self) -> Structure:
+        """
+        :return: the structure of the entry.
+        """
+        return self._structure
 
     def as_dict(self) -> dict:
         """
         :return: MSONAble dict.
         """
         d = super().as_dict()
-        d["@module"] = self.__class__.__module__
-        d["@class"] = self.__class__.__name__
         d["structure"] = self.structure.as_dict()
         return d
 
@@ -629,14 +647,12 @@ class ComputedStructureEntry(ComputedEntry):
         # the first block here is for legacy ComputedEntry that were
         # serialized before we had the energy_adjustments attribute.
         if d["correction"] != 0 and not d.get("energy_adjustments"):
+            struct = dec.process_decoded(d["structure"])
             return cls(
-                dec.process_decoded(d["structure"]),
+                struct,
                 d["energy"],
-                d["correction"],
-                parameters={
-                    k: dec.process_decoded(v)
-                    for k, v in d.get("parameters", {}).items()
-                },
+                correction=d["correction"],
+                parameters={k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()},
                 data={k: dec.process_decoded(v) for k, v in d.get("data", {}).items()},
                 entry_id=d.get("entry_id", None),
             )
@@ -646,17 +662,40 @@ class ComputedStructureEntry(ComputedEntry):
         return cls(
             dec.process_decoded(d["structure"]),
             d["energy"],
+            composition=d.get("composition", None),
             correction=0,
-            energy_adjustments=[
-                dec.process_decoded(e) for e in d.get("energy_adjustments", {})
-            ],
-            parameters={
-                k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()
-            },
+            energy_adjustments=[dec.process_decoded(e) for e in d.get("energy_adjustments", {})],
+            parameters={k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()},
             data={k: dec.process_decoded(v) for k, v in d.get("data", {}).items()},
             entry_id=d.get("entry_id", None),
         )
 
+    def normalize(self, mode: str = "formula_unit") -> "ComputedStructureEntry":
+        """
+        Normalize the entry's composition and energy. The structure remains
+        unchanged.
+        Args:
+            mode: "formula_unit" is the default, which normalizes to
+                composition.reduced_formula. The other option is "atom",
+                which normalizes such that the composition amounts sum to 1.
+        """
+        # TODO this should raise TypeError
+        # raise TypeError("You cannot normalize a structure.")
+        warnings.warn(
+            (
+                f"Normalization of a `{self.__class__.__name__}` makes "
+                "`self.composition` and `self.structure.composition` inconsistent"
+                " - please use self.composition for all further calculations."
+            )
+        )
+        # TODO: find a better solution for creating copies instead of as/from dict
+        factor = self._normalization_factor(mode)
+        d = super().normalize(mode).as_dict()
+        d["structure"] = self.structure.as_dict()
+        entry = self.from_dict(d)
+        entry._composition /= factor
+        return entry
+
 
 class GibbsComputedStructureEntry(ComputedStructureEntry):
     """
@@ -667,9 +706,10 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
     def __init__(
         self,
         structure: Structure,
-        formation_enthalpy: float,
+        formation_enthalpy_per_atom: float,
         temp: float = 300,
         gibbs_model: str = "SISSO",
+        composition: Composition = None,
         correction: float = 0.0,
         energy_adjustments: list = None,
         parameters: dict = None,
@@ -679,14 +719,15 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
         """
         Args:
             structure (Structure): The pymatgen Structure object of an entry.
-            formation_enthalpy (float): Formation enthalpy of the entry, calculated
-                using phase diagram construction (eV)
+            formation_enthalpy_per_atom (float): Formation enthalpy of the entry;
+            must be
+                calculated using phase diagram construction (eV)
             temp (float): Temperature in Kelvin. If temperature is not selected from
                 one of [300, 400, 500, ... 2000 K], then free energies will
                 be interpolated. Defaults to 300 K.
             gibbs_model (str): Model for Gibbs Free energy. Currently the default (and
                 only supported) option is "SISSO", the descriptor created by Bartel et
-                al. (2018).
+                al. (2018) -- see reference in documentation.
             correction (float): A correction to be applied to the energy. Defaults to 0
             parameters (dict): An optional dict of parameters associated with
                 the entry. Defaults to None.
@@ -694,29 +735,21 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
                 with the entry. Defaults to None.
             entry_id: An optional id to uniquely identify the entry.
         """
-        self.structure = structure
-        self.formation_enthalpy = formation_enthalpy
-        self.temp = temp
-        self.interpolated = False
-
-        if self.temp < 300 or self.temp > 2000:
+        if temp < 300 or temp > 2000:
             raise ValueError("Temperature must be selected from range: [300, 2000] K.")
 
-        if self.temp % 100:
-            self.interpolated = True
+        integer_formula, _ = structure.composition.get_integer_formula_and_factor()
 
-        if gibbs_model.lower() == "sisso":
-            gibbs_energy = self.gf_sisso()
-        else:
-            raise ValueError(
-                f"{gibbs_model} not a valid model. Please select from [" f"'SISSO']"
-            )
-
-        self.gibbs_model = gibbs_model
+        self.experimental = False
+        if integer_formula in G_GASES.keys():
+            self.experimental = True
+            if "Experimental" not in str(entry_id):
+                entry_id = f"{entry_id} (Experimental)"
 
         super().__init__(
             structure,
-            energy=gibbs_energy,
+            energy=0,  # placeholder, energy reassigned at end of __init__
+            composition=composition,
             correction=correction,
             energy_adjustments=energy_adjustments,
             parameters=parameters,
@@ -724,14 +757,31 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
             entry_id=entry_id,
         )
 
+        self.temp = temp
+        self.gibbs_model = gibbs_model
+        self.formation_enthalpy_per_atom = formation_enthalpy_per_atom
+
+        self.interpolated = False
+        if self.temp % 100:
+            self.interpolated = True
+
+        if gibbs_model.lower() == "sisso":
+            self.gibbs_fn = self.gf_sisso
+        else:
+            raise ValueError(f"{gibbs_model} not a valid model. The only currently " f"available model is 'SISSO'.")
+
+        self._energy = self.gibbs_fn()
+
     def gf_sisso(self) -> float:
         """
         Gibbs Free Energy of formation as calculated by SISSO descriptor from Bartel
         et al. (2018). Units: eV (not normalized)
 
         WARNING: This descriptor only applies to solids. The implementation here
-        attempts to detect and use downloaded NIST-JANAF data for common gases (e.g.
-        CO2) where possible.
+        attempts to detect and use downloaded NIST-JANAF data for common
+        experimental gases (e.g. CO2) where possible. Note that experimental data is
+        only for Gibbs Free Energy of formation, so expt. entries will register as
+        having a formation enthalpy of 0.
 
         Reference: Bartel, C. J., Millican, S. L., Deml, A. M., Rumptz, J. R.,
         Tumas, W., Weimer, A. W., … Holder, A. M. (2018). Physical descriptor for
@@ -740,32 +790,37 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
         4168. https://doi.org/10.1038/s41467-018-06682-4
 
         Returns:
-            float: Gibbs free energy of formation (eV)
+            float: the difference between formation enthalpy (T=0 K, Materials
+            Project) and the predicted Gibbs free energy of formation  (eV)
         """
-        comp = self.structure.composition
+        comp = self.composition
 
         if comp.is_element:
-            return self.formation_enthalpy
+            return 0
 
-        if comp.reduced_formula in G_GASES.keys():
-            data = G_GASES[comp.reduced_formula]
-            factor = comp.get_reduced_formula_and_factor()[1]
+        integer_formula, factor = comp.get_integer_formula_and_factor()
+        if self.experimental:
+            data = G_GASES[integer_formula]
 
             if self.interpolated:
                 g_interp = interp1d([int(t) for t in data.keys()], list(data.values()))
-                return g_interp(self.temp) * factor
+                energy = g_interp(self.temp)
+            else:
+                energy = data[str(self.temp)]
 
-            return data[str(self.temp)] * factor
+            gibbs_energy = energy * factor
+        else:
+            num_atoms = self.structure.num_sites
+            vol_per_atom = self.structure.volume / num_atoms
+            reduced_mass = self._reduced_mass(self.structure)
 
-        num_atoms = self.structure.num_sites
-        vol_per_atom = self.structure.volume / num_atoms
-        reduced_mass = self._reduced_mass()
+            gibbs_energy = (
+                comp.num_atoms
+                * (self.formation_enthalpy_per_atom + self._g_delta_sisso(vol_per_atom, reduced_mass, self.temp))
+                - self._sum_g_i()
+            )
 
-        return (
-            self.formation_enthalpy
-            + num_atoms * self._g_delta_sisso(vol_per_atom, reduced_mass, self.temp)
-            - self._sum_g_i()
-        )
+        return gibbs_energy
 
     def _sum_g_i(self) -> float:
         """
@@ -775,7 +830,7 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
         Returns:
              float: sum of weighted chemical potentials [eV]
         """
-        elems = self.structure.composition.get_el_amt_dict()
+        elems = self.composition.get_el_amt_dict()
 
         if self.interpolated:
             sum_g_i = 0
@@ -786,20 +841,22 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
                 )
                 sum_g_i += amt * g_interp(self.temp)
         else:
-            sum_g_i = sum(
-                [amt * G_ELEMS[str(self.temp)][elem] for elem, amt in elems.items()]
-            )
+            sum_g_i = sum([amt * G_ELEMS[str(self.temp)][elem] for elem, amt in elems.items()])
 
         return sum_g_i
 
-    def _reduced_mass(self) -> float:
+    @staticmethod
+    def _reduced_mass(structure) -> float:
         """
         Reduced mass as calculated via Eq. 6 in Bartel et al. (2018)
 
+        Args:
+            structure (Structure): The pymatgen Structure object of the entry.
+
         Returns:
             float: reduced mass (amu)
         """
-        reduced_comp = self.structure.composition.reduced_composition
+        reduced_comp = structure.composition.reduced_composition
         num_elems = len(reduced_comp.elements)
         elem_dict = reduced_comp.get_el_amt_dict()
 
@@ -814,7 +871,7 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
             alpha_i = pair[0][1]
             alpha_j = pair[1][1]
 
-            mass_sum += (alpha_i + alpha_j) * (m_i * m_j) / (m_i + m_j)
+            mass_sum += (alpha_i + alpha_j) * (m_i * m_j) / (m_i + m_j)  # type: ignore
 
         reduced_mass = (1 / denominator) * mass_sum
 
@@ -833,25 +890,22 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
             temp (float) - Temperature [K]
 
         Returns:
-            float: G^delta
+            float: G^delta [eV/atom]
         """
 
         return (
-            (-2.48e-4 * np.log(vol_per_atom) - 8.94e-5 * reduced_mass / vol_per_atom)
-            * temp
+            (-2.48e-4 * np.log(vol_per_atom) - 8.94e-5 * reduced_mass / vol_per_atom) * temp
             + 0.181 * np.log(temp)
             - 0.882
         )
 
     @classmethod
-    def from_pd(
-        cls, pd, temp=300, gibbs_model="SISSO"
-    ) -> List["GibbsComputedStructureEntry"]:
+    def from_pd(cls, pd, temp=300, gibbs_model="SISSO") -> List["GibbsComputedStructureEntry"]:
         """
         Constructor method for initializing a list of GibbsComputedStructureEntry
         objects from an existing T = 0 K phase diagram composed of
         ComputedStructureEntry objects, as acquired from a thermochemical database;
-        e.g. The Materials Project.
+        (e.g.. The Materials Project)
 
         Args:
             pd (PhaseDiagram): T = 0 K phase diagram as created in pymatgen. Must
@@ -866,14 +920,11 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
         """
         gibbs_entries = []
         for entry in pd.all_entries:
-            if (
-                entry in pd.el_refs.values()
-                or not entry.structure.composition.is_element
-            ):
+            if entry in pd.el_refs.values() or not entry.composition.is_element:
                 gibbs_entries.append(
                     cls(
                         entry.structure,
-                        formation_enthalpy=pd.get_form_energy(entry),
+                        formation_enthalpy_per_atom=pd.get_form_energy_per_atom(entry),
                         temp=temp,
                         correction=0,
                         gibbs_model=gibbs_model,
@@ -884,9 +935,7 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
         return gibbs_entries
 
     @classmethod
-    def from_entries(
-        cls, entries, temp=300, gibbs_model="SISSO"
-    ) -> List["GibbsComputedStructureEntry"]:
+    def from_entries(cls, entries, temp=300, gibbs_model="SISSO") -> List["GibbsComputedStructureEntry"]:
         """
         Constructor method for initializing GibbsComputedStructureEntry objects from
         T = 0 K ComputedStructureEntry objects, as acquired from a thermochemical
@@ -913,9 +962,7 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
         :return: MSONAble dict.
         """
         d = super().as_dict()
-        d["@module"] = self.__class__.__module__
-        d["@class"] = self.__class__.__name__
-        d["formation_enthalpy"] = self.formation_enthalpy
+        d["formation_enthalpy_per_atom"] = self.formation_enthalpy_per_atom
         d["temp"] = self.temp
         d["gibbs_model"] = self.gibbs_model
         d["interpolated"] = self.interpolated
@@ -930,25 +977,20 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
         dec = MontyDecoder()
         return cls(
             dec.process_decoded(d["structure"]),
-            d["formation_enthalpy"],
+            d["formation_enthalpy_per_atom"],
             d["temp"],
             d["gibbs_model"],
+            composition=d.get("composition", None),
             correction=d["correction"],
-            energy_adjustments=[
-                dec.process_decoded(e) for e in d.get("energy_adjustments", {})
-            ],
-            parameters={
-                k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()
-            },
+            energy_adjustments=[dec.process_decoded(e) for e in d.get("energy_adjustments", {})],
+            parameters={k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()},
             data={k: dec.process_decoded(v) for k, v in d.get("data", {}).items()},
             entry_id=d.get("entry_id", None),
         )
 
     def __repr__(self):
         output = [
-            "GibbsComputedStructureEntry {} - {}".format(
-                self.entry_id, self.composition.formula
-            ),
+            "GibbsComputedStructureEntry {} - {}".format(self.entry_id, self.composition.formula),
             "Gibbs Free Energy (Formation) = {:.4f}".format(self.energy),
         ]
         return "\n".join(output)
