@@ -29,9 +29,12 @@ import pandas as pd
 from monty.dev import deprecated
 from monty.json import MSONable
 from monty.serialization import loadfn
-from ruamel.yaml import YAML
 
-from pymatgen import Element, Lattice, Molecule, Structure, SymmOp
+from pymatgen import yaml
+from pymatgen.core.periodic_table import Element
+from pymatgen.core.lattice import Lattice
+from pymatgen.core.structure import Molecule, Structure
+from pymatgen.core.operations import SymmOp
 from pymatgen.util.io_utils import clean_lines
 
 __author__ = "Kiran Mathew, Zhi Deng, Tingzheng Hou"
@@ -132,9 +135,7 @@ class LammpsBox(MSONable):
         self.tilt = None
         if tilt is not None:
             tilt_arr = np.array(tilt)
-            assert tilt_arr.shape == (
-                3,
-            ), "Expecting a (3,) array for box_tilt," " got {}".format(tilt_arr.shape)
+            assert tilt_arr.shape == (3,), "Expecting a (3,) array for box_tilt," " got {}".format(tilt_arr.shape)
             self.tilt = tilt_arr.tolist()
             matrix[1, 0] = tilt_arr[0]
             matrix[2, 0] = tilt_arr[1]
@@ -231,9 +232,7 @@ def lattice_2_lmpbox(lattice, origin=(0, 0, 0)):
     yz = (np.dot(m[1], m[2]) - xy * xz) / (yhi - ylo)
     zhi = np.sqrt(c ** 2 - xz ** 2 - yz ** 2) + zlo
     tilt = None if lattice.is_orthogonal else [xy, xz, yz]
-    rot_matrix = np.linalg.solve(
-        [[xhi - xlo, 0, 0], [xy, yhi - ylo, 0], [xz, yz, zhi - zlo]], m
-    )
+    rot_matrix = np.linalg.solve([[xhi - xlo, 0, 0], [xy, yhi - ylo, 0], [xz, yz, zhi - zlo]], m)
     bounds = [[xlo, xhi], [ylo, yhi], [zlo, zhi]]
     symmop = SymmOp.from_rotation_and_translation(rot_matrix, origin)
     return LammpsBox(bounds, tilt), symmop
@@ -282,18 +281,14 @@ class LammpsData(MSONable):
         """
 
         if velocities is not None:
-            assert len(velocities) == len(
-                atoms
-            ), "Inconsistency found between atoms and velocities"
+            assert len(velocities) == len(atoms), "Inconsistency found between atoms and velocities"
 
         if force_field:
             all_ff_kws = SECTION_KEYWORDS["ff"] + SECTION_KEYWORDS["class2"]
             force_field = {k: v for k, v in force_field.items() if k in all_ff_kws}
 
         if topology:
-            topology = {
-                k: v for k, v in topology.items() if k in SECTION_KEYWORDS["topology"]
-            }
+            topology = {k: v for k, v in topology.items() if k in SECTION_KEYWORDS["topology"]}
 
         self.box = box
         self.masses = masses
@@ -502,9 +497,7 @@ class LammpsData(MSONable):
 
         """
         with open(filename, "w") as f:
-            f.write(
-                self.get_string(distance=distance, velocity=velocity, charge=charge)
-            )
+            f.write(self.get_string(distance=distance, velocity=velocity, charge=charge))
 
     def disassemble(self, atom_labels=None, guess_element=True, ff_label="ff_map"):
         """
@@ -540,9 +533,7 @@ class LammpsData(MSONable):
         """
         atoms_df = self.atoms.copy()
         if "nx" in atoms_df.columns:
-            atoms_df[["x", "y", "z"]] += self.box.get_box_shift(
-                atoms_df[["nx", "ny", "nz"]].values
-            )
+            atoms_df[["x", "y", "z"]] += self.box.get_box_shift(atoms_df[["nx", "ny", "nz"]].values)
         atoms_df = pd.concat([atoms_df, self.velocities], axis=1)
 
         mids = atoms_df.get("molecule-ID")
@@ -570,12 +561,8 @@ class LammpsData(MSONable):
             masses.loc[masses["mass"] == um, "element"] = s
         if atom_labels is None:  # add unique labels based on elements
             for el, vc in masses["element"].value_counts().iteritems():
-                masses.loc[masses["element"] == el, "label"] = [
-                    "%s%d" % (el, c) for c in range(1, vc + 1)
-                ]
-        assert masses["label"].nunique(dropna=False) == len(
-            masses
-        ), "Expecting unique atom label for each type"
+                masses.loc[masses["element"] == el, "label"] = ["%s%d" % (el, c) for c in range(1, vc + 1)]
+        assert masses["label"].nunique(dropna=False) == len(masses), "Expecting unique atom label for each type"
         mass_info = [tuple([r["label"], r["mass"]]) for _, r in masses.iterrows()]
 
         nonbond_coeffs, topo_coeffs = None, None
@@ -588,9 +575,7 @@ class LammpsData(MSONable):
                 nbc = self.force_field["Pair Coeffs"].sort_index()
                 nonbond_coeffs = [list(t) for t in nbc.itertuples(False, None)]
 
-            topo_coeffs = {
-                k: [] for k in SECTION_KEYWORDS["ff"][2:] if k in self.force_field
-            }
+            topo_coeffs = {k: [] for k in SECTION_KEYWORDS["ff"][2:] if k in self.force_field}
             for kw in topo_coeffs.keys():
                 class2_coeffs = {
                     k: list(v.itertuples(False, None))
@@ -601,9 +586,7 @@ class LammpsData(MSONable):
                 for t in ff_df.itertuples(True, None):
                     d = {"coeffs": list(t[1:]), "types": []}
                     if class2_coeffs:
-                        d.update(
-                            {k: list(v[t[0] - 1]) for k, v in class2_coeffs.items()}
-                        )
+                        d.update({k: list(v[t[0] - 1]) for k, v in class2_coeffs.items()})
                     topo_coeffs[kw].append(d)
 
         if self.topology:
@@ -618,8 +601,7 @@ class LammpsData(MSONable):
                     indices = list(topo[1:])
                     mids = atoms_df.loc[indices]["molecule-ID"].unique()
                     assert len(mids) == 1, (
-                        "Do not support intermolecular topology formed "
-                        "by atoms with different molecule-IDs"
+                        "Do not support intermolecular topology formed " "by atoms with different molecule-IDs"
                     )
                     label = label_topo(indices)
                     topo_coeffs[ff_kw][topo_idx]["types"].append(label)
@@ -633,9 +615,7 @@ class LammpsData(MSONable):
                 for d in v:
                     d["types"] = list(set(d["types"]))
 
-        ff = ForceField(
-            mass_info=mass_info, nonbond_coeffs=nonbond_coeffs, topo_coeffs=topo_coeffs
-        )
+        ff = ForceField(mass_info=mass_info, nonbond_coeffs=nonbond_coeffs, topo_coeffs=topo_coeffs)
 
         topo_list = []
         for mid in unique_mids:
@@ -646,9 +626,7 @@ class LammpsData(MSONable):
             species = masses.loc[type_ids, "element"]
             labels = masses.loc[type_ids, "label"]
             coords = atoms[["x", "y", "z"]]
-            m = Molecule(
-                species.values, coords.values, site_properties={ff_label: labels.values}
-            )
+            m = Molecule(species.values, coords.values, site_properties={ff_label: labels.values})
             charges = atoms.get("q")
             velocities = atoms[["vx", "vy", "vz"]] if "vx" in atoms.columns else None
             topologies = {}
@@ -690,12 +668,8 @@ class LammpsData(MSONable):
         header_pattern = dict()
         header_pattern["counts"] = r"^\s*(\d+)\s+([a-zA-Z]+)$"
         header_pattern["types"] = r"^\s*(\d+)\s+([a-zA-Z]+)\s+types$"
-        header_pattern["bounds"] = r"^\s*{}$".format(
-            r"\s+".join([float_group] * 2 + [r"([xyz])lo \3hi"])
-        )
-        header_pattern["tilt"] = r"^\s*{}$".format(
-            r"\s+".join([float_group] * 3 + ["xy xz yz"])
-        )
+        header_pattern["bounds"] = r"^\s*{}$".format(r"\s+".join([float_group] * 2 + [r"([xyz])lo \3hi"]))
+        header_pattern["tilt"] = r"^\s*{}$".format(r"\s+".join([float_group] * 3 + ["xy xz yz"]))
 
         header = {"counts": {}, "types": {}}
         bounds = {}
@@ -721,9 +695,7 @@ class LammpsData(MSONable):
             sio = StringIO("".join(sec_lines[2:]))  # skip the 2nd line
             if kw.endswith("Coeffs") and not kw.startswith("PairIJ"):
                 df_list = [
-                    pd.read_csv(
-                        StringIO(line), header=None, comment="#", delim_whitespace=True
-                    )
+                    pd.read_csv(StringIO(line), header=None, comment="#", delim_whitespace=True)
                     for line in sec_lines[2:]
                     if line.strip()
                 ]
@@ -732,9 +704,7 @@ class LammpsData(MSONable):
             else:
                 df = pd.read_csv(sio, header=None, comment="#", delim_whitespace=True)
                 if kw == "PairIJ Coeffs":
-                    names = ["id1", "id2"] + [
-                        "coeff%d" % i for i in range(1, df.shape[1] - 1)
-                    ]
+                    names = ["id1", "id2"] + ["coeff%d" % i for i in range(1, df.shape[1] - 1)]
                     df.index.name = None
                 elif kw in SECTION_HEADERS:
                     names = ["id"] + SECTION_HEADERS[kw]
@@ -745,14 +715,9 @@ class LammpsData(MSONable):
                     elif df.shape[1] == len(names) + 3:
                         names += ["nx", "ny", "nz"]
                     else:
-                        raise ValueError(
-                            "Format in Atoms section inconsistent"
-                            " with atom_style %s" % atom_style
-                        )
+                        raise ValueError("Format in Atoms section inconsistent" " with atom_style %s" % atom_style)
                 else:
-                    raise NotImplementedError(
-                        "Parser for %s section" " not implemented" % kw
-                    )
+                    raise NotImplementedError("Parser for %s section" " not implemented" % kw)
             df.columns = names
             if sort_id:
                 sort_by = "id" if kw != "PairIJ Coeffs" else ["id1", "id2"]
@@ -772,29 +737,21 @@ class LammpsData(MSONable):
             if (
                 name in ["Velocities"] + SECTION_KEYWORDS["topology"] and not seen_atoms
             ):  # Atoms must appear earlier than these
-                raise RuntimeError(
-                    err_msg + "%s section appears before" " Atoms section" % name
-                )
+                raise RuntimeError(err_msg + "%s section appears before" " Atoms section" % name)
             body.update({name: section})
 
         err_msg += "Nos. of {} do not match between header and {} section"
-        assert len(body["Masses"]) == header["types"]["atom"], err_msg.format(
-            "atom types", "Masses"
-        )
+        assert len(body["Masses"]) == header["types"]["atom"], err_msg.format("atom types", "Masses")
         atom_sections = ["Atoms", "Velocities"] if "Velocities" in body else ["Atoms"]
         for s in atom_sections:
             assert len(body[s]) == header["counts"]["atoms"], err_msg.format("atoms", s)
         for s in SECTION_KEYWORDS["topology"]:
             if header["counts"].get(s.lower(), 0) > 0:
-                assert len(body[s]) == header["counts"][s.lower()], err_msg.format(
-                    s.lower(), s
-                )
+                assert len(body[s]) == header["counts"][s.lower()], err_msg.format(s.lower(), s)
 
         items = {k.lower(): body[k] for k in ["Masses", "Atoms"]}
         items["velocities"] = body.get("Velocities")
-        ff_kws = [
-            k for k in body if k in SECTION_KEYWORDS["ff"] + SECTION_KEYWORDS["class2"]
-        ]
+        ff_kws = [k for k in body if k in SECTION_KEYWORDS["ff"] + SECTION_KEYWORDS["class2"]]
         items["force_field"] = {k: body[k] for k in ff_kws} if ff_kws else None
         topo_kws = [k for k in body if k in SECTION_KEYWORDS["topology"]]
         items["topology"] = {k: body[k] for k in topo_kws} if topo_kws else None
@@ -820,13 +777,9 @@ class LammpsData(MSONable):
 
         """
         atom_types = set.union(*[t.species for t in topologies])
-        assert atom_types.issubset(
-            ff.maps["Atoms"].keys()
-        ), "Unknown atom type found in topologies"
+        assert atom_types.issubset(ff.maps["Atoms"].keys()), "Unknown atom type found in topologies"
 
-        items = dict(
-            box=box, atom_style=atom_style, masses=ff.masses, force_field=ff.force_field
-        )
+        items = dict(box=box, atom_style=atom_style, masses=ff.masses, force_field=ff.force_field)
 
         mol_ids, charges, coords, labels = [], [], [], []
         v_collector = [] if topologies[0].velocities else None
@@ -837,9 +790,7 @@ class LammpsData(MSONable):
                 shift = len(labels)
                 for k, v in topo.topologies.items():
                     topo_collector[k].append(np.array(v) + shift + 1)
-                    topo_labels[k].extend(
-                        [tuple([topo.type_by_sites[j] for j in t]) for t in v]
-                    )
+                    topo_labels[k].extend([tuple([topo.type_by_sites[j] for j in t]) for t in v])
             if isinstance(v_collector, list):
                 v_collector.append(topo.velocities)
             mol_ids.extend([i + 1] * len(topo.sites))
@@ -857,16 +808,12 @@ class LammpsData(MSONable):
 
         velocities = None
         if v_collector:
-            velocities = pd.DataFrame(
-                np.concatenate(v_collector), columns=SECTION_HEADERS["Velocities"]
-            )
+            velocities = pd.DataFrame(np.concatenate(v_collector), columns=SECTION_HEADERS["Velocities"])
             velocities.index += 1
 
         topology = {k: None for k, v in topo_labels.items() if len(v) > 0}
         for k in topology:
-            df = pd.DataFrame(
-                np.concatenate(topo_collector[k]), columns=SECTION_HEADERS[k][1:]
-            )
+            df = pd.DataFrame(np.concatenate(topo_collector[k]), columns=SECTION_HEADERS[k][1:])
             df["type"] = list(map(ff.maps[k].get, topo_labels[k]))
             if any(pd.isnull(df["type"])):  # Throw away undefined topologies
                 warnings.warn("Undefined %s detected and removed" % k.lower())
@@ -880,9 +827,7 @@ class LammpsData(MSONable):
         return cls(**items)
 
     @classmethod
-    def from_structure(
-        cls, structure, ff_elements=None, atom_style="charge", is_sort=False
-    ):
+    def from_structure(cls, structure, ff_elements=None, atom_style="charge", is_sort=False):
         """
         Simple constructor building LammpsData from a structure without
         force field parameters and topologies.
@@ -924,9 +869,7 @@ class LammpsData(MSONable):
         mass_info = [tuple([i.symbol] * 2) for i in elements]
         ff = ForceField(mass_info)
         topo = Topology(boxed_s)
-        return cls.from_ff_and_topologies(
-            box=box, ff=ff, topologies=[topo], atom_style=atom_style
-        )
+        return cls.from_ff_and_topologies(box=box, ff=ff, topologies=[topo], atom_style=atom_style)
 
     @classmethod
     def from_dict(cls, d):
@@ -977,19 +920,9 @@ class LammpsData(MSONable):
         d["atoms"] = encode_df(self.atoms)
         d["atom_style"] = self.atom_style
 
-        d["velocities"] = (
-            None if self.velocities is None else encode_df(self.velocities)
-        )
-        d["force_field"] = (
-            None
-            if not self.force_field
-            else {k: encode_df(v) for k, v in self.force_field.items()}
-        )
-        d["topology"] = (
-            None
-            if not self.topology
-            else {k: encode_df(v) for k, v in self.topology.items()}
-        )
+        d["velocities"] = None if self.velocities is None else encode_df(self.velocities)
+        d["force_field"] = None if not self.force_field else {k: encode_df(v) for k, v in self.force_field.items()}
+        d["topology"] = None if not self.topology else {k: encode_df(v) for k, v in self.topology.items()}
         return d
 
 
@@ -1001,9 +934,7 @@ class Topology(MSONable):
 
     """
 
-    def __init__(
-        self, sites, ff_label=None, charges=None, velocities=None, topologies=None
-    ):
+    def __init__(self, sites, ff_label=None, charges=None, velocities=None, topologies=None):
         """
 
         Args:
@@ -1057,9 +988,7 @@ class Topology(MSONable):
             velocities = velocities_arr.tolist()
 
         if topologies:
-            topologies = {
-                k: v for k, v in topologies.items() if k in SECTION_KEYWORDS["topology"]
-            }
+            topologies = {k: v for k, v in topologies.items() if k in SECTION_KEYWORDS["topology"]}
 
         self.sites = sites
         self.ff_label = ff_label
@@ -1070,9 +999,7 @@ class Topology(MSONable):
         self.species = set(type_by_sites)
 
     @classmethod
-    def from_bonding(
-        cls, molecule, bond=True, angle=True, dihedral=True, tol=0.1, **kwargs
-    ):
+    def from_bonding(cls, molecule, bond=True, angle=True, dihedral=True, tol=0.1, **kwargs):
         """
         Another constructor that creates an instance from a molecule.
         Covalent bonds and other bond-based topologies (angles and
@@ -1119,16 +1046,10 @@ class Topology(MSONable):
             for i, j in hub_cons.tolist():
                 ks = [k for k in hub_spokes[i] if k != j]
                 ls = [l for l in hub_spokes[j] if l != i]
-                dihedral_list.extend(
-                    [[k, i, j, l] for k, l in itertools.product(ks, ls) if k != l]
-                )
+                dihedral_list.extend([[k, i, j, l] for k, l in itertools.product(ks, ls) if k != l])
 
         topologies = {
-            k: v
-            for k, v in zip(
-                SECTION_KEYWORDS["topology"][:3], [bond_list, angle_list, dihedral_list]
-            )
-            if len(v) > 0
+            k: v for k, v in zip(SECTION_KEYWORDS["topology"][:3], [bond_list, angle_list, dihedral_list]) if len(v) > 0
         }
         topologies = None if len(topologies) == 0 else topologies
         return cls(sites=molecule, topologies=topologies, **kwargs)
@@ -1221,11 +1142,7 @@ class ForceField(MSONable):
 
         self.topo_coeffs = topo_coeffs
         if self.topo_coeffs:
-            self.topo_coeffs = {
-                k: v
-                for k, v in self.topo_coeffs.items()
-                if k in SECTION_KEYWORDS["ff"][2:]
-            }
+            self.topo_coeffs = {k: v for k, v in self.topo_coeffs.items() if k in SECTION_KEYWORDS["ff"][2:]}
             for k in self.topo_coeffs.keys():
                 coeffs, mapper = self._process_topo(k)
                 ff_dfs.update(coeffs)
@@ -1235,9 +1152,7 @@ class ForceField(MSONable):
 
     def _process_nonbond(self):
         pair_df = pd.DataFrame(self.nonbond_coeffs)
-        assert self._is_valid(
-            pair_df
-        ), "Invalid nonbond coefficients with rows varying in length"
+        assert self._is_valid(pair_df), "Invalid nonbond coefficients with rows varying in length"
         npair, ncoeff = pair_df.shape
         pair_df.columns = ["coeff%d" % i for i in range(1, ncoeff + 1)]
         nm = len(self.mass_info)
@@ -1267,29 +1182,18 @@ class ForceField(MSONable):
             return [label] + [label[::-1]]
 
         main_data, distinct_types = [], []
-        class2_data = {
-            k: []
-            for k in self.topo_coeffs[kw][0].keys()
-            if k in CLASS2_KEYWORDS.get(kw, [])
-        }
+        class2_data = {k: [] for k in self.topo_coeffs[kw][0].keys() if k in CLASS2_KEYWORDS.get(kw, [])}
         for i, d in enumerate(self.topo_coeffs[kw]):
             main_data.append(d["coeffs"])
             distinct_types.append(d["types"])
             for k in class2_data.keys():
                 class2_data[k].append(d[k])
-        distinct_types = [
-            set(itertools.chain(*[find_eq_types(t, kw) for t in dt]))
-            for dt in distinct_types
-        ]
+        distinct_types = [set(itertools.chain(*[find_eq_types(t, kw) for t in dt])) for dt in distinct_types]
         type_counts = sum([len(dt) for dt in distinct_types])
         type_union = set.union(*distinct_types)
-        assert len(type_union) == type_counts, (
-            "Duplicated items found " "under different coefficients in %s" % kw
-        )
+        assert len(type_union) == type_counts, "Duplicated items found " "under different coefficients in %s" % kw
         atoms = set(np.ravel(list(itertools.chain(*distinct_types))))
-        assert atoms.issubset(self.maps["Atoms"].keys()), (
-            "Undefined atom type found in %s" % kw
-        )
+        assert atoms.issubset(self.maps["Atoms"].keys()), "Undefined atom type found in %s" % kw
         mapper = {}
         for i, dt in enumerate(distinct_types):
             for t in dt:
@@ -1297,9 +1201,7 @@ class ForceField(MSONable):
 
         def process_data(data):
             df = pd.DataFrame(data)
-            assert self._is_valid(
-                df
-            ), "Invalid coefficients with rows varying in length"
+            assert self._is_valid(df), "Invalid coefficients with rows varying in length"
             n, c = df.shape
             df.columns = ["coeff%d" % i for i in range(1, c + 1)]
             df.index = range(1, n + 1)
@@ -1323,9 +1225,9 @@ class ForceField(MSONable):
             "nonbond_coeffs": self.nonbond_coeffs,
             "topo_coeffs": self.topo_coeffs,
         }
-        yaml = YAML(typ="safe")
+        yml = yaml.YAML(typ="safe")
         with open(filename, "w") as f:
-            yaml.dump(d, f)
+            yml.dump(d, f)
 
     @classmethod
     def from_file(cls, filename):
@@ -1336,9 +1238,9 @@ class ForceField(MSONable):
             filename (str): Filename.
 
         """
-        yaml = YAML(typ="safe")
+        yml = yaml.YAML(typ="safe")
         with open(filename, "r") as f:
-            d = yaml.load(f)
+            d = yml.load(f)
         return cls.from_dict(d)
 
     @classmethod
@@ -1390,20 +1292,14 @@ class CombinedData(LammpsData):
         self.names = list_of_names
         self.mols = list_of_molecules
         self.nums = list_of_numbers
-        self.masses = pd.concat(
-            [mol.masses.copy() for mol in self.mols], ignore_index=True
-        )
+        self.masses = pd.concat([mol.masses.copy() for mol in self.mols], ignore_index=True)
         self.masses.index += 1
         all_ff_kws = SECTION_KEYWORDS["ff"] + SECTION_KEYWORDS["class2"]
         ff_kws = [k for k in all_ff_kws if k in self.mols[0].force_field]
         self.force_field = {}
         for kw in ff_kws:
             self.force_field[kw] = pd.concat(
-                [
-                    mol.force_field[kw].copy()
-                    for mol in self.mols
-                    if kw in mol.force_field
-                ],
+                [mol.force_field[kw].copy() for mol in self.mols if kw in mol.force_field],
                 ignore_index=True,
             )
             self.force_field[kw].index += 1
@@ -1440,9 +1336,7 @@ class CombinedData(LammpsData):
                     for col in topo_df.columns[1:]:
                         topo_df[col] += atom_count
                     for j in range(self.nums[i]):
-                        self.topology[kw] = self.topology[kw].append(
-                            topo_df, ignore_index=True
-                        )
+                        self.topology[kw] = self.topology[kw].append(topo_df, ignore_index=True)
                         for col in topo_df.columns[1:]:
                             topo_df[col] += len(mol.atoms)
                     count[kw] += len(mol.force_field[kw[:-1] + " Coeffs"])
@@ -1496,14 +1390,10 @@ class CombinedData(LammpsData):
             styles.append(eval("cluster%d" % (i + 1)).atom_style)
         style = set(styles)
         assert len(style) == 1, "Files have different atom styles."
-        return cls.from_lammpsdata(
-            mols, names, list_of_numbers, coordinates, style.pop()
-        )
+        return cls.from_lammpsdata(mols, names, list_of_numbers, coordinates, style.pop())
 
     @classmethod
-    def from_lammpsdata(
-        cls, mols, names, list_of_numbers, coordinates, atom_style=None
-    ):
+    def from_lammpsdata(cls, mols, names, list_of_numbers, coordinates, atom_style=None):
         """
         Constructor that can infer atom_style.
         The input LammpsData objects are used non-destructively.
@@ -1523,9 +1413,7 @@ class CombinedData(LammpsData):
         assert len(style) == 1, "Data have different atom_style."
         style_return = style.pop()
         if atom_style:
-            assert (
-                atom_style == style_return
-            ), "Data have different atom_style as specified."
+            assert atom_style == style_return, "Data have different atom_style as specified."
         return cls(mols, names, list_of_numbers, coordinates, style_return)
 
     def get_string(self, distance=6, velocity=8, charge=4):
@@ -1546,9 +1434,7 @@ class CombinedData(LammpsData):
             String representation
         """
         lines = LammpsData.get_string(self, distance, velocity, charge).splitlines()
-        info = "# " + " + ".join(
-            str(a) + " " + b for a, b in zip(self.nums, self.names)
-        )
+        info = "# " + " + ".join(str(a) + " " + b for a, b in zip(self.nums, self.names))
         lines.insert(1, info)
         return "\n".join(lines)
 
@@ -1557,9 +1443,7 @@ class CombinedData(LammpsData):
     LammpsData.from_structure,
     "structure_2_lmpdata has been deprecated " "in favor of LammpsData.from_structure",
 )
-def structure_2_lmpdata(
-    structure, ff_elements=None, atom_style="charge", is_sort=False
-):
+def structure_2_lmpdata(structure, ff_elements=None, atom_style="charge", is_sort=False):
     """
     Converts a structure to a LammpsData object with no force field
     parameters and topologies.
@@ -1603,6 +1487,4 @@ def structure_2_lmpdata(
     mass_info = [tuple([i.symbol] * 2) for i in elements]
     ff = ForceField(mass_info)
     topo = Topology(s)
-    return LammpsData.from_ff_and_topologies(
-        box=box, ff=ff, topologies=[topo], atom_style=atom_style
-    )
+    return LammpsData.from_ff_and_topologies(box=box, ff=ff, topologies=[topo], atom_style=atom_style)
