@@ -19,6 +19,7 @@ import warnings
 from collections import OrderedDict, namedtuple
 from enum import Enum
 from hashlib import md5
+from typing import Dict, Any, Tuple, Sequence, Union
 
 import numpy as np
 import scipy.constants as const
@@ -36,7 +37,7 @@ from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.core import Magmom
 from pymatgen.util.io_utils import clean_lines
 from pymatgen.util.string import str_delimited
-from pymatgen.util.typing import PathLike
+from pymatgen.util.typing import PathLike, ArrayLike
 
 __author__ = "Shyue Ping Ong, Geoffroy Hautier, Rickard Armiento, Vincent L Chevrier, Stephen Dacek"
 __copyright__ = "Copyright 2011, The Materials Project"
@@ -97,9 +98,9 @@ class Poscar(MSONable):
         comment: str = None,
         selective_dynamics=None,
         true_names: bool = True,
-        velocities=None,
-        predictor_corrector=None,
-        predictor_corrector_preamble=None,
+        velocities: ArrayLike = None,
+        predictor_corrector: ArrayLike = None,
+        predictor_corrector_preamble: str = None,
         sort_structure: bool = False,
     ):
         """
@@ -138,11 +139,9 @@ class Poscar(MSONable):
             self.comment = structure.formula if comment is None else comment
             self.predictor_corrector_preamble = predictor_corrector_preamble
         else:
-            raise ValueError(
-                "Structure with partial occupancies cannot be " "converted into POSCAR!"
-            )
+            raise ValueError("Structure with partial occupancies cannot be " "converted into POSCAR!")
 
-        self.temperature = -1
+        self.temperature = -1.0
 
     @property
     def velocities(self):
@@ -198,9 +197,7 @@ class Poscar(MSONable):
                 value = np.array(value)
                 dim = value.shape
                 if dim[1] != 3 or dim[0] != len(self.structure):
-                    raise ValueError(
-                        name + " array must be same length as" + " the structure."
-                    )
+                    raise ValueError(name + " array must be same length as" + " the structure.")
                 value = value.tolist()
         super().__setattr__(name, value)
 
@@ -343,9 +340,7 @@ class Poscar(MSONable):
                 symbols.extend(lines[iline_symbols].split())
             natoms = []
             iline_natoms_start = 5 + nlines_symbols
-            for iline_natoms in range(
-                iline_natoms_start, iline_natoms_start + nlines_symbols
-            ):
+            for iline_natoms in range(iline_natoms_start, iline_natoms_start + nlines_symbols):
                 natoms.extend([int(i) for i in lines[iline_natoms].split()])
             atomic_symbols = list()
             for i, nat in enumerate(natoms):
@@ -380,9 +375,7 @@ class Poscar(MSONable):
             ind = 3 if not sdynamics else 6
             try:
                 # Check if names are appended at the end of the coordinates.
-                atomic_symbols = [
-                    l.split()[ind] for l in lines[ipos + 1 : ipos + 1 + nsites]
-                ]
+                atomic_symbols = [l.split()[ind] for l in lines[ipos + 1 : ipos + 1 + nsites]]
                 # Ensure symbols are valid elements
                 if not all([Element.is_valid_symbol(sym) for sym in atomic_symbols]):
                     raise ValueError("Non-valid symbols detected.")
@@ -436,9 +429,7 @@ class Poscar(MSONable):
                 # First line in chunk is a key in CONTCAR
                 # Second line is POTIM
                 # Third line is the thermostat parameters
-                predictor_corrector_preamble = (
-                    lines[0] + "\n" + lines[1] + "\n" + lines[2]
-                )
+                predictor_corrector_preamble = lines[0] + "\n" + lines[1] + "\n" + lines[2]
                 # Rest is three sets of parameters, each set contains
                 # x, y, z predictor-corrector parameters for every atom in orde
                 lines = lines[3:]
@@ -462,7 +453,7 @@ class Poscar(MSONable):
             predictor_corrector_preamble=predictor_corrector_preamble,
         )
 
-    def get_string(self, direct=True, vasp4_compatible=False, significant_figures=6):
+    def get_string(self, direct: bool = True, vasp4_compatible: bool = False, significant_figures: int = 6) -> str:
         """
         Returns a string to be written as a POSCAR file. By default, site
         symbols are written, which means compatibility is for vasp >= 5.
@@ -529,8 +520,7 @@ class Poscar(MSONable):
                         lines.append(" ".join([format_str.format(i) for i in z]))
             else:
                 warnings.warn(
-                    "Preamble information missing or corrupt. "
-                    "Writing Poscar with no predictor corrector data."
+                    "Preamble information missing or corrupt. " "Writing Poscar with no predictor corrector data."
                 )
 
         return "\n".join(lines) + "\n"
@@ -544,7 +534,7 @@ class Poscar(MSONable):
         """
         return self.get_string()
 
-    def write_file(self, filename, **kwargs):
+    def write_file(self, filename: PathLike, **kwargs):
         """
         Writes POSCAR to a file. The supported kwargs are the same as those for
         the Poscar.get_string method and are passed through directly.
@@ -552,7 +542,7 @@ class Poscar(MSONable):
         with zopen(filename, "wt") as f:
             f.write(self.get_string(**kwargs))
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """
         :return: MSONable dict.
         """
@@ -568,7 +558,7 @@ class Poscar(MSONable):
         }
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, d: dict) -> "Poscar":
         """
         :param d: Dict representation.
         :return: Poscar
@@ -582,7 +572,7 @@ class Poscar(MSONable):
             predictor_corrector=d.get("predictor_corrector", None),
         )
 
-    def set_temperature(self, temperature):
+    def set_temperature(self, temperature: float):
         """
         Initializes the velocities based on Maxwell-Boltzmann distribution.
         Removes linear, but not angular drift (same as VASP)
@@ -601,9 +591,7 @@ class Poscar(MSONable):
         velocities = np.random.randn(len(self.structure), 3)
 
         # in AMU, (N,1) array
-        atomic_masses = np.array(
-            [site.specie.atomic_mass.to("kg") for site in self.structure]
-        )
+        atomic_masses = np.array([site.specie.atomic_mass.to("kg") for site in self.structure])
         dof = 3 * len(self.structure) - 3
 
         # scale velocities due to atomic masses
@@ -611,9 +599,7 @@ class Poscar(MSONable):
         velocities /= atomic_masses[:, np.newaxis] ** (1 / 2)
 
         # remove linear drift (net momentum)
-        velocities -= np.average(
-            atomic_masses[:, np.newaxis] * velocities, axis=0
-        ) / np.average(atomic_masses)
+        velocities -= np.average(atomic_masses[:, np.newaxis] * velocities, axis=0) / np.average(atomic_masses)
 
         # scale velocities to get correct temperature
         energy = np.sum(1 / 2 * atomic_masses * np.sum(velocities ** 2, axis=1))
@@ -656,7 +642,7 @@ class Incar(dict, MSONable):
     a dictionary with some helper functions
     """
 
-    def __init__(self, params=None):
+    def __init__(self, params: Dict[str, Any] = None):
         """
         Creates an Incar object.
 
@@ -668,9 +654,9 @@ class Incar(dict, MSONable):
 
             # if Incar contains vector-like magmoms given as a list
             # of floats, convert to a list of lists
-            if (
-                params.get("MAGMOM") and isinstance(params["MAGMOM"][0], (int, float))
-            ) and (params.get("LSORBIT") or params.get("LNONCOLLINEAR")):
+            if (params.get("MAGMOM") and isinstance(params["MAGMOM"][0], (int, float))) and (
+                params.get("LSORBIT") or params.get("LNONCOLLINEAR")
+            ):
                 val = []
                 for i in range(len(params["MAGMOM"]) // 3):
                     val.append(params["MAGMOM"][i * 3 : (i + 1) * 3])
@@ -678,7 +664,7 @@ class Incar(dict, MSONable):
 
             self.update(params)
 
-    def __setitem__(self, key, val):
+    def __setitem__(self, key: str, val: Any):
         """
         Add parameter-val pair to Incar.  Warns if parameter is not in list of
         valid INCAR tags. Also cleans the parameter and val by stripping
@@ -689,7 +675,7 @@ class Incar(dict, MSONable):
             Incar.proc_val(key.strip(), val.strip()) if isinstance(val, str) else val,
         )
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """
         :return: MSONable dict.
         """
@@ -699,7 +685,7 @@ class Incar(dict, MSONable):
         return d
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, d) -> "Incar":
         """
         :param d: Dict representation.
         :return: Incar
@@ -708,7 +694,7 @@ class Incar(dict, MSONable):
             d["MAGMOM"] = [Magmom.from_dict(m) for m in d["MAGMOM"]]
         return Incar({k: v for k, v in d.items() if k not in ("@module", "@class")})
 
-    def get_string(self, sort_keys=False, pretty=False):
+    def get_string(self, sort_keys: bool = False, pretty: bool = False) -> str:
         """
         Returns a string representation of the INCAR.  The reason why this
         method is different from the __str__ method is to provide options for
@@ -720,7 +706,7 @@ class Incar(dict, MSONable):
             pretty (bool): Set to True for pretty aligned output. Defaults
                 to False.
         """
-        keys = self.keys()
+        keys = list(self.keys())
         if sort_keys:
             keys = sorted(keys)
         lines = []
@@ -728,9 +714,7 @@ class Incar(dict, MSONable):
             if k == "MAGMOM" and isinstance(self[k], list):
                 value = []
 
-                if isinstance(self[k][0], (list, Magmom)) and (
-                    self.get("LSORBIT") or self.get("LNONCOLLINEAR")
-                ):
+                if isinstance(self[k][0], (list, Magmom)) and (self.get("LSORBIT") or self.get("LNONCOLLINEAR")):
                     value.append(" ".join(str(i) for j in self[k] for i in j))
                 elif self.get("LSORBIT") or self.get("LNONCOLLINEAR"):
                     for m, g in itertools.groupby(self[k]):
@@ -754,7 +738,7 @@ class Incar(dict, MSONable):
     def __str__(self):
         return self.get_string(sort_keys=True, pretty=False)
 
-    def write_file(self, filename):
+    def write_file(self, filename: PathLike):
         """
         Write Incar to a file.
 
@@ -765,7 +749,7 @@ class Incar(dict, MSONable):
             f.write(self.__str__())
 
     @staticmethod
-    def from_file(filename):
+    def from_file(filename: PathLike) -> "Incar":
         """
         Reads an Incar object from a file.
 
@@ -779,7 +763,7 @@ class Incar(dict, MSONable):
             return Incar.from_string(f.read())
 
     @staticmethod
-    def from_string(string):
+    def from_string(string: str) -> "Incar":
         """
         Reads an Incar object from a string.
 
@@ -802,7 +786,7 @@ class Incar(dict, MSONable):
         return Incar(params)
 
     @staticmethod
-    def proc_val(key, val):
+    def proc_val(key: str, val: Any):
         """
         Static helper method to convert INCAR parameters to proper types, e.g.,
         integers, floats, lists, etc.
@@ -875,14 +859,10 @@ class Incar(dict, MSONable):
         try:
             if key in list_keys:
                 output = []
-                toks = re.findall(
-                    r"(-?\d+\.?\d*)\*?(-?\d+\.?\d*)?\*?(-?\d+\.?\d*)?", val
-                )
+                toks = re.findall(r"(-?\d+\.?\d*)\*?(-?\d+\.?\d*)?\*?(-?\d+\.?\d*)?", val)
                 for tok in toks:
                     if tok[2] and "3" in tok[0]:
-                        output.extend(
-                            [smart_int_or_float(tok[2])] * int(tok[0]) * int(tok[1])
-                        )
+                        output.extend([smart_int_or_float(tok[2])] * int(tok[0]) * int(tok[1]))
                     elif tok[1]:
                         output.extend([smart_int_or_float(tok[1])] * int(tok[0]))
                     else:
@@ -896,10 +876,10 @@ class Incar(dict, MSONable):
                 raise ValueError(key + " should be a boolean type!")
 
             if key in float_keys:
-                return float(re.search(r"^-?\d*\.?\d*[e|E]?-?\d*", val).group(0))
+                return float(re.search(r"^-?\d*\.?\d*[e|E]?-?\d*", val).group(0))  # type: ignore
 
             if key in int_keys:
-                return int(re.match(r"^-?[0-9]+", val).group(0))
+                return int(re.match(r"^-?[0-9]+", val).group(0))  # type: ignore
 
         except ValueError:
             pass
@@ -925,7 +905,7 @@ class Incar(dict, MSONable):
 
         return val.strip().capitalize()
 
-    def diff(self, other):
+    def diff(self, other: "Incar") -> Dict[str, Dict[str, Any]]:
         """
         Diff function for Incar.  Compares two Incars and indicates which
         parameters are the same and which are not. Useful for checking whether
@@ -1007,8 +987,7 @@ class Incar(dict, MSONable):
                 elif type(incar_params[k]).__name__ == "list":
                     if self[k] not in incar_params[k]:
                         warnings.warn(
-                            "%s: Cannot find %s in the list of parameters"
-                            % (k, self[k]),
+                            "%s: Cannot find %s in the list of parameters" % (k, self[k]),
                             BadIncarWarning,
                             stacklevel=2,
                         )
@@ -1051,16 +1030,16 @@ class Kpoints(MSONable):
 
     def __init__(
         self,
-        comment="Default gamma",
-        num_kpts=0,
-        style=supported_modes.Gamma,
-        kpts=((1, 1, 1),),
-        kpts_shift=(0, 0, 0),
+        comment: str = "Default gamma",
+        num_kpts: int = 0,
+        style: Kpoints_supported_modes = supported_modes.Gamma,
+        kpts: Sequence[Union[float, int, Sequence]] = ((1, 1, 1),),
+        kpts_shift: Tuple[int, int, int] = (0, 0, 0),
         kpts_weights=None,
         coord_type=None,
         labels=None,
-        tet_number=0,
-        tet_weight=0,
+        tet_number: int = 0,
+        tet_weight: float = 0,
         tet_connections=None,
     ):
         """
@@ -1105,8 +1084,7 @@ class Kpoints(MSONable):
         """
         if num_kpts > 0 and (not labels) and (not kpts_weights):
             raise ValueError(
-                "For explicit or line-mode kpoints, either the "
-                "labels or kpts_weights must be specified."
+                "For explicit or line-mode kpoints, either the " "labels or kpts_weights must be specified."
             )
 
         self.comment = comment
@@ -1401,9 +1379,7 @@ class Kpoints(MSONable):
         if style == "a":
             return Kpoints.automatic(int(lines[3]))
 
-        coord_pattern = re.compile(
-            r"^\s*([\d+.\-Ee]+)\s+([\d+.\-Ee]+)\s+" r"([\d+.\-Ee]+)"
-        )
+        coord_pattern = re.compile(r"^\s*([\d+.\-Ee]+)\s+([\d+.\-Ee]+)\s+" r"([\d+.\-Ee]+)")
 
         # Automatic gamma and Monk KPOINTS, with optional shift
         if style in ["g", "m"]:
@@ -1422,11 +1398,7 @@ class Kpoints(MSONable):
 
         # Automatic kpoints with basis
         if num_kpts <= 0:
-            style = (
-                Kpoints.supported_modes.Cartesian
-                if style in "ck"
-                else Kpoints.supported_modes.Reciprocal
-            )
+            style = Kpoints.supported_modes.Cartesian if style in "ck" else Kpoints.supported_modes.Reciprocal
             kpts = [[float(j) for j in lines[i].split()] for i in range(3, 6)]
             kpts_shift = [float(i) for i in lines[6].split()]
             return Kpoints(
@@ -1443,16 +1415,12 @@ class Kpoints(MSONable):
             style = Kpoints.supported_modes.Line_mode
             kpts = []
             labels = []
-            patt = re.compile(
-                r"([e0-9.\-]+)\s+([e0-9.\-]+)\s+([e0-9.\-]+)" r"\s*!*\s*(.*)"
-            )
+            patt = re.compile(r"([e0-9.\-]+)\s+([e0-9.\-]+)\s+([e0-9.\-]+)" r"\s*!*\s*(.*)")
             for i in range(4, len(lines)):
                 line = lines[i]
                 m = patt.match(line)
                 if m:
-                    kpts.append(
-                        [float(m.group(1)), float(m.group(2)), float(m.group(3))]
-                    )
+                    kpts.append([float(m.group(1)), float(m.group(2)), float(m.group(3))])
                     labels.append(m.group(4).strip())
             return Kpoints(
                 comment=comment,
@@ -1464,11 +1432,7 @@ class Kpoints(MSONable):
             )
 
         # Assume explicit KPOINTS if all else fails.
-        style = (
-            Kpoints.supported_modes.Cartesian
-            if style in "ck"
-            else Kpoints.supported_modes.Reciprocal
-        )
+        style = Kpoints.supported_modes.Cartesian if style in "ck" else Kpoints.supported_modes.Reciprocal
         kpts = []
         kpts_weights = []
         labels = []
@@ -1493,9 +1457,7 @@ class Kpoints(MSONable):
                 tet_connections = []
                 for i in range(5 + num_kpts, 5 + num_kpts + tet_number):
                     toks = lines[i].split()
-                    tet_connections.append(
-                        (int(toks[0]), [int(toks[j]) for j in range(1, 5)])
-                    )
+                    tet_connections.append((int(toks[0]), [int(toks[j]) for j in range(1, 5)]))
         except IndexError:
             pass
 
@@ -1546,10 +1508,7 @@ class Kpoints(MSONable):
             lines.append("Tetrahedron")
             lines.append("%d %f" % (self.tet_number, self.tet_weight))
             for sym_weight, vertices in self.tet_connections:
-                lines.append(
-                    "%d %d %d %d %d"
-                    % (sym_weight, vertices[0], vertices[1], vertices[2], vertices[3])
-                )
+                lines.append("%d %d %d %d %d" % (sym_weight, vertices[0], vertices[1], vertices[2], vertices[3]))
 
         # Print shifts for automatic kpoints types if not zero.
         if self.num_kpts <= 0 and tuple(self.kpts_shift) != (0, 0, 0):
@@ -1632,9 +1591,7 @@ def _parse_list(s):
 
 
 Orbital = namedtuple("Orbital", ["n", "l", "j", "E", "occ"])
-OrbitalDescription = namedtuple(
-    "OrbitalDescription", ["l", "E", "Type", "Rcut", "Type2", "Rcut2"]
-)
+OrbitalDescription = namedtuple("OrbitalDescription", ["l", "E", "Type", "Rcut", "Type2", "Rcut2"])
 
 
 class UnknownPotcarWarning(UserWarning):
@@ -1748,9 +1705,7 @@ class PotcarSingle:
         ).group(1)
 
         self.keywords = {}
-        for key, val in re.findall(
-            r"(\S+)\s*=\s*(.*?)(?=;|$)", search_lines, flags=re.MULTILINE
-        ):
+        for key, val in re.findall(r"(\S+)\s*=\s*(.*?)(?=;|$)", search_lines, flags=re.MULTILINE):
             try:
                 self.keywords[key] = self.parse_functions[key](val)
             except KeyError:
@@ -1761,9 +1716,7 @@ class PotcarSingle:
         array_search = re.compile(r"(-*[0-9.]+)")
         orbitals = []
         descriptions = []
-        atomic_configuration = re.search(
-            r"Atomic configuration\s*\n?" r"(.*?)Description", search_lines
-        )
+        atomic_configuration = re.search(r"Atomic configuration\s*\n?" r"(.*?)Description", search_lines)
         if atomic_configuration:
             lines = atomic_configuration.group(1).splitlines()
             num_entries = re.search(r"([0-9]+)", lines[0]).group(1)
@@ -1784,9 +1737,7 @@ class PotcarSingle:
             PSCTR["Orbitals"] = tuple(orbitals)
 
         description_string = re.search(
-            r"(?s)Description\s*\n"
-            r"(.*?)Error from kinetic"
-            r" energy argument \(eV\)",
+            r"(?s)Description\s*\n" r"(.*?)Error from kinetic" r" energy argument \(eV\)",
             search_lines,
         )
         if description_string:
@@ -1808,8 +1759,7 @@ class PotcarSingle:
             PSCTR["OrbitalDescriptions"] = tuple(descriptions)
 
         rrkj_kinetic_energy_string = re.search(
-            r"(?s)Error from kinetic energy argument \(eV\)\s*\n"
-            r"(.*?)END of PSCTR-controll parameters",
+            r"(?s)Error from kinetic energy argument \(eV\)\s*\n" r"(.*?)END of PSCTR-controll parameters",
             search_lines,
         )
         rrkj_array = []
@@ -1865,10 +1815,7 @@ class PotcarSingle:
         :return: Electronic configuration of the PotcarSingle.
         """
         if not self.nelectrons.is_integer():
-            warnings.warn(
-                "POTCAR has non-integer charge, "
-                "electron configuration not well-defined."
-            )
+            warnings.warn("POTCAR has non-integer charge, " "electron configuration not well-defined.")
             return None
         el = Element.from_Z(self.atomic_no)
         full_config = el.full_electronic_structure
@@ -1906,10 +1853,7 @@ class PotcarSingle:
             with zopen(filename, "rt") as f:
                 return PotcarSingle(f.read(), symbol=symbol or None)
         except UnicodeDecodeError:
-            warnings.warn(
-                "POTCAR contains invalid unicode errors. "
-                "We will attempt to read it by ignoring errors."
-            )
+            warnings.warn("POTCAR contains invalid unicode errors. " "We will attempt to read it by ignoring errors.")
             import codecs
 
             with codecs.open(filename, "r", encoding="utf-8", errors="ignore") as f:
@@ -2266,10 +2210,7 @@ class Potcar(list, MSONable):
             with zopen(filename, "rt") as f:
                 fdata = f.read()
         except UnicodeDecodeError:
-            warnings.warn(
-                "POTCAR contains invalid unicode errors. "
-                "We will attempt to read it by ignoring errors."
-            )
+            warnings.warn("POTCAR contains invalid unicode errors. " "We will attempt to read it by ignoring errors.")
             import codecs
 
             with codecs.open(filename, "r", encoding="utf-8", errors="ignore") as f:
@@ -2360,9 +2301,7 @@ class VaspInput(dict, MSONable):
                 conventions in implementing a as_dict() and from_dict method.
         """
         super().__init__(**kwargs)
-        self.update(
-            {"INCAR": incar, "KPOINTS": kpoints, "POSCAR": poscar, "POTCAR": potcar}
-        )
+        self.update({"INCAR": incar, "KPOINTS": kpoints, "POSCAR": poscar, "POTCAR": potcar})
         if optional_files is not None:
             self.update(optional_files)
 
@@ -2445,9 +2384,7 @@ class VaspInput(dict, MSONable):
         sub_d["optional_files"] = {}
         if optional_files is not None:
             for fname, ftype in optional_files.items():
-                sub_d["optional_files"][fname] = ftype.from_file(
-                    os.path.join(input_dir, fname)
-                )
+                sub_d["optional_files"][fname] = ftype.from_file(os.path.join(input_dir, fname))
         return VaspInput(**sub_d)
 
     def run_vasp(
@@ -2470,11 +2407,7 @@ class VaspInput(dict, MSONable):
         vasp_cmd = vasp_cmd or SETTINGS.get("PMG_VASP_EXE")
         vasp_cmd = [os.path.expanduser(os.path.expandvars(t)) for t in vasp_cmd]
         if not vasp_cmd:
-            raise RuntimeError(
-                "You need to supply vasp_cmd or set the PMG_VASP_EXE in .pmgrc.yaml to run VASP."
-            )
+            raise RuntimeError("You need to supply vasp_cmd or set the PMG_VASP_EXE in .pmgrc.yaml to run VASP.")
         with cd(run_dir):
-            with open(output_file, "w") as f_std, open(
-                err_file, "w", buffering=1
-            ) as f_err:
+            with open(output_file, "w") as f_std, open(err_file, "w", buffering=1) as f_err:
                 subprocess.check_call(vasp_cmd, stdout=f_std, stderr=f_err)
