@@ -27,9 +27,7 @@ class InsertSitesTransformation(AbstractTransformation):
     This transformation substitutes certain sites with certain species.
     """
 
-    def __init__(
-        self, species, coords, coords_are_cartesian=False, validate_proximity=True
-    ):
+    def __init__(self, species, coords, coords_are_cartesian=False, validate_proximity=True):
         """
         Args:
             species: A list of species. e.g., ["Li", "Fe"]
@@ -70,9 +68,7 @@ class InsertSitesTransformation(AbstractTransformation):
         return s.get_sorted_structure()
 
     def __str__(self):
-        return "InsertSiteTransformation : " + "species {}, coords {}".format(
-            self.species, self.coords
-        )
+        return "InsertSiteTransformation : " + "species {}, coords {}".format(self.species, self.coords)
 
     def __repr__(self):
         return self.__str__()
@@ -169,9 +165,7 @@ class RemoveSitesTransformation(AbstractTransformation):
         return s
 
     def __str__(self):
-        return "RemoveSitesTransformation :" + ", ".join(
-            map(str, self.indices_to_remove)
-        )
+        return "RemoveSitesTransformation :" + ", ".join(map(str, self.indices_to_remove))
 
     def __repr__(self):
         return self.__str__()
@@ -222,9 +216,7 @@ class TranslateSitesTransformation(AbstractTransformation):
         s = structure.copy()
         if self.translation_vector.shape == (len(self.indices_to_move), 3):
             for i, idx in enumerate(self.indices_to_move):
-                s.translate_sites(
-                    idx, self.translation_vector[i], self.vector_in_frac_coords
-                )
+                s.translate_sites(idx, self.translation_vector[i], self.vector_in_frac_coords)
         else:
             s.translate_sites(
                 self.indices_to_move,
@@ -234,13 +226,10 @@ class TranslateSitesTransformation(AbstractTransformation):
         return s
 
     def __str__(self):
-        return (
-            "TranslateSitesTransformation for indices "
-            + "{}, vect {} and vect_in_frac_coords = {}".format(
-                self.indices_to_move,
-                self.translation_vector,
-                self.vector_in_frac_coords,
-            )
+        return "TranslateSitesTransformation for indices " + "{}, vect {} and vect_in_frac_coords = {}".format(
+            self.indices_to_move,
+            self.translation_vector,
+            self.vector_in_frac_coords,
         )
 
     def __repr__(self):
@@ -252,9 +241,7 @@ class TranslateSitesTransformation(AbstractTransformation):
         Returns:
             TranslateSitesTranformation with the reverse translation.
         """
-        return TranslateSitesTransformation(
-            self.indices_to_move, -self.translation_vector, self.vector_in_frac_coords
-        )
+        return TranslateSitesTransformation(self.indices_to_move, -self.translation_vector, self.vector_in_frac_coords)
 
     @property
     def is_one_to_many(self):
@@ -354,11 +341,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
                 if removed[indices] < num_remove_dict[indices]:
                     for ind in indices:
                         if ind not in to_delete:
-                            energy = (
-                                sum(ematrix[:, ind])
-                                + sum(ematrix[:, ind])
-                                - ematrix[ind, ind]
-                            )
+                            energy = sum(ematrix[:, ind]) + sum(ematrix[:, ind]) - ematrix[ind, ind]
                             if energy > maxe:
                                 maxindex = ind
                                 maxe = energy
@@ -369,9 +352,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
             ematrix[maxindex, :] = 0
         s = structure.copy()
         s.remove_sites(to_delete)
-        self.logger.debug(
-            "Minimizing Ewald took {} seconds.".format(time.time() - starttime)
-        )
+        self.logger.debug("Minimizing Ewald took {} seconds.".format(time.time() - starttime))
         return [{"energy": sum(sum(ematrix)), "structure": s.get_sorted_structure()}]
 
     def _complete_ordering(self, structure, num_remove_dict):
@@ -379,11 +360,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         all_structures = []
         symprec = 0.2
         s = SpacegroupAnalyzer(structure, symprec=symprec)
-        self.logger.debug(
-            "Symmetry of structure is determined to be {}.".format(
-                s.get_space_group_symbol()
-            )
-        )
+        self.logger.debug("Symmetry of structure is determined to be {}.".format(s.get_space_group_symbol()))
         sg = s.get_space_group_operations()
         tested_sites = []
         starttime = time.time()
@@ -409,9 +386,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
             already_tested = False
             for i, tsites in enumerate(tested_sites):
                 tenergy = all_structures[i]["energy"]
-                if abs(
-                    (energy - tenergy) / len(s_new)
-                ) < 1e-5 and sg.are_symmetrically_equivalent(
+                if abs((energy - tenergy) / len(s_new)) < 1e-5 and sg.are_symmetrically_equivalent(
                     sites_to_remove, tsites, symm_prec=symprec
                 ):
                     already_tested = True
@@ -423,25 +398,11 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
             count += 1
             if count % 10 == 0:
                 timenow = time.time()
-                self.logger.debug(
-                    "{} structures, {:.2f} seconds.".format(count, timenow - starttime)
-                )
-                self.logger.debug(
-                    "Average time per combi = {} seconds".format(
-                        (timenow - starttime) / count
-                    )
-                )
-                self.logger.debug(
-                    "{} symmetrically distinct structures found.".format(
-                        len(all_structures)
-                    )
-                )
+                self.logger.debug("{} structures, {:.2f} seconds.".format(count, timenow - starttime))
+                self.logger.debug("Average time per combi = {} seconds".format((timenow - starttime) / count))
+                self.logger.debug("{} symmetrically distinct structures found.".format(len(all_structures)))
 
-        self.logger.debug(
-            "Total symmetrically distinct structures found = {}".format(
-                len(all_structures)
-            )
-        )
+        self.logger.debug("Total symmetrically distinct structures found = {}".format(len(all_structures)))
         all_structures = sorted(all_structures, key=lambda s: s["energy"])
         return all_structures
 
@@ -472,9 +433,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
             num_to_return,
             PartialRemoveSitesTransformation.ALGO_FAST,
         )
-        self.logger.debug(
-            "Minimizing Ewald took {} seconds.".format(time.time() - starttime)
-        )
+        self.logger.debug("Minimizing Ewald took {} seconds.".format(time.time() - starttime))
 
         all_structures = []
 
@@ -507,9 +466,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         s = structure.copy()
         for indices, fraction in zip(self.indices, self.fractions):
             for ind in indices:
-                new_sp = {
-                    sp: occu * fraction for sp, occu in structure[ind].species.items()
-                }
+                new_sp = {sp: occu * fraction for sp, occu in structure[ind].species.items()}
                 s[ind] = new_sp
         # Perform enumeration
         from pymatgen.transformations.advanced_transformations import (
@@ -545,19 +502,12 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         for indices, frac in zip(self.indices, self.fractions):
             num_to_remove = len(indices) * frac
             if abs(num_to_remove - int(round(num_to_remove))) > 1e-3:
-                raise ValueError(
-                    "Fraction to remove must be consistent with "
-                    "integer amounts in structure."
-                )
+                raise ValueError("Fraction to remove must be consistent with " "integer amounts in structure.")
             num_to_remove = int(round(num_to_remove))
             num_remove_dict[tuple(indices)] = num_to_remove
             n = len(indices)
             total_combis += int(
-                round(
-                    math.factorial(n)
-                    / math.factorial(num_to_remove)
-                    / math.factorial(n - num_to_remove)
-                )
+                round(math.factorial(n) / math.factorial(num_to_remove) / math.factorial(n - num_to_remove))
             )
 
         self.logger.debug("Total combinations = {}".format(total_combis))
@@ -571,9 +521,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         self.logger.debug("Will return {} best structures.".format(num_to_return))
 
         if self.algo == PartialRemoveSitesTransformation.ALGO_FAST:
-            all_structures = self._fast_ordering(
-                structure, num_remove_dict, num_to_return
-            )
+            all_structures = self._fast_ordering(structure, num_remove_dict, num_to_return)
         elif self.algo == PartialRemoveSitesTransformation.ALGO_COMPLETE:
             all_structures = self._complete_ordering(structure, num_remove_dict)
         elif self.algo == PartialRemoveSitesTransformation.ALGO_BEST_FIRST:
@@ -587,9 +535,8 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         return opt_s if not return_ranked_list else all_structures[0:num_to_return]
 
     def __str__(self):
-        return (
-            "PartialRemoveSitesTransformation : Indices and fraction"
-            + " to remove = {}, ALGO = {}".format(self.indices, self.algo)
+        return "PartialRemoveSitesTransformation : Indices and fraction" + " to remove = {}, ALGO = {}".format(
+            self.indices, self.algo
         )
 
     def __repr__(self):
